;;;; unitex-named-chars.scm  -*- Scheme -*-
;;;; Kon Lovett, Sep '20

;; Issues
;;
;; - /.../ to protect `:' from keyword interpretation, to set-out from other
;; named characters, & to bracket other special characters. Use of `/' to echo
;; `\' but otherwise arbitrary.
;;
;; - '|...| for uniformity but usually not required
;;
;; - no combined code-points
;;
;; - #\/^(/| & #\/^)/| are unusable: (print (char-name '|^(|)) NOT (print #\/^(/)

(module unitex-named-chars ()

(import scheme)
(import (only (chicken base) char-name))

(char-name '|exclamdown| (integer->char #x000A1))		; ¡	Inverted Exclamation Mark
(char-name '|sterling| (integer->char #x000A3))		; £	Pound Sign
(char-name '|yen| (integer->char #x000A5))			; ¥	Yen Sign
(char-name '|brokenbar| (integer->char #x000A6))			; ¦	Broken Bar / Broken Vertical Bar
(char-name '|/S/| (integer->char #x000A7))			; §	Section Sign
(char-name '|copyright| (integer->char #x000A9))			; ©	Copyright Sign
(char-name '|:copyright:| (integer->char #x000A9))			; ©	Copyright Sign
(char-name '|ordfeminine| (integer->char #x000AA))			; ª	Feminine Ordinal Indicator
(char-name '|neg| (integer->char #x000AC))			; ¬	Not Sign
(char-name '|circledR| (integer->char #x000AE))			; ®	Registered Sign / Registered Trade Mark Sign
(char-name '|:registered:| (integer->char #x000AE))			; ®	Registered Sign / Registered Trade Mark Sign
(char-name '|highminus| (integer->char #x000AF))			; ¯	Macron / Spacing Macron
(char-name '|degree| (integer->char #x000B0))			; °	Degree Sign
(char-name '|pm| (integer->char #x000B1))			; ±	Plus-Minus Sign / Plus-Or-Minus Sign
(char-name '|^2| (integer->char #x000B2))			; ²	Superscript Two / Superscript Digit Two
(char-name '|^3| (integer->char #x000B3))			; ³	Superscript Three / Superscript Digit Three
(char-name '|/P/| (integer->char #x000B6))			; ¶	Pilcrow Sign / Paragraph Sign
(char-name '|cdotp| (integer->char #x000B7))			; ·	Middle Dot
(char-name '|^1| (integer->char #x000B9))			; ¹	Superscript One / Superscript Digit One
(char-name '|ordmasculine| (integer->char #x000BA))			; º	Masculine Ordinal Indicator
(char-name '|1/4| (integer->char #x000BC))			; ¼	Vulgar Fraction One Quarter / Fraction One Quarter
(char-name '|1/2| (integer->char #x000BD))			; ½	Vulgar Fraction One Half / Fraction One Half
(char-name '|3/4| (integer->char #x000BE))			; ¾	Vulgar Fraction Three Quarters / Fraction Three Quarters
(char-name '|questiondown| (integer->char #x000BF))			; ¿	Inverted Question Mark
(char-name '|AA| (integer->char #x000C5))			; Å	Latin Capital Letter A With Ring Above / Latin Capital Letter A Ring
(char-name '|AE| (integer->char #x000C6))			; Æ	Latin Capital Letter Ae / Latin Capital Letter A E
(char-name '|DH| (integer->char #x000D0))			; Ð	Latin Capital Letter Eth
(char-name '|times| (integer->char #x000D7))			; ×	Multiplication Sign
(char-name '|/O/| (integer->char #x000D8))			; Ø	Latin Capital Letter O With Stroke / Latin Capital Letter O Slash
(char-name '|TH| (integer->char #x000DE))			; Þ	Latin Capital Letter Thorn
(char-name '|ss| (integer->char #x000DF))			; ß	Latin Small Letter Sharp S
(char-name '|aa| (integer->char #x000E5))			; å	Latin Small Letter A With Ring Above / Latin Small Letter A Ring
(char-name '|ae| (integer->char #x000E6))			; æ	Latin Small Letter Ae / Latin Small Letter A E
(char-name '|eth| (integer->char #x000F0))			; ð	Latin Small Letter Eth
(char-name '|dh| (integer->char #x000F0))			; ð	Latin Small Letter Eth
(char-name '|div| (integer->char #x000F7))			; ÷	Division Sign
(char-name '|/o/| (integer->char #x000F8))			; ø	Latin Small Letter O With Stroke / Latin Small Letter O Slash
(char-name '|th| (integer->char #x000FE))			; þ	Latin Small Letter Thorn
(char-name '|DJ| (integer->char #x00110))			; Đ	Latin Capital Letter D With Stroke / Latin Capital Letter D Bar
(char-name '|dj| (integer->char #x00111))			; đ	Latin Small Letter D With Stroke / Latin Small Letter D Bar
(char-name '|hbar| (integer->char #x00127))			; ħ	Latin Small Letter H With Stroke / Latin Small Letter H Bar
(char-name '|imath| (integer->char #x00131))			; ı	Latin Small Letter Dotless I
(char-name '|/L/| (integer->char #x00141))			; Ł	Latin Capital Letter L With Stroke / Latin Capital Letter L Slash
(char-name '|/l/| (integer->char #x00142))			; ł	Latin Small Letter L With Stroke / Latin Small Letter L Slash
(char-name '|NG| (integer->char #x0014A))			; Ŋ	Latin Capital Letter Eng
(char-name '|ng| (integer->char #x0014B))			; ŋ	Latin Small Letter Eng
(char-name '|OE| (integer->char #x00152))			; Œ	Latin Capital Ligature Oe / Latin Capital Letter O E
(char-name '|oe| (integer->char #x00153))			; œ	Latin Small Ligature Oe / Latin Small Letter O E
(char-name '|hvlig| (integer->char #x00195))			; ƕ	Latin Small Letter Hv / Latin Small Letter H V
(char-name '|nrleg| (integer->char #x0019E))			; ƞ	Latin Small Letter N With Long Right Leg
(char-name '|Zbar| (integer->char #x001B5))			; Ƶ	Latin Capital Letter Z With Stroke / Latin Capital Letter Z Bar
(char-name '|doublepipe| (integer->char #x001C2))			; ǂ	Latin Letter Alveolar Click / Latin Letter Pipe Double Bar
(char-name '|jmath| (integer->char #x00237))			; ȷ	Latin Small Letter Dotless J
(char-name '|trna| (integer->char #x00250))			; ɐ	Latin Small Letter Turned A
(char-name '|trnsa| (integer->char #x00252))			; ɒ	Latin Small Letter Turned Alpha / Latin Small Letter Turned Script A
(char-name '|openo| (integer->char #x00254))			; ɔ	Latin Small Letter Open O
(char-name '|rtld| (integer->char #x00256))			; ɖ	Latin Small Letter D With Tail / Latin Small Letter D Retroflex Hook
(char-name '|schwa| (integer->char #x00259))			; ə	Latin Small Letter Schwa
(char-name '|pgamma| (integer->char #x00263))			; ɣ	Latin Small Letter Gamma
(char-name '|pbgam| (integer->char #x00264))			; ɤ	Latin Small Letter Rams Horn / Latin Small Letter Baby Gamma
(char-name '|trnh| (integer->char #x00265))			; ɥ	Latin Small Letter Turned H
(char-name '|btdl| (integer->char #x0026C))			; ɬ	Latin Small Letter L With Belt / Latin Small Letter L Belt
(char-name '|rtll| (integer->char #x0026D))			; ɭ	Latin Small Letter L With Retroflex Hook / Latin Small Letter L Retroflex Hook
(char-name '|trnm| (integer->char #x0026F))			; ɯ	Latin Small Letter Turned M
(char-name '|trnmlr| (integer->char #x00270))			; ɰ	Latin Small Letter Turned M With Long Leg
(char-name '|ltlmr| (integer->char #x00271))			; ɱ	Latin Small Letter M With Hook / Latin Small Letter M Hook
(char-name '|ltln| (integer->char #x00272))			; ɲ	Latin Small Letter N With Left Hook / Latin Small Letter N Hook
(char-name '|rtln| (integer->char #x00273))			; ɳ	Latin Small Letter N With Retroflex Hook / Latin Small Letter N Retroflex Hook
(char-name '|clomeg| (integer->char #x00277))			; ɷ	Latin Small Letter Closed Omega
(char-name '|ltphi| (integer->char #x00278))			; ɸ	Latin Small Letter Phi
(char-name '|trnr| (integer->char #x00279))			; ɹ	Latin Small Letter Turned R
(char-name '|trnrl| (integer->char #x0027A))			; ɺ	Latin Small Letter Turned R With Long Leg
(char-name '|rttrnr| (integer->char #x0027B))			; ɻ	Latin Small Letter Turned R With Hook / Latin Small Letter Turned R Hook
(char-name '|rl| (integer->char #x0027C))			; ɼ	Latin Small Letter R With Long Leg
(char-name '|rtlr| (integer->char #x0027D))			; ɽ	Latin Small Letter R With Tail / Latin Small Letter R Hook
(char-name '|fhr| (integer->char #x0027E))			; ɾ	Latin Small Letter R With Fishhook / Latin Small Letter Fishhook R
(char-name '|rtls| (integer->char #x00282))			; ʂ	Latin Small Letter S With Hook / Latin Small Letter S Hook
(char-name '|esh| (integer->char #x00283))			; ʃ	Latin Small Letter Esh
(char-name '|trnt| (integer->char #x00287))			; ʇ	Latin Small Letter Turned T
(char-name '|rtlt| (integer->char #x00288))			; ʈ	Latin Small Letter T With Retroflex Hook / Latin Small Letter T Retroflex Hook
(char-name '|pupsil| (integer->char #x0028A))			; ʊ	Latin Small Letter Upsilon
(char-name '|pscrv| (integer->char #x0028B))			; ʋ	Latin Small Letter V With Hook / Latin Small Letter Script V
(char-name '|invv| (integer->char #x0028C))			; ʌ	Latin Small Letter Turned V
(char-name '|invw| (integer->char #x0028D))			; ʍ	Latin Small Letter Turned W
(char-name '|trny| (integer->char #x0028E))			; ʎ	Latin Small Letter Turned Y
(char-name '|rtlz| (integer->char #x00290))			; ʐ	Latin Small Letter Z With Retroflex Hook / Latin Small Letter Z Retroflex Hook
(char-name '|yogh| (integer->char #x00292))			; ʒ	Latin Small Letter Ezh / Latin Small Letter Yogh
(char-name '|glst| (integer->char #x00294))			; ʔ	Latin Letter Glottal Stop
(char-name '|reglst| (integer->char #x00295))			; ʕ	Latin Letter Pharyngeal Voiced Fricative / Latin Letter Reversed Glottal Stop
(char-name '|inglst| (integer->char #x00296))			; ʖ	Latin Letter Inverted Glottal Stop
(char-name '|turnk| (integer->char #x0029E))			; ʞ	Latin Small Letter Turned K
(char-name '|dyogh| (integer->char #x002A4))			; ʤ	Latin Small Letter Dezh Digraph / Latin Small Letter D Yogh
(char-name '|tesh| (integer->char #x002A7))			; ʧ	Latin Small Letter Tesh Digraph / Latin Small Letter T Esh
(char-name '|^h| (integer->char #x002B0))			; ʰ	Modifier Letter Small H
(char-name '|^j| (integer->char #x002B2))			; ʲ	Modifier Letter Small J
(char-name '|^r| (integer->char #x002B3))			; ʳ	Modifier Letter Small R
(char-name '|^w| (integer->char #x002B7))			; ʷ	Modifier Letter Small W
(char-name '|^y| (integer->char #x002B8))			; ʸ	Modifier Letter Small Y
(char-name '|rasp| (integer->char #x002BC))			; ʼ	Modifier Letter Apostrophe
(char-name '|verts| (integer->char #x002C8))			; ˈ	Modifier Letter Vertical Line
(char-name '|verti| (integer->char #x002CC))			; ˌ	Modifier Letter Low Vertical Line
(char-name '|lmrk| (integer->char #x002D0))			; ː	Modifier Letter Triangular Colon
(char-name '|hlmrk| (integer->char #x002D1))			; ˑ	Modifier Letter Half Triangular Colon
(char-name '|sbrhr| (integer->char #x002D2))			; ˒	Modifier Letter Centred Right Half Ring / Modifier Letter Centered Right Half Ring
(char-name '|sblhr| (integer->char #x002D3))			; ˓	Modifier Letter Centred Left Half Ring / Modifier Letter Centered Left Half Ring
(char-name '|rais| (integer->char #x002D4))			; ˔	Modifier Letter Up Tack
(char-name '|low| (integer->char #x002D5))			; ˕	Modifier Letter Down Tack
(char-name '|/u/| (integer->char #x002D8))			; ˘	Breve / Spacing Breve
(char-name '|tildelow| (integer->char #x002DC))			; ˜	Small Tilde / Spacing Tilde
(char-name '|^l| (integer->char #x002E1))			; ˡ	Modifier Letter Small L
(char-name '|^s| (integer->char #x002E2))			; ˢ	Modifier Letter Small S
(char-name '|^x| (integer->char #x002E3))			; ˣ	Modifier Letter Small X
(char-name '|grave| (integer->char #x00300))			; ̀	Combining Grave Accent / Non-Spacing Grave
(char-name '|acute| (integer->char #x00301))			; ́	Combining Acute Accent / Non-Spacing Acute
(char-name '|hat| (integer->char #x00302))			; ̂	Combining Circumflex Accent / Non-Spacing Circumflex
(char-name '|tilde| (integer->char #x00303))			; ̃	Combining Tilde / Non-Spacing Tilde
(char-name '|bar| (integer->char #x00304))			; ̄	Combining Macron / Non-Spacing Macron
(char-name '|overbar| (integer->char #x00305))			; ̅	Combining Overline / Non-Spacing Overscore
(char-name '|breve| (integer->char #x00306))			; ̆	Combining Breve / Non-Spacing Breve
(char-name '|dot| (integer->char #x00307))			; ̇	Combining Dot Above / Non-Spacing Dot Above
(char-name '|ddot| (integer->char #x00308))			; ̈	Combining Diaeresis / Non-Spacing Diaeresis
(char-name '|ovhook| (integer->char #x00309))			; ̉	Combining Hook Above / Non-Spacing Hook Above
(char-name '|ocirc| (integer->char #x0030A))			; ̊	Combining Ring Above / Non-Spacing Ring Above
(char-name '|/H/| (integer->char #x0030B))			; ̋	Combining Double Acute Accent / Non-Spacing Double Acute
(char-name '|check| (integer->char #x0030C))			; ̌	Combining Caron / Non-Spacing Hacek
(char-name '|candra| (integer->char #x00310))			; ̐	Combining Candrabindu / Non-Spacing Candrabindu
(char-name '|oturnedcomma| (integer->char #x00312))			; ̒	Combining Turned Comma Above / Non-Spacing Turned Comma Above
(char-name '|ocommatopright| (integer->char #x00315))			; ̕	Combining Comma Above Right / Non-Spacing Comma Above Right
(char-name '|droang| (integer->char #x0031A))			; ̚	Combining Left Angle Above / Non-Spacing Left Angle Above
(char-name '|palh| (integer->char #x00321))			; ̡	Combining Palatalized Hook Below / Non-Spacing Palatalized Hook Below
(char-name '|rh| (integer->char #x00322))			; ̢	Combining Retroflex Hook Below / Non-Spacing Retroflex Hook Below
(char-name '|/c/| (integer->char #x00327))			; ̧	Combining Cedilla / Non-Spacing Cedilla
(char-name '|/k/| (integer->char #x00328))			; ̨	Combining Ogonek / Non-Spacing Ogonek
(char-name '|sbbrg| (integer->char #x0032A))			; ̪	Combining Bridge Below / Non-Spacing Bridge Below
(char-name '|wideutilde| (integer->char #x00330))			; ̰	Combining Tilde Below / Non-Spacing Tilde Below
(char-name '|underbar| (integer->char #x00332))			; ̲	Combining Low Line / Non-Spacing Underscore
(char-name '|strike| (integer->char #x00336))			; ̶	Combining Long Stroke Overlay / Non-Spacing Long Bar Overlay
(char-name '|sout| (integer->char #x00336))			; ̶	Combining Long Stroke Overlay / Non-Spacing Long Bar Overlay
(char-name '|not| (integer->char #x00338))			; ̸	Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|underleftrightarrow| (integer->char #x0034D))			; ͍	Combining Left Right Arrow Below
(char-name '|Alpha| (integer->char #x00391))			; Α	Greek Capital Letter Alpha
(char-name '|Beta| (integer->char #x00392))			; Β	Greek Capital Letter Beta
(char-name '|Gamma| (integer->char #x00393))			; Γ	Greek Capital Letter Gamma
(char-name '|Delta| (integer->char #x00394))			; Δ	Greek Capital Letter Delta
(char-name '|Epsilon| (integer->char #x00395))			; Ε	Greek Capital Letter Epsilon
(char-name '|Zeta| (integer->char #x00396))			; Ζ	Greek Capital Letter Zeta
(char-name '|Eta| (integer->char #x00397))			; Η	Greek Capital Letter Eta
(char-name '|Theta| (integer->char #x00398))			; Θ	Greek Capital Letter Theta
(char-name '|Iota| (integer->char #x00399))			; Ι	Greek Capital Letter Iota
(char-name '|Kappa| (integer->char #x0039A))			; Κ	Greek Capital Letter Kappa
(char-name '|Lambda| (integer->char #x0039B))			; Λ	Greek Capital Letter Lamda / Greek Capital Letter Lambda
(char-name '|upMu| (integer->char #x0039C))			; Μ	Greek Capital Letter Mu
(char-name '|upNu| (integer->char #x0039D))			; Ν	Greek Capital Letter Nu
(char-name '|Xi| (integer->char #x0039E))			; Ξ	Greek Capital Letter Xi
(char-name '|upOmicron| (integer->char #x0039F))			; Ο	Greek Capital Letter Omicron
(char-name '|Pi| (integer->char #x003A0))			; Π	Greek Capital Letter Pi
(char-name '|Rho| (integer->char #x003A1))			; Ρ	Greek Capital Letter Rho
(char-name '|Sigma| (integer->char #x003A3))			; Σ	Greek Capital Letter Sigma
(char-name '|Tau| (integer->char #x003A4))			; Τ	Greek Capital Letter Tau
(char-name '|Upsilon| (integer->char #x003A5))			; Υ	Greek Capital Letter Upsilon
(char-name '|Phi| (integer->char #x003A6))			; Φ	Greek Capital Letter Phi
(char-name '|Chi| (integer->char #x003A7))			; Χ	Greek Capital Letter Chi
(char-name '|Psi| (integer->char #x003A8))			; Ψ	Greek Capital Letter Psi
(char-name '|Omega| (integer->char #x003A9))			; Ω	Greek Capital Letter Omega
(char-name '|alpha| (integer->char #x003B1))			; α	Greek Small Letter Alpha
(char-name '|beta| (integer->char #x003B2))			; β	Greek Small Letter Beta
(char-name '|gamma| (integer->char #x003B3))			; γ	Greek Small Letter Gamma
(char-name '|delta| (integer->char #x003B4))			; δ	Greek Small Letter Delta
(char-name '|upepsilon| (integer->char #x003B5))			; ε	Greek Small Letter Epsilon
(char-name '|varepsilon| (integer->char #x003B5))			; ε	Greek Small Letter Epsilon
(char-name '|zeta| (integer->char #x003B6))			; ζ	Greek Small Letter Zeta
(char-name '|eta| (integer->char #x003B7))			; η	Greek Small Letter Eta
(char-name '|theta| (integer->char #x003B8))			; θ	Greek Small Letter Theta
(char-name '|iota| (integer->char #x003B9))			; ι	Greek Small Letter Iota
(char-name '|kappa| (integer->char #x003BA))			; κ	Greek Small Letter Kappa
(char-name '|lambda| (integer->char #x003BB))			; λ	Greek Small Letter Lamda / Greek Small Letter Lambda
(char-name '|mu| (integer->char #x003BC))			; μ	Greek Small Letter Mu
(char-name '|nu| (integer->char #x003BD))			; ν	Greek Small Letter Nu
(char-name '|xi| (integer->char #x003BE))			; ξ	Greek Small Letter Xi
(char-name '|upomicron| (integer->char #x003BF))			; ο	Greek Small Letter Omicron
(char-name '|pi| (integer->char #x003C0))			; π	Greek Small Letter Pi
(char-name '|rho| (integer->char #x003C1))			; ρ	Greek Small Letter Rho
(char-name '|varsigma| (integer->char #x003C2))			; ς	Greek Small Letter Final Sigma
(char-name '|sigma| (integer->char #x003C3))			; σ	Greek Small Letter Sigma
(char-name '|tau| (integer->char #x003C4))			; τ	Greek Small Letter Tau
(char-name '|upsilon| (integer->char #x003C5))			; υ	Greek Small Letter Upsilon
(char-name '|varphi| (integer->char #x003C6))			; φ	Greek Small Letter Phi
(char-name '|chi| (integer->char #x003C7))			; χ	Greek Small Letter Chi
(char-name '|psi| (integer->char #x003C8))			; ψ	Greek Small Letter Psi
(char-name '|omega| (integer->char #x003C9))			; ω	Greek Small Letter Omega
(char-name '|upvarbeta| (integer->char #x003D0))			; ϐ	Greek Beta Symbol / Greek Small Letter Curled Beta
(char-name '|vartheta| (integer->char #x003D1))			; ϑ	Greek Theta Symbol / Greek Small Letter Script Theta
(char-name '|phi| (integer->char #x003D5))			; ϕ	Greek Phi Symbol / Greek Small Letter Script Phi
(char-name '|varpi| (integer->char #x003D6))			; ϖ	Greek Pi Symbol / Greek Small Letter Omega Pi
(char-name '|upoldKoppa| (integer->char #x003D8))			; Ϙ	Greek Letter Archaic Koppa
(char-name '|upoldkoppa| (integer->char #x003D9))			; ϙ	Greek Small Letter Archaic Koppa
(char-name '|Stigma| (integer->char #x003DA))			; Ϛ	Greek Letter Stigma / Greek Capital Letter Stigma
(char-name '|upstigma| (integer->char #x003DB))			; ϛ	Greek Small Letter Stigma
(char-name '|Digamma| (integer->char #x003DC))			; Ϝ	Greek Letter Digamma / Greek Capital Letter Digamma
(char-name '|digamma| (integer->char #x003DD))			; ϝ	Greek Small Letter Digamma
(char-name '|Koppa| (integer->char #x003DE))			; Ϟ	Greek Letter Koppa / Greek Capital Letter Koppa
(char-name '|upkoppa| (integer->char #x003DF))			; ϟ	Greek Small Letter Koppa
(char-name '|Sampi| (integer->char #x003E0))			; Ϡ	Greek Letter Sampi / Greek Capital Letter Sampi
(char-name '|upsampi| (integer->char #x003E1))			; ϡ	Greek Small Letter Sampi
(char-name '|varkappa| (integer->char #x003F0))			; ϰ	Greek Kappa Symbol / Greek Small Letter Script Kappa
(char-name '|varrho| (integer->char #x003F1))			; ϱ	Greek Rho Symbol / Greek Small Letter Tailed Rho
(char-name '|varTheta| (integer->char #x003F4))			; ϴ	Greek Capital Theta Symbol
(char-name '|epsilon| (integer->char #x003F5))			; ϵ	Greek Lunate Epsilon Symbol
(char-name '|backepsilon| (integer->char #x003F6))			; ϶	Greek Reversed Lunate Epsilon Symbol
(char-name '|^A| (integer->char #x01D2C))			; ᴬ	Modifier Letter Capital A
(char-name '|^B| (integer->char #x01D2E))			; ᴮ	Modifier Letter Capital B
(char-name '|^D| (integer->char #x01D30))			; ᴰ	Modifier Letter Capital D
(char-name '|^E| (integer->char #x01D31))			; ᴱ	Modifier Letter Capital E
(char-name '|^G| (integer->char #x01D33))			; ᴳ	Modifier Letter Capital G
(char-name '|^H| (integer->char #x01D34))			; ᴴ	Modifier Letter Capital H
(char-name '|^I| (integer->char #x01D35))			; ᴵ	Modifier Letter Capital I
(char-name '|^J| (integer->char #x01D36))			; ᴶ	Modifier Letter Capital J
(char-name '|^K| (integer->char #x01D37))			; ᴷ	Modifier Letter Capital K
(char-name '|^L| (integer->char #x01D38))			; ᴸ	Modifier Letter Capital L
(char-name '|^M| (integer->char #x01D39))			; ᴹ	Modifier Letter Capital M
(char-name '|^N| (integer->char #x01D3A))			; ᴺ	Modifier Letter Capital N
(char-name '|^O| (integer->char #x01D3C))			; ᴼ	Modifier Letter Capital O
(char-name '|^P| (integer->char #x01D3E))			; ᴾ	Modifier Letter Capital P
(char-name '|^R| (integer->char #x01D3F))			; ᴿ	Modifier Letter Capital R
(char-name '|^T| (integer->char #x01D40))			; ᵀ	Modifier Letter Capital T
(char-name '|^U| (integer->char #x01D41))			; ᵁ	Modifier Letter Capital U
(char-name '|^W| (integer->char #x01D42))			; ᵂ	Modifier Letter Capital W
(char-name '|^a| (integer->char #x01D43))			; ᵃ	Modifier Letter Small A
(char-name '|^alpha| (integer->char #x01D45))			; ᵅ	Modifier Letter Small Alpha
(char-name '|^b| (integer->char #x01D47))			; ᵇ	Modifier Letter Small B
(char-name '|^d| (integer->char #x01D48))			; ᵈ	Modifier Letter Small D
(char-name '|^e| (integer->char #x01D49))			; ᵉ	Modifier Letter Small E
(char-name '|^epsilon| (integer->char #x01D4B))			; ᵋ	Modifier Letter Small Open E
(char-name '|^g| (integer->char #x01D4D))			; ᵍ	Modifier Letter Small G
(char-name '|^k| (integer->char #x01D4F))			; ᵏ	Modifier Letter Small K
(char-name '|^m| (integer->char #x01D50))			; ᵐ	Modifier Letter Small M
(char-name '|^o| (integer->char #x01D52))			; ᵒ	Modifier Letter Small O
(char-name '|^p| (integer->char #x01D56))			; ᵖ	Modifier Letter Small P
(char-name '|^t| (integer->char #x01D57))			; ᵗ	Modifier Letter Small T
(char-name '|^u| (integer->char #x01D58))			; ᵘ	Modifier Letter Small U
(char-name '|^v| (integer->char #x01D5B))			; ᵛ	Modifier Letter Small V
(char-name '|^beta| (integer->char #x01D5D))			; ᵝ	Modifier Letter Small Beta
(char-name '|^gamma| (integer->char #x01D5E))			; ᵞ	Modifier Letter Small Greek Gamma
(char-name '|^delta| (integer->char #x01D5F))			; ᵟ	Modifier Letter Small Delta
(char-name '|^phi| (integer->char #x01D60))			; ᵠ	Modifier Letter Small Greek Phi
(char-name '|^chi| (integer->char #x01D61))			; ᵡ	Modifier Letter Small Chi
(char-name '|_i| (integer->char #x01D62))			; ᵢ	Latin Subscript Small Letter I
(char-name '|_r| (integer->char #x01D63))			; ᵣ	Latin Subscript Small Letter R
(char-name '|_u| (integer->char #x01D64))			; ᵤ	Latin Subscript Small Letter U
(char-name '|_v| (integer->char #x01D65))			; ᵥ	Latin Subscript Small Letter V
(char-name '|_beta| (integer->char #x01D66))			; ᵦ	Greek Subscript Small Letter Beta
(char-name '|_gamma| (integer->char #x01D67))			; ᵧ	Greek Subscript Small Letter Gamma
(char-name '|_rho| (integer->char #x01D68))			; ᵨ	Greek Subscript Small Letter Rho
(char-name '|_phi| (integer->char #x01D69))			; ᵩ	Greek Subscript Small Letter Phi
(char-name '|_chi| (integer->char #x01D6A))			; ᵪ	Greek Subscript Small Letter Chi
(char-name '|^c| (integer->char #x01D9C))			; ᶜ	Modifier Letter Small C
(char-name '|^f| (integer->char #x01DA0))			; ᶠ	Modifier Letter Small F
(char-name '|^iota| (integer->char #x01DA5))			; ᶥ	Modifier Letter Small Iota
(char-name '|^Phi| (integer->char #x01DB2))			; ᶲ	Modifier Letter Small Phi
(char-name '|^z| (integer->char #x01DBB))			; ᶻ	Modifier Letter Small Z
(char-name '|^theta| (integer->char #x01DBF))			; ᶿ	Modifier Letter Small Theta
(char-name '|enspace| (integer->char #x02002))			; 	En Space
(char-name '|quad| (integer->char #x02003))			; 	Em Space
(char-name '|thickspace| (integer->char #x02005))			; 	Four-Per-Em Space
(char-name '|thinspace| (integer->char #x02009))			; 	Thin Space
(char-name '|hspace| (integer->char #x0200A))			; 	Hair Space
(char-name '|endash| (integer->char #x02013))			; –	En Dash
(char-name '|emdash| (integer->char #x02014))			; —	Em Dash
(char-name '|Vert| (integer->char #x02016))			; ‖	Double Vertical Line / Double Vertical Bar
(char-name '|lq| (integer->char #x02018))			; ‘	Left Single Quotation Mark / Single Turned Comma Quotation Mark
(char-name '|rq| (integer->char #x02019))			; ’	Right Single Quotation Mark / Single Comma Quotation Mark
(char-name '|reapos| (integer->char #x0201B))			; ‛	Single High-Reversed-9 Quotation Mark / Single Reversed Comma Quotation Mark
(char-name '|quotedblleft| (integer->char #x0201C))			; “	Left Double Quotation Mark / Double Turned Comma Quotation Mark
(char-name '|quotedblright| (integer->char #x0201D))			; ”	Right Double Quotation Mark / Double Comma Quotation Mark
(char-name '|dagger| (integer->char #x02020))			; †	Dagger
(char-name '|ddagger| (integer->char #x02021))			; ‡	Double Dagger
(char-name '|bullet| (integer->char #x02022))			; •	Bullet
(char-name '|dots| (integer->char #x02026))			; …	Horizontal Ellipsis
(char-name '|ldots| (integer->char #x02026))			; …	Horizontal Ellipsis
(char-name '|perthousand| (integer->char #x02030))			; ‰	Per Mille Sign
(char-name '|pertenthousand| (integer->char #x02031))			; ‱	Per Ten Thousand Sign
(char-name '|prime| (integer->char #x02032))			; ′	Prime
(char-name '|pprime| (integer->char #x02033))			; ″	Double Prime
(char-name '|ppprime| (integer->char #x02034))			; ‴	Triple Prime
(char-name '|backprime| (integer->char #x02035))			; ‵	Reversed Prime
(char-name '|backpprime| (integer->char #x02036))			; ‶	Reversed Double Prime
(char-name '|backppprime| (integer->char #x02037))			; ‷	Reversed Triple Prime
(char-name '|guilsinglleft| (integer->char #x02039))			; ‹	Single Left-Pointing Angle Quotation Mark / Left Pointing Single Guillemet
(char-name '|guilsinglright| (integer->char #x0203A))			; ›	Single Right-Pointing Angle Quotation Mark / Right Pointing Single Guillemet
(char-name '|:bangbang:| (integer->char #x0203C))			; ‼	Double Exclamation Mark
(char-name '|tieconcat| (integer->char #x02040))			; ⁀	Character Tie
(char-name '|:interrobang:| (integer->char #x02049))			; ⁉	Exclamation Question Mark
(char-name '|pppprime| (integer->char #x02057))			; ⁗	Quadruple Prime
(char-name '|tricolon| (integer->char #x0205D))			; ⁝	Tricolon
(char-name '|nolinebreak| (integer->char #x02060))			; ⁠	Word Joiner
(char-name '|^0| (integer->char #x02070))			; ⁰	Superscript Zero / Superscript Digit Zero
(char-name '|^i| (integer->char #x02071))			; ⁱ	Superscript Latin Small Letter I
(char-name '|^4| (integer->char #x02074))			; ⁴	Superscript Four / Superscript Digit Four
(char-name '|^5| (integer->char #x02075))			; ⁵	Superscript Five / Superscript Digit Five
(char-name '|^6| (integer->char #x02076))			; ⁶	Superscript Six / Superscript Digit Six
(char-name '|^7| (integer->char #x02077))			; ⁷	Superscript Seven / Superscript Digit Seven
(char-name '|^8| (integer->char #x02078))			; ⁸	Superscript Eight / Superscript Digit Eight
(char-name '|^9| (integer->char #x02079))			; ⁹	Superscript Nine / Superscript Digit Nine
(char-name '|^+| (integer->char #x0207A))			; ⁺	Superscript Plus Sign
(char-name '|^-| (integer->char #x0207B))			; ⁻	Superscript Minus / Superscript Hyphen-Minus
(char-name '|^=| (integer->char #x0207C))			; ⁼	Superscript Equals Sign
(char-name '|^(| (integer->char #x0207D))			; ⁽	Superscript Left Parenthesis / Superscript Opening Parenthesis
(char-name '|^)| (integer->char #x0207E))			; ⁾	Superscript Right Parenthesis / Superscript Closing Parenthesis
(char-name '|^n| (integer->char #x0207F))			; ⁿ	Superscript Latin Small Letter N
(char-name '|_0| (integer->char #x02080))			; ₀	Subscript Zero / Subscript Digit Zero
(char-name '|_1| (integer->char #x02081))			; ₁	Subscript One / Subscript Digit One
(char-name '|_2| (integer->char #x02082))			; ₂	Subscript Two / Subscript Digit Two
(char-name '|_3| (integer->char #x02083))			; ₃	Subscript Three / Subscript Digit Three
(char-name '|_4| (integer->char #x02084))			; ₄	Subscript Four / Subscript Digit Four
(char-name '|_5| (integer->char #x02085))			; ₅	Subscript Five / Subscript Digit Five
(char-name '|_6| (integer->char #x02086))			; ₆	Subscript Six / Subscript Digit Six
(char-name '|_7| (integer->char #x02087))			; ₇	Subscript Seven / Subscript Digit Seven
(char-name '|_8| (integer->char #x02088))			; ₈	Subscript Eight / Subscript Digit Eight
(char-name '|_9| (integer->char #x02089))			; ₉	Subscript Nine / Subscript Digit Nine
(char-name '|_+| (integer->char #x0208A))			; ₊	Subscript Plus Sign
(char-name '|_-| (integer->char #x0208B))			; ₋	Subscript Minus / Subscript Hyphen-Minus
(char-name '|_=| (integer->char #x0208C))			; ₌	Subscript Equals Sign
(char-name '|_(| (integer->char #x0208D))			; ₍	Subscript Left Parenthesis / Subscript Opening Parenthesis
(char-name '|_)| (integer->char #x0208E))			; ₎	Subscript Right Parenthesis / Subscript Closing Parenthesis
(char-name '|_a| (integer->char #x02090))			; ₐ	Latin Subscript Small Letter A
(char-name '|_e| (integer->char #x02091))			; ₑ	Latin Subscript Small Letter E
(char-name '|_o| (integer->char #x02092))			; ₒ	Latin Subscript Small Letter O
(char-name '|_x| (integer->char #x02093))			; ₓ	Latin Subscript Small Letter X
(char-name '|_schwa| (integer->char #x02094))			; ₔ	Latin Subscript Small Letter Schwa
(char-name '|_h| (integer->char #x02095))			; ₕ	Latin Subscript Small Letter H
(char-name '|_k| (integer->char #x02096))			; ₖ	Latin Subscript Small Letter K
(char-name '|_l| (integer->char #x02097))			; ₗ	Latin Subscript Small Letter L
(char-name '|_m| (integer->char #x02098))			; ₘ	Latin Subscript Small Letter M
(char-name '|_n| (integer->char #x02099))			; ₙ	Latin Subscript Small Letter N
(char-name '|_p| (integer->char #x0209A))			; ₚ	Latin Subscript Small Letter P
(char-name '|_s| (integer->char #x0209B))			; ₛ	Latin Subscript Small Letter S
(char-name '|_t| (integer->char #x0209C))			; ₜ	Latin Subscript Small Letter T
(char-name '|pes| (integer->char #x020A7))			; ₧	Peseta Sign
(char-name '|euro| (integer->char #x020AC))			; €	Euro Sign
(char-name '|leftharpoonaccent| (integer->char #x020D0))			; ⃐	Combining Left Harpoon Above / Non-Spacing Left Harpoon Above
(char-name '|rightharpoonaccent| (integer->char #x020D1))			; ⃑	Combining Right Harpoon Above / Non-Spacing Right Harpoon Above
(char-name '|vertoverlay| (integer->char #x020D2))			; ⃒	Combining Long Vertical Line Overlay / Non-Spacing Long Vertical Bar Overlay
(char-name '|overleftarrow| (integer->char #x020D6))			; ⃖	Combining Left Arrow Above / Non-Spacing Left Arrow Above
(char-name '|vec| (integer->char #x020D7))			; ⃗	Combining Right Arrow Above / Non-Spacing Right Arrow Above
(char-name '|dddot| (integer->char #x020DB))			; ⃛	Combining Three Dots Above / Non-Spacing Three Dots Above
(char-name '|ddddot| (integer->char #x020DC))			; ⃜	Combining Four Dots Above / Non-Spacing Four Dots Above
(char-name '|enclosecircle| (integer->char #x020DD))			; ⃝	Combining Enclosing Circle / Enclosing Circle
(char-name '|enclosesquare| (integer->char #x020DE))			; ⃞	Combining Enclosing Square / Enclosing Square
(char-name '|enclosediamond| (integer->char #x020DF))			; ⃟	Combining Enclosing Diamond / Enclosing Diamond
(char-name '|overleftrightarrow| (integer->char #x020E1))			; ⃡	Combining Left Right Arrow Above / Non-Spacing Left Right Arrow Above
(char-name '|enclosetriangle| (integer->char #x020E4))			; ⃤	Combining Enclosing Upward Pointing Triangle
(char-name '|annuity| (integer->char #x020E7))			; ⃧	Combining Annuity Symbol
(char-name '|threeunderdot| (integer->char #x020E8))			; ⃨	Combining Triple Underdot
(char-name '|widebridgeabove| (integer->char #x020E9))			; ⃩	Combining Wide Bridge Above
(char-name '|underrightharpoondown| (integer->char #x020EC))			; ⃬	Combining Rightwards Harpoon With Barb Downwards
(char-name '|underleftharpoondown| (integer->char #x020ED))			; ⃭	Combining Leftwards Harpoon With Barb Downwards
(char-name '|underleftarrow| (integer->char #x020EE))			; ⃮	Combining Left Arrow Below
(char-name '|underrightarrow| (integer->char #x020EF))			; ⃯	Combining Right Arrow Below
(char-name '|asteraccent| (integer->char #x020F0))			; ⃰	Combining Asterisk Above
(char-name '|bbC| (integer->char #x02102))			; ℂ	Double-Struck Capital C / Double-Struck C
(char-name '|eulermascheroni| (integer->char #x02107))			; ℇ	Euler Constant / Eulers
(char-name '|scrg| (integer->char #x0210A))			; ℊ	Script Small G
(char-name '|scrH| (integer->char #x0210B))			; ℋ	Script Capital H / Script H
(char-name '|frakH| (integer->char #x0210C))			; ℌ	Black-Letter Capital H / Black-Letter H
(char-name '|bbH| (integer->char #x0210D))			; ℍ	Double-Struck Capital H / Double-Struck H
(char-name '|planck| (integer->char #x0210E))			; ℎ	Planck Constant
(char-name '|hslash| (integer->char #x0210F))			; ℏ	Planck Constant Over Two Pi / Planck Constant Over 2 Pi
(char-name '|scrI| (integer->char #x02110))			; ℐ	Script Capital I / Script I
(char-name '|Im| (integer->char #x02111))			; ℑ	Black-Letter Capital I / Black-Letter I
(char-name '|scrL| (integer->char #x02112))			; ℒ	Script Capital L / Script L
(char-name '|ell| (integer->char #x02113))			; ℓ	Script Small L
(char-name '|bbN| (integer->char #x02115))			; ℕ	Double-Struck Capital N / Double-Struck N
(char-name '|numero| (integer->char #x02116))			; №	Numero Sign / Numero
(char-name '|wp| (integer->char #x02118))			; ℘	Script Capital P / Script P
(char-name '|bbP| (integer->char #x02119))			; ℙ	Double-Struck Capital P / Double-Struck P
(char-name '|bbQ| (integer->char #x0211A))			; ℚ	Double-Struck Capital Q / Double-Struck Q
(char-name '|scrR| (integer->char #x0211B))			; ℛ	Script Capital R / Script R
(char-name '|Re| (integer->char #x0211C))			; ℜ	Black-Letter Capital R / Black-Letter R
(char-name '|bbR| (integer->char #x0211D))			; ℝ	Double-Struck Capital R / Double-Struck R
(char-name '|xrat| (integer->char #x0211E))			; ℞	Prescription Take
(char-name '|trademark| (integer->char #x02122))			; ™	Trade Mark Sign / Trademark
(char-name '|:tm:| (integer->char #x02122))			; ™	Trade Mark Sign / Trademark
(char-name '|bbZ| (integer->char #x02124))			; ℤ	Double-Struck Capital Z / Double-Struck Z
(char-name '|ohm| (integer->char #x02126))			; Ω	Ohm Sign / Ohm
(char-name '|mho| (integer->char #x02127))			; ℧	Inverted Ohm Sign / Mho
(char-name '|frakZ| (integer->char #x02128))			; ℨ	Black-Letter Capital Z / Black-Letter Z
(char-name '|turnediota| (integer->char #x02129))			; ℩	Turned Greek Small Letter Iota
(char-name '|Angstrom| (integer->char #x0212B))			; Å	Angstrom Sign / Angstrom Unit
(char-name '|scrB| (integer->char #x0212C))			; ℬ	Script Capital B / Script B
(char-name '|frakC| (integer->char #x0212D))			; ℭ	Black-Letter Capital C / Black-Letter C
(char-name '|scre| (integer->char #x0212F))			; ℯ	Script Small E
(char-name '|euler| (integer->char #x0212F))			; ℯ	Script Small E
(char-name '|scrE| (integer->char #x02130))			; ℰ	Script Capital E / Script E
(char-name '|scrF| (integer->char #x02131))			; ℱ	Script Capital F / Script F
(char-name '|Finv| (integer->char #x02132))			; Ⅎ	Turned Capital F / Turned F
(char-name '|scrM| (integer->char #x02133))			; ℳ	Script Capital M / Script M
(char-name '|scro| (integer->char #x02134))			; ℴ	Script Small O
(char-name '|aleph| (integer->char #x02135))			; ℵ	Alef Symbol / First Transfinite Cardinal
(char-name '|beth| (integer->char #x02136))			; ℶ	Bet Symbol / Second Transfinite Cardinal
(char-name '|gimel| (integer->char #x02137))			; ℷ	Gimel Symbol / Third Transfinite Cardinal
(char-name '|daleth| (integer->char #x02138))			; ℸ	Dalet Symbol / Fourth Transfinite Cardinal
(char-name '|:information_source:| (integer->char #x02139))			; ℹ	Information Source
(char-name '|bbpi| (integer->char #x0213C))			; ℼ	Double-Struck Small Pi
(char-name '|bbgamma| (integer->char #x0213D))			; ℽ	Double-Struck Small Gamma
(char-name '|bbGamma| (integer->char #x0213E))			; ℾ	Double-Struck Capital Gamma
(char-name '|bbPi| (integer->char #x0213F))			; ℿ	Double-Struck Capital Pi
(char-name '|bbsum| (integer->char #x02140))			; ⅀	Double-Struck N-Ary Summation
(char-name '|Game| (integer->char #x02141))			; ⅁	Turned Sans-Serif Capital G
(char-name '|sansLturned| (integer->char #x02142))			; ⅂	Turned Sans-Serif Capital L
(char-name '|sansLmirrored| (integer->char #x02143))			; ⅃	Reversed Sans-Serif Capital L
(char-name '|Yup| (integer->char #x02144))			; ⅄	Turned Sans-Serif Capital Y
(char-name '|bbiD| (integer->char #x02145))			; ⅅ	Double-Struck Italic Capital D
(char-name '|bbid| (integer->char #x02146))			; ⅆ	Double-Struck Italic Small D
(char-name '|bbie| (integer->char #x02147))			; ⅇ	Double-Struck Italic Small E
(char-name '|bbii| (integer->char #x02148))			; ⅈ	Double-Struck Italic Small I
(char-name '|bbij| (integer->char #x02149))			; ⅉ	Double-Struck Italic Small J
(char-name '|PropertyLine| (integer->char #x0214A))			; ⅊	Property Line
(char-name '|upand| (integer->char #x0214B))			; ⅋	Turned Ampersand
(char-name '|1/7| (integer->char #x02150))			; ⅐	Vulgar Fraction One Seventh
(char-name '|1/9| (integer->char #x02151))			; ⅑	Vulgar Fraction One Ninth
(char-name '|1/10| (integer->char #x02152))			; ⅒	Vulgar Fraction One Tenth
(char-name '|1/3| (integer->char #x02153))			; ⅓	Vulgar Fraction One Third / Fraction One Third
(char-name '|2/3| (integer->char #x02154))			; ⅔	Vulgar Fraction Two Thirds / Fraction Two Thirds
(char-name '|1/5| (integer->char #x02155))			; ⅕	Vulgar Fraction One Fifth / Fraction One Fifth
(char-name '|2/5| (integer->char #x02156))			; ⅖	Vulgar Fraction Two Fifths / Fraction Two Fifths
(char-name '|3/5| (integer->char #x02157))			; ⅗	Vulgar Fraction Three Fifths / Fraction Three Fifths
(char-name '|4/5| (integer->char #x02158))			; ⅘	Vulgar Fraction Four Fifths / Fraction Four Fifths
(char-name '|1/6| (integer->char #x02159))			; ⅙	Vulgar Fraction One Sixth / Fraction One Sixth
(char-name '|5/6| (integer->char #x0215A))			; ⅚	Vulgar Fraction Five Sixths / Fraction Five Sixths
(char-name '|1/8| (integer->char #x0215B))			; ⅛	Vulgar Fraction One Eighth / Fraction One Eighth
(char-name '|3/8| (integer->char #x0215C))			; ⅜	Vulgar Fraction Three Eighths / Fraction Three Eighths
(char-name '|5/8| (integer->char #x0215D))			; ⅝	Vulgar Fraction Five Eighths / Fraction Five Eighths
(char-name '|7/8| (integer->char #x0215E))			; ⅞	Vulgar Fraction Seven Eighths / Fraction Seven Eighths
(char-name '|1/| (integer->char #x0215F))			; ⅟	Fraction Numerator One
(char-name '|0/3| (integer->char #x02189))			; ↉	Vulgar Fraction Zero Thirds
(char-name '|leftarrow| (integer->char #x02190))			; ←	Leftwards Arrow / Left Arrow
(char-name '|uparrow| (integer->char #x02191))			; ↑	Upwards Arrow / Up Arrow
(char-name '|to| (integer->char #x02192))			; →	Rightwards Arrow / Right Arrow
(char-name '|rightarrow| (integer->char #x02192))			; →	Rightwards Arrow / Right Arrow
(char-name '|downarrow| (integer->char #x02193))			; ↓	Downwards Arrow / Down Arrow
(char-name '|leftrightarrow| (integer->char #x02194))			; ↔	Left Right Arrow
(char-name '|:left_right_arrow:| (integer->char #x02194))			; ↔	Left Right Arrow
(char-name '|updownarrow| (integer->char #x02195))			; ↕	Up Down Arrow
(char-name '|:arrow_up_down:| (integer->char #x02195))			; ↕	Up Down Arrow
(char-name '|nwarrow| (integer->char #x02196))			; ↖	North West Arrow / Upper Left Arrow
(char-name '|:arrow_upper_left:| (integer->char #x02196))			; ↖	North West Arrow / Upper Left Arrow
(char-name '|nearrow| (integer->char #x02197))			; ↗	North East Arrow / Upper Right Arrow
(char-name '|:arrow_upper_right:| (integer->char #x02197))			; ↗	North East Arrow / Upper Right Arrow
(char-name '|searrow| (integer->char #x02198))			; ↘	South East Arrow / Lower Right Arrow
(char-name '|:arrow_lower_right:| (integer->char #x02198))			; ↘	South East Arrow / Lower Right Arrow
(char-name '|swarrow| (integer->char #x02199))			; ↙	South West Arrow / Lower Left Arrow
(char-name '|:arrow_lower_left:| (integer->char #x02199))			; ↙	South West Arrow / Lower Left Arrow
(char-name '|nleftarrow| (integer->char #x0219A))			; ↚	Leftwards Arrow With Stroke / Left Arrow With Stroke
(char-name '|nrightarrow| (integer->char #x0219B))			; ↛	Rightwards Arrow With Stroke / Right Arrow With Stroke
(char-name '|leftwavearrow| (integer->char #x0219C))			; ↜	Leftwards Wave Arrow / Left Wave Arrow
(char-name '|rightwavearrow| (integer->char #x0219D))			; ↝	Rightwards Wave Arrow / Right Wave Arrow
(char-name '|twoheadleftarrow| (integer->char #x0219E))			; ↞	Leftwards Two Headed Arrow / Left Two Headed Arrow
(char-name '|twoheaduparrow| (integer->char #x0219F))			; ↟	Upwards Two Headed Arrow / Up Two Headed Arrow
(char-name '|twoheadrightarrow| (integer->char #x021A0))			; ↠	Rightwards Two Headed Arrow / Right Two Headed Arrow
(char-name '|twoheaddownarrow| (integer->char #x021A1))			; ↡	Downwards Two Headed Arrow / Down Two Headed Arrow
(char-name '|leftarrowtail| (integer->char #x021A2))			; ↢	Leftwards Arrow With Tail / Left Arrow With Tail
(char-name '|rightarrowtail| (integer->char #x021A3))			; ↣	Rightwards Arrow With Tail / Right Arrow With Tail
(char-name '|mapsfrom| (integer->char #x021A4))			; ↤	Leftwards Arrow From Bar / Left Arrow From Bar
(char-name '|mapsup| (integer->char #x021A5))			; ↥	Upwards Arrow From Bar / Up Arrow From Bar
(char-name '|mapsto| (integer->char #x021A6))			; ↦	Rightwards Arrow From Bar / Right Arrow From Bar
(char-name '|mapsdown| (integer->char #x021A7))			; ↧	Downwards Arrow From Bar / Down Arrow From Bar
(char-name '|updownarrowbar| (integer->char #x021A8))			; ↨	Up Down Arrow With Base
(char-name '|hookleftarrow| (integer->char #x021A9))			; ↩	Leftwards Arrow With Hook / Left Arrow With Hook
(char-name '|:leftwards_arrow_with_hook:| (integer->char #x021A9))			; ↩	Leftwards Arrow With Hook / Left Arrow With Hook
(char-name '|hookrightarrow| (integer->char #x021AA))			; ↪	Rightwards Arrow With Hook / Right Arrow With Hook
(char-name '|:arrow_right_hook:| (integer->char #x021AA))			; ↪	Rightwards Arrow With Hook / Right Arrow With Hook
(char-name '|looparrowleft| (integer->char #x021AB))			; ↫	Leftwards Arrow With Loop / Left Arrow With Loop
(char-name '|looparrowright| (integer->char #x021AC))			; ↬	Rightwards Arrow With Loop / Right Arrow With Loop
(char-name '|leftrightsquigarrow| (integer->char #x021AD))			; ↭	Left Right Wave Arrow
(char-name '|nleftrightarrow| (integer->char #x021AE))			; ↮	Left Right Arrow With Stroke
(char-name '|downzigzagarrow| (integer->char #x021AF))			; ↯	Downwards Zigzag Arrow / Down Zigzag Arrow
(char-name '|Lsh| (integer->char #x021B0))			; ↰	Upwards Arrow With Tip Leftwards / Up Arrow With Tip Left
(char-name '|Rsh| (integer->char #x021B1))			; ↱	Upwards Arrow With Tip Rightwards / Up Arrow With Tip Right
(char-name '|Ldsh| (integer->char #x021B2))			; ↲	Downwards Arrow With Tip Leftwards / Down Arrow With Tip Left
(char-name '|Rdsh| (integer->char #x021B3))			; ↳	Downwards Arrow With Tip Rightwards / Down Arrow With Tip Right
(char-name '|linefeed| (integer->char #x021B4))			; ↴	Rightwards Arrow With Corner Downwards / Right Arrow With Corner Down
(char-name '|carriagereturn| (integer->char #x021B5))			; ↵	Downwards Arrow With Corner Leftwards / Down Arrow With Corner Left
(char-name '|curvearrowleft| (integer->char #x021B6))			; ↶	Anticlockwise Top Semicircle Arrow
(char-name '|curvearrowright| (integer->char #x021B7))			; ↷	Clockwise Top Semicircle Arrow
(char-name '|barovernorthwestarrow| (integer->char #x021B8))			; ↸	North West Arrow To Long Bar / Upper Left Arrow To Long Bar
(char-name '|barleftarrowrightarrowbar| (integer->char #x021B9))			; ↹	Leftwards Arrow To Bar Over Rightwards Arrow To Bar / Left Arrow To Bar Over Right Arrow To Bar
(char-name '|circlearrowleft| (integer->char #x021BA))			; ↺	Anticlockwise Open Circle Arrow
(char-name '|circlearrowright| (integer->char #x021BB))			; ↻	Clockwise Open Circle Arrow
(char-name '|leftharpoonup| (integer->char #x021BC))			; ↼	Leftwards Harpoon With Barb Upwards / Left Harpoon With Barb Up
(char-name '|leftharpoondown| (integer->char #x021BD))			; ↽	Leftwards Harpoon With Barb Downwards / Left Harpoon With Barb Down
(char-name '|upharpoonright| (integer->char #x021BE))			; ↾	Upwards Harpoon With Barb Rightwards / Up Harpoon With Barb Right
(char-name '|upharpoonleft| (integer->char #x021BF))			; ↿	Upwards Harpoon With Barb Leftwards / Up Harpoon With Barb Left
(char-name '|rightharpoonup| (integer->char #x021C0))			; ⇀	Rightwards Harpoon With Barb Upwards / Right Harpoon With Barb Up
(char-name '|rightharpoondown| (integer->char #x021C1))			; ⇁	Rightwards Harpoon With Barb Downwards / Right Harpoon With Barb Down
(char-name '|downharpoonright| (integer->char #x021C2))			; ⇂	Downwards Harpoon With Barb Rightwards / Down Harpoon With Barb Right
(char-name '|downharpoonleft| (integer->char #x021C3))			; ⇃	Downwards Harpoon With Barb Leftwards / Down Harpoon With Barb Left
(char-name '|rightleftarrows| (integer->char #x021C4))			; ⇄	Rightwards Arrow Over Leftwards Arrow / Right Arrow Over Left Arrow
(char-name '|dblarrowupdown| (integer->char #x021C5))			; ⇅	Upwards Arrow Leftwards Of Downwards Arrow / Up Arrow Left Of Down Arrow
(char-name '|leftrightarrows| (integer->char #x021C6))			; ⇆	Leftwards Arrow Over Rightwards Arrow / Left Arrow Over Right Arrow
(char-name '|leftleftarrows| (integer->char #x021C7))			; ⇇	Leftwards Paired Arrows / Left Paired Arrows
(char-name '|upuparrows| (integer->char #x021C8))			; ⇈	Upwards Paired Arrows / Up Paired Arrows
(char-name '|rightrightarrows| (integer->char #x021C9))			; ⇉	Rightwards Paired Arrows / Right Paired Arrows
(char-name '|downdownarrows| (integer->char #x021CA))			; ⇊	Downwards Paired Arrows / Down Paired Arrows
(char-name '|leftrightharpoons| (integer->char #x021CB))			; ⇋	Leftwards Harpoon Over Rightwards Harpoon / Left Harpoon Over Right Harpoon
(char-name '|rightleftharpoons| (integer->char #x021CC))			; ⇌	Rightwards Harpoon Over Leftwards Harpoon / Right Harpoon Over Left Harpoon
(char-name '|nLeftarrow| (integer->char #x021CD))			; ⇍	Leftwards Double Arrow With Stroke / Left Double Arrow With Stroke
(char-name '|nLeftrightarrow| (integer->char #x021CE))			; ⇎	Left Right Double Arrow With Stroke
(char-name '|nRightarrow| (integer->char #x021CF))			; ⇏	Rightwards Double Arrow With Stroke / Right Double Arrow With Stroke
(char-name '|Leftarrow| (integer->char #x021D0))			; ⇐	Leftwards Double Arrow / Left Double Arrow
(char-name '|Uparrow| (integer->char #x021D1))			; ⇑	Upwards Double Arrow / Up Double Arrow
(char-name '|Rightarrow| (integer->char #x021D2))			; ⇒	Rightwards Double Arrow / Right Double Arrow
(char-name '|Downarrow| (integer->char #x021D3))			; ⇓	Downwards Double Arrow / Down Double Arrow
(char-name '|Leftrightarrow| (integer->char #x021D4))			; ⇔	Left Right Double Arrow
(char-name '|Updownarrow| (integer->char #x021D5))			; ⇕	Up Down Double Arrow
(char-name '|Nwarrow| (integer->char #x021D6))			; ⇖	North West Double Arrow / Upper Left Double Arrow
(char-name '|Nearrow| (integer->char #x021D7))			; ⇗	North East Double Arrow / Upper Right Double Arrow
(char-name '|Searrow| (integer->char #x021D8))			; ⇘	South East Double Arrow / Lower Right Double Arrow
(char-name '|Swarrow| (integer->char #x021D9))			; ⇙	South West Double Arrow / Lower Left Double Arrow
(char-name '|Lleftarrow| (integer->char #x021DA))			; ⇚	Leftwards Triple Arrow / Left Triple Arrow
(char-name '|Rrightarrow| (integer->char #x021DB))			; ⇛	Rightwards Triple Arrow / Right Triple Arrow
(char-name '|leftsquigarrow| (integer->char #x021DC))			; ⇜	Leftwards Squiggle Arrow / Left Squiggle Arrow
(char-name '|rightsquigarrow| (integer->char #x021DD))			; ⇝	Rightwards Squiggle Arrow / Right Squiggle Arrow
(char-name '|nHuparrow| (integer->char #x021DE))			; ⇞	Upwards Arrow With Double Stroke / Up Arrow With Double Stroke
(char-name '|nHdownarrow| (integer->char #x021DF))			; ⇟	Downwards Arrow With Double Stroke / Down Arrow With Double Stroke
(char-name '|leftdasharrow| (integer->char #x021E0))			; ⇠	Leftwards Dashed Arrow / Left Dashed Arrow
(char-name '|updasharrow| (integer->char #x021E1))			; ⇡	Upwards Dashed Arrow / Up Dashed Arrow
(char-name '|rightdasharrow| (integer->char #x021E2))			; ⇢	Rightwards Dashed Arrow / Right Dashed Arrow
(char-name '|downdasharrow| (integer->char #x021E3))			; ⇣	Downwards Dashed Arrow / Down Dashed Arrow
(char-name '|barleftarrow| (integer->char #x021E4))			; ⇤	Leftwards Arrow To Bar / Left Arrow To Bar
(char-name '|rightarrowbar| (integer->char #x021E5))			; ⇥	Rightwards Arrow To Bar / Right Arrow To Bar
(char-name '|leftwhitearrow| (integer->char #x021E6))			; ⇦	Leftwards White Arrow / White Left Arrow
(char-name '|upwhitearrow| (integer->char #x021E7))			; ⇧	Upwards White Arrow / White Up Arrow
(char-name '|rightwhitearrow| (integer->char #x021E8))			; ⇨	Rightwards White Arrow / White Right Arrow
(char-name '|downwhitearrow| (integer->char #x021E9))			; ⇩	Downwards White Arrow / White Down Arrow
(char-name '|whitearrowupfrombar| (integer->char #x021EA))			; ⇪	Upwards White Arrow From Bar / White Up Arrow From Bar
(char-name '|circleonrightarrow| (integer->char #x021F4))			; ⇴	Right Arrow With Small Circle
(char-name '|DownArrowUpArrow| (integer->char #x021F5))			; ⇵	Downwards Arrow Leftwards Of Upwards Arrow
(char-name '|rightthreearrows| (integer->char #x021F6))			; ⇶	Three Rightwards Arrows
(char-name '|nvleftarrow| (integer->char #x021F7))			; ⇷	Leftwards Arrow With Vertical Stroke
(char-name '|nvrightarrow| (integer->char #x021F8))			; ⇸	Rightwards Arrow With Vertical Stroke
(char-name '|nvleftrightarrow| (integer->char #x021F9))			; ⇹	Left Right Arrow With Vertical Stroke
(char-name '|nVleftarrow| (integer->char #x021FA))			; ⇺	Leftwards Arrow With Double Vertical Stroke
(char-name '|nVrightarrow| (integer->char #x021FB))			; ⇻	Rightwards Arrow With Double Vertical Stroke
(char-name '|nVleftrightarrow| (integer->char #x021FC))			; ⇼	Left Right Arrow With Double Vertical Stroke
(char-name '|leftarrowtriangle| (integer->char #x021FD))			; ⇽	Leftwards Open-Headed Arrow
(char-name '|rightarrowtriangle| (integer->char #x021FE))			; ⇾	Rightwards Open-Headed Arrow
(char-name '|leftrightarrowtriangle| (integer->char #x021FF))			; ⇿	Left Right Open-Headed Arrow
(char-name '|forall| (integer->char #x02200))			; ∀	For All
(char-name '|complement| (integer->char #x02201))			; ∁	Complement
(char-name '|partial| (integer->char #x02202))			; ∂	Partial Differential
(char-name '|exists| (integer->char #x02203))			; ∃	There Exists
(char-name '|nexists| (integer->char #x02204))			; ∄	There Does Not Exist
(char-name '|varnothing| (integer->char #x02205))			; ∅	Empty Set
(char-name '|emptyset| (integer->char #x02205))			; ∅	Empty Set
(char-name '|increment| (integer->char #x02206))			; ∆	Increment
(char-name '|del| (integer->char #x02207))			; ∇	Nabla
(char-name '|nabla| (integer->char #x02207))			; ∇	Nabla
(char-name '|in| (integer->char #x02208))			; ∈	Element Of
(char-name '|notin| (integer->char #x02209))			; ∉	Not An Element Of
(char-name '|smallin| (integer->char #x0220A))			; ∊	Small Element Of
(char-name '|ni| (integer->char #x0220B))			; ∋	Contains As Member
(char-name '|nni| (integer->char #x0220C))			; ∌	Does Not Contain As Member
(char-name '|smallni| (integer->char #x0220D))			; ∍	Small Contains As Member
(char-name '|QED| (integer->char #x0220E))			; ∎	End Of Proof
(char-name '|prod| (integer->char #x0220F))			; ∏	N-Ary Product
(char-name '|coprod| (integer->char #x02210))			; ∐	N-Ary Coproduct
(char-name '|sum| (integer->char #x02211))			; ∑	N-Ary Summation
(char-name '|minus| (integer->char #x02212))			; −	Minus Sign
(char-name '|mp| (integer->char #x02213))			; ∓	Minus-Or-Plus Sign
(char-name '|dotplus| (integer->char #x02214))			; ∔	Dot Plus
(char-name '|setminus| (integer->char #x02216))			; ∖	Set Minus
(char-name '|ast| (integer->char #x02217))			; ∗	Asterisk Operator
(char-name '|circ| (integer->char #x02218))			; ∘	Ring Operator
(char-name '|vysmblkcircle| (integer->char #x02219))			; ∙	Bullet Operator
(char-name '|surd| (integer->char #x0221A))			; √	Square Root
(char-name '|sqrt| (integer->char #x0221A))			; √	Square Root
(char-name '|cbrt| (integer->char #x0221B))			; ∛	Cube Root
(char-name '|fourthroot| (integer->char #x0221C))			; ∜	Fourth Root
(char-name '|propto| (integer->char #x0221D))			; ∝	Proportional To
(char-name '|infty| (integer->char #x0221E))			; ∞	Infinity
(char-name '|rightangle| (integer->char #x0221F))			; ∟	Right Angle
(char-name '|angle| (integer->char #x02220))			; ∠	Angle
(char-name '|measuredangle| (integer->char #x02221))			; ∡	Measured Angle
(char-name '|sphericalangle| (integer->char #x02222))			; ∢	Spherical Angle
(char-name '|mid| (integer->char #x02223))			; ∣	Divides
(char-name '|nmid| (integer->char #x02224))			; ∤	Does Not Divide
(char-name '|parallel| (integer->char #x02225))			; ∥	Parallel To
(char-name '|nparallel| (integer->char #x02226))			; ∦	Not Parallel To
(char-name '|wedge| (integer->char #x02227))			; ∧	Logical And
(char-name '|vee| (integer->char #x02228))			; ∨	Logical Or
(char-name '|cap| (integer->char #x02229))			; ∩	Intersection
(char-name '|cup| (integer->char #x0222A))			; ∪	Union
(char-name '|int| (integer->char #x0222B))			; ∫	Integral
(char-name '|iint| (integer->char #x0222C))			; ∬	Double Integral
(char-name '|iiint| (integer->char #x0222D))			; ∭	Triple Integral
(char-name '|oint| (integer->char #x0222E))			; ∮	Contour Integral
(char-name '|oiint| (integer->char #x0222F))			; ∯	Surface Integral
(char-name '|oiiint| (integer->char #x02230))			; ∰	Volume Integral
(char-name '|clwintegral| (integer->char #x02231))			; ∱	Clockwise Integral
(char-name '|varointclockwise| (integer->char #x02232))			; ∲	Clockwise Contour Integral
(char-name '|ointctrclockwise| (integer->char #x02233))			; ∳	Anticlockwise Contour Integral
(char-name '|therefore| (integer->char #x02234))			; ∴	Therefore
(char-name '|because| (integer->char #x02235))			; ∵	Because
(char-name '|Colon| (integer->char #x02237))			; ∷	Proportion
(char-name '|dotminus| (integer->char #x02238))			; ∸	Dot Minus
(char-name '|dotsminusdots| (integer->char #x0223A))			; ∺	Geometric Proportion
(char-name '|kernelcontraction| (integer->char #x0223B))			; ∻	Homothetic
(char-name '|sim| (integer->char #x0223C))			; ∼	Tilde Operator
(char-name '|backsim| (integer->char #x0223D))			; ∽	Reversed Tilde
(char-name '|lazysinv| (integer->char #x0223E))			; ∾	Inverted Lazy S
(char-name '|sinewave| (integer->char #x0223F))			; ∿	Sine Wave
(char-name '|wr| (integer->char #x02240))			; ≀	Wreath Product
(char-name '|nsim| (integer->char #x02241))			; ≁	Not Tilde
(char-name '|eqsim| (integer->char #x02242))			; ≂	Minus Tilde
;(char-name '|neqsim|  U+02242 + U+00338)			; ≂̸	Minus Tilde + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|simeq| (integer->char #x02243))			; ≃	Asymptotically Equal To
(char-name '|nsime| (integer->char #x02244))			; ≄	Not Asymptotically Equal To
(char-name '|cong| (integer->char #x02245))			; ≅	Approximately Equal To
(char-name '|approxnotequal| (integer->char #x02246))			; ≆	Approximately But Not Actually Equal To
(char-name '|ncong| (integer->char #x02247))			; ≇	Neither Approximately Nor Actually Equal To
(char-name '|approx| (integer->char #x02248))			; ≈	Almost Equal To
(char-name '|napprox| (integer->char #x02249))			; ≉	Not Almost Equal To
(char-name '|approxeq| (integer->char #x0224A))			; ≊	Almost Equal Or Equal To
(char-name '|tildetrpl| (integer->char #x0224B))			; ≋	Triple Tilde
(char-name '|allequal| (integer->char #x0224C))			; ≌	All Equal To
(char-name '|asymp| (integer->char #x0224D))			; ≍	Equivalent To
(char-name '|Bumpeq| (integer->char #x0224E))			; ≎	Geometrically Equivalent To
;(char-name '|nBumpeq|  U+0224E + U+00338)			; ≎̸	Geometrically Equivalent To + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|bumpeq| (integer->char #x0224F))			; ≏	Difference Between
;(char-name '|nbumpeq|  U+0224F + U+00338)			; ≏̸	Difference Between + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|doteq| (integer->char #x02250))			; ≐	Approaches The Limit
(char-name '|Doteq| (integer->char #x02251))			; ≑	Geometrically Equal To
(char-name '|fallingdotseq| (integer->char #x02252))			; ≒	Approximately Equal To Or The Image Of
(char-name '|risingdotseq| (integer->char #x02253))			; ≓	Image Of Or Approximately Equal To
(char-name '|coloneq| (integer->char #x02254))			; ≔	Colon Equals / Colon Equal
(char-name '|eqcolon| (integer->char #x02255))			; ≕	Equals Colon / Equal Colon
(char-name '|eqcirc| (integer->char #x02256))			; ≖	Ring In Equal To
(char-name '|circeq| (integer->char #x02257))			; ≗	Ring Equal To
(char-name '|arceq| (integer->char #x02258))			; ≘	Corresponds To
(char-name '|wedgeq| (integer->char #x02259))			; ≙	Estimates
(char-name '|veeeq| (integer->char #x0225A))			; ≚	Equiangular To
(char-name '|starequal| (integer->char #x0225B))			; ≛	Star Equals
(char-name '|triangleq| (integer->char #x0225C))			; ≜	Delta Equal To
(char-name '|eqdef| (integer->char #x0225D))			; ≝	Equal To By Definition
(char-name '|measeq| (integer->char #x0225E))			; ≞	Measured By
(char-name '|questeq| (integer->char #x0225F))			; ≟	Questioned Equal To
(char-name '|ne| (integer->char #x02260))			; ≠	Not Equal To
(char-name '|equiv| (integer->char #x02261))			; ≡	Identical To
(char-name '|nequiv| (integer->char #x02262))			; ≢	Not Identical To
(char-name '|Equiv| (integer->char #x02263))			; ≣	Strictly Equivalent To
(char-name '|le| (integer->char #x02264))			; ≤	Less-Than Or Equal To / Less Than Or Equal To
(char-name '|leq| (integer->char #x02264))			; ≤	Less-Than Or Equal To / Less Than Or Equal To
(char-name '|ge| (integer->char #x02265))			; ≥	Greater-Than Or Equal To / Greater Than Or Equal To
(char-name '|geq| (integer->char #x02265))			; ≥	Greater-Than Or Equal To / Greater Than Or Equal To
(char-name '|leqq| (integer->char #x02266))			; ≦	Less-Than Over Equal To / Less Than Over Equal To
(char-name '|geqq| (integer->char #x02267))			; ≧	Greater-Than Over Equal To / Greater Than Over Equal To
(char-name '|lneqq| (integer->char #x02268))			; ≨	Less-Than But Not Equal To / Less Than But Not Equal To
;(char-name '|lvertneqq|  U+02268 + U+0FE00)			; ≨︀	Less-Than But Not Equal To / Less Than But Not Equal To + Variation Selector-1
(char-name '|gneqq| (integer->char #x02269))			; ≩	Greater-Than But Not Equal To / Greater Than But Not Equal To
;(char-name '|gvertneqq|  U+02269 + U+0FE00)			; ≩︀	Greater-Than But Not Equal To / Greater Than But Not Equal To + Variation Selector-1
(char-name '|ll| (integer->char #x0226A))			; ≪	Much Less-Than / Much Less Than
;(char-name '|NotLessLess|  U+0226A + U+00338)			; ≪̸	Much Less-Than / Much Less Than + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|gg| (integer->char #x0226B))			; ≫	Much Greater-Than / Much Greater Than
;(char-name '|NotGreaterGreater|  U+0226B + U+00338)			; ≫̸	Much Greater-Than / Much Greater Than + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|between| (integer->char #x0226C))			; ≬	Between
(char-name '|nasymp| (integer->char #x0226D))			; ≭	Not Equivalent To
(char-name '|nless| (integer->char #x0226E))			; ≮	Not Less-Than / Not Less Than
(char-name '|ngtr| (integer->char #x0226F))			; ≯	Not Greater-Than / Not Greater Than
(char-name '|nleq| (integer->char #x02270))			; ≰	Neither Less-Than Nor Equal To / Neither Less Than Nor Equal To
(char-name '|ngeq| (integer->char #x02271))			; ≱	Neither Greater-Than Nor Equal To / Neither Greater Than Nor Equal To
(char-name '|lesssim| (integer->char #x02272))			; ≲	Less-Than Or Equivalent To / Less Than Or Equivalent To
(char-name '|gtrsim| (integer->char #x02273))			; ≳	Greater-Than Or Equivalent To / Greater Than Or Equivalent To
(char-name '|nlesssim| (integer->char #x02274))			; ≴	Neither Less-Than Nor Equivalent To / Neither Less Than Nor Equivalent To
(char-name '|ngtrsim| (integer->char #x02275))			; ≵	Neither Greater-Than Nor Equivalent To / Neither Greater Than Nor Equivalent To
(char-name '|lessgtr| (integer->char #x02276))			; ≶	Less-Than Or Greater-Than / Less Than Or Greater Than
(char-name '|gtrless| (integer->char #x02277))			; ≷	Greater-Than Or Less-Than / Greater Than Or Less Than
(char-name '|notlessgreater| (integer->char #x02278))			; ≸	Neither Less-Than Nor Greater-Than / Neither Less Than Nor Greater Than
(char-name '|notgreaterless| (integer->char #x02279))			; ≹	Neither Greater-Than Nor Less-Than / Neither Greater Than Nor Less Than
(char-name '|prec| (integer->char #x0227A))			; ≺	Precedes
(char-name '|succ| (integer->char #x0227B))			; ≻	Succeeds
(char-name '|preccurlyeq| (integer->char #x0227C))			; ≼	Precedes Or Equal To
(char-name '|succcurlyeq| (integer->char #x0227D))			; ≽	Succeeds Or Equal To
(char-name '|precsim| (integer->char #x0227E))			; ≾	Precedes Or Equivalent To
;(char-name '|nprecsim|  U+0227E + U+00338)			; ≾̸	Precedes Or Equivalent To + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|succsim| (integer->char #x0227F))			; ≿	Succeeds Or Equivalent To
;(char-name '|nsuccsim|  U+0227F + U+00338)			; ≿̸	Succeeds Or Equivalent To + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|nprec| (integer->char #x02280))			; ⊀	Does Not Precede
(char-name '|nsucc| (integer->char #x02281))			; ⊁	Does Not Succeed
(char-name '|subset| (integer->char #x02282))			; ⊂	Subset Of
(char-name '|supset| (integer->char #x02283))			; ⊃	Superset Of
(char-name '|nsubset| (integer->char #x02284))			; ⊄	Not A Subset Of
(char-name '|nsupset| (integer->char #x02285))			; ⊅	Not A Superset Of
(char-name '|subseteq| (integer->char #x02286))			; ⊆	Subset Of Or Equal To
(char-name '|supseteq| (integer->char #x02287))			; ⊇	Superset Of Or Equal To
(char-name '|nsubseteq| (integer->char #x02288))			; ⊈	Neither A Subset Of Nor Equal To
(char-name '|nsupseteq| (integer->char #x02289))			; ⊉	Neither A Superset Of Nor Equal To
(char-name '|subsetneq| (integer->char #x0228A))			; ⊊	Subset Of With Not Equal To / Subset Of Or Not Equal To
;(char-name '|varsubsetneqq|  U+0228A + U+0FE00)			; ⊊︀	Subset Of With Not Equal To / Subset Of Or Not Equal To + Variation Selector-1
(char-name '|supsetneq| (integer->char #x0228B))			; ⊋	Superset Of With Not Equal To / Superset Of Or Not Equal To
;(char-name '|varsupsetneq|  U+0228B + U+0FE00)			; ⊋︀	Superset Of With Not Equal To / Superset Of Or Not Equal To + Variation Selector-1
(char-name '|cupdot| (integer->char #x0228D))			; ⊍	Multiset Multiplication
(char-name '|uplus| (integer->char #x0228E))			; ⊎	Multiset Union
(char-name '|sqsubset| (integer->char #x0228F))			; ⊏	Square Image Of
;(char-name '|NotSquareSubset|  U+0228F + U+00338)			; ⊏̸	Square Image Of + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|sqsupset| (integer->char #x02290))			; ⊐	Square Original Of
;(char-name '|NotSquareSuperset|  U+02290 + U+00338)			; ⊐̸	Square Original Of + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|sqsubseteq| (integer->char #x02291))			; ⊑	Square Image Of Or Equal To
(char-name '|sqsupseteq| (integer->char #x02292))			; ⊒	Square Original Of Or Equal To
(char-name '|sqcap| (integer->char #x02293))			; ⊓	Square Cap
(char-name '|sqcup| (integer->char #x02294))			; ⊔	Square Cup
(char-name '|oplus| (integer->char #x02295))			; ⊕	Circled Plus
(char-name '|ominus| (integer->char #x02296))			; ⊖	Circled Minus
(char-name '|otimes| (integer->char #x02297))			; ⊗	Circled Times
(char-name '|oslash| (integer->char #x02298))			; ⊘	Circled Division Slash
(char-name '|odot| (integer->char #x02299))			; ⊙	Circled Dot Operator
(char-name '|circledcirc| (integer->char #x0229A))			; ⊚	Circled Ring Operator
(char-name '|circledast| (integer->char #x0229B))			; ⊛	Circled Asterisk Operator
(char-name '|circledequal| (integer->char #x0229C))			; ⊜	Circled Equals
(char-name '|circleddash| (integer->char #x0229D))			; ⊝	Circled Dash
(char-name '|boxplus| (integer->char #x0229E))			; ⊞	Squared Plus
(char-name '|boxminus| (integer->char #x0229F))			; ⊟	Squared Minus
(char-name '|boxtimes| (integer->char #x022A0))			; ⊠	Squared Times
(char-name '|boxdot| (integer->char #x022A1))			; ⊡	Squared Dot Operator
(char-name '|vdash| (integer->char #x022A2))			; ⊢	Right Tack
(char-name '|dashv| (integer->char #x022A3))			; ⊣	Left Tack
(char-name '|top| (integer->char #x022A4))			; ⊤	Down Tack
(char-name '|bot| (integer->char #x022A5))			; ⊥	Up Tack
(char-name '|models| (integer->char #x022A7))			; ⊧	Models
(char-name '|vDash| (integer->char #x022A8))			; ⊨	True
(char-name '|Vdash| (integer->char #x022A9))			; ⊩	Forces
(char-name '|Vvdash| (integer->char #x022AA))			; ⊪	Triple Vertical Bar Right Turnstile
(char-name '|VDash| (integer->char #x022AB))			; ⊫	Double Vertical Bar Double Right Turnstile
(char-name '|nvdash| (integer->char #x022AC))			; ⊬	Does Not Prove
(char-name '|nvDash| (integer->char #x022AD))			; ⊭	Not True
(char-name '|nVdash| (integer->char #x022AE))			; ⊮	Does Not Force
(char-name '|nVDash| (integer->char #x022AF))			; ⊯	Negated Double Vertical Bar Double Right Turnstile
(char-name '|prurel| (integer->char #x022B0))			; ⊰	Precedes Under Relation
(char-name '|scurel| (integer->char #x022B1))			; ⊱	Succeeds Under Relation
(char-name '|vartriangleleft| (integer->char #x022B2))			; ⊲	Normal Subgroup Of
(char-name '|vartriangleright| (integer->char #x022B3))			; ⊳	Contains As Normal Subgroup
(char-name '|trianglelefteq| (integer->char #x022B4))			; ⊴	Normal Subgroup Of Or Equal To
(char-name '|trianglerighteq| (integer->char #x022B5))			; ⊵	Contains As Normal Subgroup Or Equal To
(char-name '|original| (integer->char #x022B6))			; ⊶	Original Of
(char-name '|image| (integer->char #x022B7))			; ⊷	Image Of
(char-name '|multimap| (integer->char #x022B8))			; ⊸	Multimap
(char-name '|hermitconjmatrix| (integer->char #x022B9))			; ⊹	Hermitian Conjugate Matrix
(char-name '|intercal| (integer->char #x022BA))			; ⊺	Intercalate
(char-name '|veebar| (integer->char #x022BB))			; ⊻	Xor
(char-name '|xor| (integer->char #x022BB))			; ⊻	Xor
(char-name '|barwedge| (integer->char #x022BC))			; ⊼	Nand
(char-name '|barvee| (integer->char #x022BD))			; ⊽	Nor
(char-name '|rightanglearc| (integer->char #x022BE))			; ⊾	Right Angle With Arc
(char-name '|varlrtriangle| (integer->char #x022BF))			; ⊿	Right Triangle
(char-name '|bigwedge| (integer->char #x022C0))			; ⋀	N-Ary Logical And
(char-name '|bigvee| (integer->char #x022C1))			; ⋁	N-Ary Logical Or
(char-name '|bigcap| (integer->char #x022C2))			; ⋂	N-Ary Intersection
(char-name '|bigcup| (integer->char #x022C3))			; ⋃	N-Ary Union
(char-name '|diamond| (integer->char #x022C4))			; ⋄	Diamond Operator
(char-name '|cdot| (integer->char #x022C5))			; ⋅	Dot Operator
(char-name '|star| (integer->char #x022C6))			; ⋆	Star Operator
(char-name '|divideontimes| (integer->char #x022C7))			; ⋇	Division Times
(char-name '|bowtie| (integer->char #x022C8))			; ⋈	Bowtie
(char-name '|ltimes| (integer->char #x022C9))			; ⋉	Left Normal Factor Semidirect Product
(char-name '|rtimes| (integer->char #x022CA))			; ⋊	Right Normal Factor Semidirect Product
(char-name '|leftthreetimes| (integer->char #x022CB))			; ⋋	Left Semidirect Product
(char-name '|rightthreetimes| (integer->char #x022CC))			; ⋌	Right Semidirect Product
(char-name '|backsimeq| (integer->char #x022CD))			; ⋍	Reversed Tilde Equals
(char-name '|curlyvee| (integer->char #x022CE))			; ⋎	Curly Logical Or
(char-name '|curlywedge| (integer->char #x022CF))			; ⋏	Curly Logical And
(char-name '|Subset| (integer->char #x022D0))			; ⋐	Double Subset
(char-name '|Supset| (integer->char #x022D1))			; ⋑	Double Superset
(char-name '|Cap| (integer->char #x022D2))			; ⋒	Double Intersection
(char-name '|Cup| (integer->char #x022D3))			; ⋓	Double Union
(char-name '|pitchfork| (integer->char #x022D4))			; ⋔	Pitchfork
(char-name '|equalparallel| (integer->char #x022D5))			; ⋕	Equal And Parallel To
(char-name '|lessdot| (integer->char #x022D6))			; ⋖	Less-Than With Dot / Less Than With Dot
(char-name '|gtrdot| (integer->char #x022D7))			; ⋗	Greater-Than With Dot / Greater Than With Dot
(char-name '|verymuchless| (integer->char #x022D8))			; ⋘	Very Much Less-Than / Very Much Less Than
(char-name '|ggg| (integer->char #x022D9))			; ⋙	Very Much Greater-Than / Very Much Greater Than
(char-name '|lesseqgtr| (integer->char #x022DA))			; ⋚	Less-Than Equal To Or Greater-Than / Less Than Equal To Or Greater Than
(char-name '|gtreqless| (integer->char #x022DB))			; ⋛	Greater-Than Equal To Or Less-Than / Greater Than Equal To Or Less Than
(char-name '|eqless| (integer->char #x022DC))			; ⋜	Equal To Or Less-Than / Equal To Or Less Than
(char-name '|eqgtr| (integer->char #x022DD))			; ⋝	Equal To Or Greater-Than / Equal To Or Greater Than
(char-name '|curlyeqprec| (integer->char #x022DE))			; ⋞	Equal To Or Precedes
(char-name '|curlyeqsucc| (integer->char #x022DF))			; ⋟	Equal To Or Succeeds
(char-name '|npreccurlyeq| (integer->char #x022E0))			; ⋠	Does Not Precede Or Equal
(char-name '|nsucccurlyeq| (integer->char #x022E1))			; ⋡	Does Not Succeed Or Equal
(char-name '|nsqsubseteq| (integer->char #x022E2))			; ⋢	Not Square Image Of Or Equal To
(char-name '|nsqsupseteq| (integer->char #x022E3))			; ⋣	Not Square Original Of Or Equal To
(char-name '|sqsubsetneq| (integer->char #x022E4))			; ⋤	Square Image Of Or Not Equal To
(char-name '|sqspne| (integer->char #x022E5))			; ⋥	Square Original Of Or Not Equal To
(char-name '|lnsim| (integer->char #x022E6))			; ⋦	Less-Than But Not Equivalent To / Less Than But Not Equivalent To
(char-name '|gnsim| (integer->char #x022E7))			; ⋧	Greater-Than But Not Equivalent To / Greater Than But Not Equivalent To
(char-name '|precnsim| (integer->char #x022E8))			; ⋨	Precedes But Not Equivalent To
(char-name '|succnsim| (integer->char #x022E9))			; ⋩	Succeeds But Not Equivalent To
(char-name '|ntriangleleft| (integer->char #x022EA))			; ⋪	Not Normal Subgroup Of
(char-name '|ntriangleright| (integer->char #x022EB))			; ⋫	Does Not Contain As Normal Subgroup
(char-name '|ntrianglelefteq| (integer->char #x022EC))			; ⋬	Not Normal Subgroup Of Or Equal To
(char-name '|ntrianglerighteq| (integer->char #x022ED))			; ⋭	Does Not Contain As Normal Subgroup Or Equal
(char-name '|vdots| (integer->char #x022EE))			; ⋮	Vertical Ellipsis
(char-name '|cdots| (integer->char #x022EF))			; ⋯	Midline Horizontal Ellipsis
(char-name '|adots| (integer->char #x022F0))			; ⋰	Up Right Diagonal Ellipsis
(char-name '|ddots| (integer->char #x022F1))			; ⋱	Down Right Diagonal Ellipsis
(char-name '|disin| (integer->char #x022F2))			; ⋲	Element Of With Long Horizontal Stroke
(char-name '|varisins| (integer->char #x022F3))			; ⋳	Element Of With Vertical Bar At End Of Horizontal Stroke
(char-name '|isins| (integer->char #x022F4))			; ⋴	Small Element Of With Vertical Bar At End Of Horizontal Stroke
(char-name '|isindot| (integer->char #x022F5))			; ⋵	Element Of With Dot Above
(char-name '|varisinobar| (integer->char #x022F6))			; ⋶	Element Of With Overbar
(char-name '|isinobar| (integer->char #x022F7))			; ⋷	Small Element Of With Overbar
(char-name '|isinvb| (integer->char #x022F8))			; ⋸	Element Of With Underbar
(char-name '|isinE| (integer->char #x022F9))			; ⋹	Element Of With Two Horizontal Strokes
(char-name '|nisd| (integer->char #x022FA))			; ⋺	Contains With Long Horizontal Stroke
(char-name '|varnis| (integer->char #x022FB))			; ⋻	Contains With Vertical Bar At End Of Horizontal Stroke
(char-name '|nis| (integer->char #x022FC))			; ⋼	Small Contains With Vertical Bar At End Of Horizontal Stroke
(char-name '|varniobar| (integer->char #x022FD))			; ⋽	Contains With Overbar
(char-name '|niobar| (integer->char #x022FE))			; ⋾	Small Contains With Overbar
(char-name '|bagmember| (integer->char #x022FF))			; ⋿	Z Notation Bag Membership
(char-name '|diameter| (integer->char #x02300))			; ⌀	Diameter Sign
(char-name '|house| (integer->char #x02302))			; ⌂	House
(char-name '|varbarwedge| (integer->char #x02305))			; ⌅	Projective
(char-name '|vardoublebarwedge| (integer->char #x02306))			; ⌆	Perspective
(char-name '|lceil| (integer->char #x02308))			; ⌈	Left Ceiling
(char-name '|rceil| (integer->char #x02309))			; ⌉	Right Ceiling
(char-name '|lfloor| (integer->char #x0230A))			; ⌊	Left Floor
(char-name '|rfloor| (integer->char #x0230B))			; ⌋	Right Floor
(char-name '|invnot| (integer->char #x02310))			; ⌐	Reversed Not Sign
(char-name '|sqlozenge| (integer->char #x02311))			; ⌑	Square Lozenge
(char-name '|profline| (integer->char #x02312))			; ⌒	Arc
(char-name '|profsurf| (integer->char #x02313))			; ⌓	Segment
(char-name '|recorder| (integer->char #x02315))			; ⌕	Telephone Recorder
(char-name '|viewdata| (integer->char #x02317))			; ⌗	Viewdata Square
(char-name '|turnednot| (integer->char #x02319))			; ⌙	Turned Not Sign
(char-name '|:watch:| (integer->char #x0231A))			; ⌚	Watch
(char-name '|:hourglass:| (integer->char #x0231B))			; ⌛	Hourglass
(char-name '|ulcorner| (integer->char #x0231C))			; ⌜	Top Left Corner
(char-name '|urcorner| (integer->char #x0231D))			; ⌝	Top Right Corner
(char-name '|llcorner| (integer->char #x0231E))			; ⌞	Bottom Left Corner
(char-name '|lrcorner| (integer->char #x0231F))			; ⌟	Bottom Right Corner
(char-name '|frown| (integer->char #x02322))			; ⌢	Frown
(char-name '|smile| (integer->char #x02323))			; ⌣	Smile
(char-name '|varhexagonlrbonds| (integer->char #x0232C))			; ⌬	Benzene Ring
(char-name '|conictaper| (integer->char #x02332))			; ⌲	Conical Taper
(char-name '|topbot| (integer->char #x02336))			; ⌶	Apl Functional Symbol I-Beam
(char-name '|obar| (integer->char #x0233D))			; ⌽	Apl Functional Symbol Circle Stile
(char-name '|notslash| (integer->char #x0233F))			; ⌿	Apl Functional Symbol Slash Bar
(char-name '|notbackslash| (integer->char #x02340))			; ⍀	Apl Functional Symbol Backslash Bar
(char-name '|boxupcaret| (integer->char #x02353))			; ⍓	Apl Functional Symbol Quad Up Caret
(char-name '|boxquestion| (integer->char #x02370))			; ⍰	Apl Functional Symbol Quad Question
(char-name '|hexagon| (integer->char #x02394))			; ⎔	Software-Function Symbol
(char-name '|dlcorn| (integer->char #x023A3))			; ⎣	Left Square Bracket Lower Corner
(char-name '|lmoustache| (integer->char #x023B0))			; ⎰	Upper Left Or Lower Right Curly Bracket Section
(char-name '|rmoustache| (integer->char #x023B1))			; ⎱	Upper Right Or Lower Left Curly Bracket Section
(char-name '|overbracket| (integer->char #x023B4))			; ⎴	Top Square Bracket
(char-name '|underbracket| (integer->char #x023B5))			; ⎵	Bottom Square Bracket
(char-name '|bbrktbrk| (integer->char #x023B6))			; ⎶	Bottom Square Bracket Over Top Square Bracket
(char-name '|sqrtbottom| (integer->char #x023B7))			; ⎷	Radical Symbol Bottom
(char-name '|lvboxline| (integer->char #x023B8))			; ⎸	Left Vertical Box Line
(char-name '|rvboxline| (integer->char #x023B9))			; ⎹	Right Vertical Box Line
(char-name '|varcarriagereturn| (integer->char #x023CE))			; ⏎	Return Symbol
(char-name '|overbrace| (integer->char #x023DE))			; ⏞	Top Curly Bracket
(char-name '|underbrace| (integer->char #x023DF))			; ⏟	Bottom Curly Bracket
(char-name '|trapezium| (integer->char #x023E2))			; ⏢	White Trapezium
(char-name '|benzenr| (integer->char #x023E3))			; ⏣	Benzene Ring With Circle
(char-name '|strns| (integer->char #x023E4))			; ⏤	Straightness
(char-name '|fltns| (integer->char #x023E5))			; ⏥	Flatness
(char-name '|accurrent| (integer->char #x023E6))			; ⏦	Ac Current
(char-name '|elinters| (integer->char #x023E7))			; ⏧	Electrical Intersection
(char-name '|:fast_forward:| (integer->char #x023E9))			; ⏩	Black Right-Pointing Double Triangle
(char-name '|:rewind:| (integer->char #x023EA))			; ⏪	Black Left-Pointing Double Triangle
(char-name '|:arrow_double_up:| (integer->char #x023EB))			; ⏫	Black Up-Pointing Double Triangle
(char-name '|:arrow_double_down:| (integer->char #x023EC))			; ⏬	Black Down-Pointing Double Triangle
(char-name '|:alarm_clock:| (integer->char #x023F0))			; ⏰	Alarm Clock
(char-name '|:hourglass_flowing_sand:| (integer->char #x023F3))			; ⏳	Hourglass With Flowing Sand
(char-name '|blanksymbol| (integer->char #x02422))			; ␢	Blank Symbol / Blank
(char-name '|visiblespace| (integer->char #x02423))			; ␣	Open Box
(char-name '|:m:| (integer->char #x024C2))			; Ⓜ	Circled Latin Capital Letter M
(char-name '|circledS| (integer->char #x024C8))			; Ⓢ	Circled Latin Capital Letter S
(char-name '|dshfnc| (integer->char #x02506))			; ┆	Box Drawings Light Triple Dash Vertical / Forms Light Triple Dash Vertical
(char-name '|sqfnw| (integer->char #x02519))			; ┙	Box Drawings Up Light And Left Heavy / Forms Up Light And Left Heavy
(char-name '|diagup| (integer->char #x02571))			; ╱	Box Drawings Light Diagonal Upper Right To Lower Left / Forms Light Diagonal Upper Right To Lower Left
(char-name '|diagdown| (integer->char #x02572))			; ╲	Box Drawings Light Diagonal Upper Left To Lower Right / Forms Light Diagonal Upper Left To Lower Right
(char-name '|blockuphalf| (integer->char #x02580))			; ▀	Upper Half Block
(char-name '|blocklowhalf| (integer->char #x02584))			; ▄	Lower Half Block
(char-name '|blockfull| (integer->char #x02588))			; █	Full Block
(char-name '|blocklefthalf| (integer->char #x0258C))			; ▌	Left Half Block
(char-name '|blockrighthalf| (integer->char #x02590))			; ▐	Right Half Block
(char-name '|blockqtrshaded| (integer->char #x02591))			; ░	Light Shade
(char-name '|blockhalfshaded| (integer->char #x02592))			; ▒	Medium Shade
(char-name '|blockthreeqtrshaded| (integer->char #x02593))			; ▓	Dark Shade
(char-name '|blacksquare| (integer->char #x025A0))			; ■	Black Square
(char-name '|square| (integer->char #x025A1))			; □	White Square
(char-name '|squoval| (integer->char #x025A2))			; ▢	White Square With Rounded Corners
(char-name '|blackinwhitesquare| (integer->char #x025A3))			; ▣	White Square Containing Black Small Square
(char-name '|squarehfill| (integer->char #x025A4))			; ▤	Square With Horizontal Fill
(char-name '|squarevfill| (integer->char #x025A5))			; ▥	Square With Vertical Fill
(char-name '|squarehvfill| (integer->char #x025A6))			; ▦	Square With Orthogonal Crosshatch Fill
(char-name '|squarenwsefill| (integer->char #x025A7))			; ▧	Square With Upper Left To Lower Right Fill
(char-name '|squareneswfill| (integer->char #x025A8))			; ▨	Square With Upper Right To Lower Left Fill
(char-name '|squarecrossfill| (integer->char #x025A9))			; ▩	Square With Diagonal Crosshatch Fill
(char-name '|smblksquare| (integer->char #x025AA))			; ▪	Black Small Square
(char-name '|:black_small_square:| (integer->char #x025AA))			; ▪	Black Small Square
(char-name '|smwhtsquare| (integer->char #x025AB))			; ▫	White Small Square
(char-name '|:white_small_square:| (integer->char #x025AB))			; ▫	White Small Square
(char-name '|hrectangleblack| (integer->char #x025AC))			; ▬	Black Rectangle
(char-name '|hrectangle| (integer->char #x025AD))			; ▭	White Rectangle
(char-name '|vrectangleblack| (integer->char #x025AE))			; ▮	Black Vertical Rectangle
(char-name '|vrecto| (integer->char #x025AF))			; ▯	White Vertical Rectangle
(char-name '|parallelogramblack| (integer->char #x025B0))			; ▰	Black Parallelogram
(char-name '|parallelogram| (integer->char #x025B1))			; ▱	White Parallelogram
(char-name '|bigblacktriangleup| (integer->char #x025B2))			; ▲	Black Up-Pointing Triangle / Black Up Pointing Triangle
(char-name '|bigtriangleup| (integer->char #x025B3))			; △	White Up-Pointing Triangle / White Up Pointing Triangle
(char-name '|blacktriangle| (integer->char #x025B4))			; ▴	Black Up-Pointing Small Triangle / Black Up Pointing Small Triangle
(char-name '|vartriangle| (integer->char #x025B5))			; ▵	White Up-Pointing Small Triangle / White Up Pointing Small Triangle
(char-name '|blacktriangleright| (integer->char #x025B6))			; ▶	Black Right-Pointing Triangle / Black Right Pointing Triangle
(char-name '|:arrow_forward:| (integer->char #x025B6))			; ▶	Black Right-Pointing Triangle / Black Right Pointing Triangle
(char-name '|triangleright| (integer->char #x025B7))			; ▷	White Right-Pointing Triangle / White Right Pointing Triangle
(char-name '|smallblacktriangleright| (integer->char #x025B8))			; ▸	Black Right-Pointing Small Triangle / Black Right Pointing Small Triangle
(char-name '|smalltriangleright| (integer->char #x025B9))			; ▹	White Right-Pointing Small Triangle / White Right Pointing Small Triangle
(char-name '|blackpointerright| (integer->char #x025BA))			; ►	Black Right-Pointing Pointer / Black Right Pointing Pointer
(char-name '|whitepointerright| (integer->char #x025BB))			; ▻	White Right-Pointing Pointer / White Right Pointing Pointer
(char-name '|bigblacktriangledown| (integer->char #x025BC))			; ▼	Black Down-Pointing Triangle / Black Down Pointing Triangle
(char-name '|bigtriangledown| (integer->char #x025BD))			; ▽	White Down-Pointing Triangle / White Down Pointing Triangle
(char-name '|blacktriangledown| (integer->char #x025BE))			; ▾	Black Down-Pointing Small Triangle / Black Down Pointing Small Triangle
(char-name '|triangledown| (integer->char #x025BF))			; ▿	White Down-Pointing Small Triangle / White Down Pointing Small Triangle
(char-name '|blacktriangleleft| (integer->char #x025C0))			; ◀	Black Left-Pointing Triangle / Black Left Pointing Triangle
(char-name '|:arrow_backward:| (integer->char #x025C0))			; ◀	Black Left-Pointing Triangle / Black Left Pointing Triangle
(char-name '|triangleleft| (integer->char #x025C1))			; ◁	White Left-Pointing Triangle / White Left Pointing Triangle
(char-name '|smallblacktriangleleft| (integer->char #x025C2))			; ◂	Black Left-Pointing Small Triangle / Black Left Pointing Small Triangle
(char-name '|smalltriangleleft| (integer->char #x025C3))			; ◃	White Left-Pointing Small Triangle / White Left Pointing Small Triangle
(char-name '|blackpointerleft| (integer->char #x025C4))			; ◄	Black Left-Pointing Pointer / Black Left Pointing Pointer
(char-name '|whitepointerleft| (integer->char #x025C5))			; ◅	White Left-Pointing Pointer / White Left Pointing Pointer
(char-name '|mdlgblkdiamond| (integer->char #x025C6))			; ◆	Black Diamond
(char-name '|mdlgwhtdiamond| (integer->char #x025C7))			; ◇	White Diamond
(char-name '|blackinwhitediamond| (integer->char #x025C8))			; ◈	White Diamond Containing Black Small Diamond
(char-name '|fisheye| (integer->char #x025C9))			; ◉	Fisheye
(char-name '|lozenge| (integer->char #x025CA))			; ◊	Lozenge
(char-name '|bigcirc| (integer->char #x025CB))			; ○	White Circle
(char-name '|dottedcircle| (integer->char #x025CC))			; ◌	Dotted Circle
(char-name '|circlevertfill| (integer->char #x025CD))			; ◍	Circle With Vertical Fill
(char-name '|bullseye| (integer->char #x025CE))			; ◎	Bullseye
(char-name '|mdlgblkcircle| (integer->char #x025CF))			; ●	Black Circle
(char-name '|cirfl| (integer->char #x025D0))			; ◐	Circle With Left Half Black
(char-name '|cirfr| (integer->char #x025D1))			; ◑	Circle With Right Half Black
(char-name '|cirfb| (integer->char #x025D2))			; ◒	Circle With Lower Half Black
(char-name '|circletophalfblack| (integer->char #x025D3))			; ◓	Circle With Upper Half Black
(char-name '|circleurquadblack| (integer->char #x025D4))			; ◔	Circle With Upper Right Quadrant Black
(char-name '|blackcircleulquadwhite| (integer->char #x025D5))			; ◕	Circle With All But Upper Left Quadrant Black
(char-name '|blacklefthalfcircle| (integer->char #x025D6))			; ◖	Left Half Black Circle
(char-name '|blackrighthalfcircle| (integer->char #x025D7))			; ◗	Right Half Black Circle
(char-name '|rvbull| (integer->char #x025D8))			; ◘	Inverse Bullet
(char-name '|inversewhitecircle| (integer->char #x025D9))			; ◙	Inverse White Circle
(char-name '|invwhiteupperhalfcircle| (integer->char #x025DA))			; ◚	Upper Half Inverse White Circle
(char-name '|invwhitelowerhalfcircle| (integer->char #x025DB))			; ◛	Lower Half Inverse White Circle
(char-name '|ularc| (integer->char #x025DC))			; ◜	Upper Left Quadrant Circular Arc
(char-name '|urarc| (integer->char #x025DD))			; ◝	Upper Right Quadrant Circular Arc
(char-name '|lrarc| (integer->char #x025DE))			; ◞	Lower Right Quadrant Circular Arc
(char-name '|llarc| (integer->char #x025DF))			; ◟	Lower Left Quadrant Circular Arc
(char-name '|topsemicircle| (integer->char #x025E0))			; ◠	Upper Half Circle
(char-name '|botsemicircle| (integer->char #x025E1))			; ◡	Lower Half Circle
(char-name '|lrblacktriangle| (integer->char #x025E2))			; ◢	Black Lower Right Triangle
(char-name '|llblacktriangle| (integer->char #x025E3))			; ◣	Black Lower Left Triangle
(char-name '|ulblacktriangle| (integer->char #x025E4))			; ◤	Black Upper Left Triangle
(char-name '|urblacktriangle| (integer->char #x025E5))			; ◥	Black Upper Right Triangle
(char-name '|smwhtcircle| (integer->char #x025E6))			; ◦	White Bullet
(char-name '|sqfl| (integer->char #x025E7))			; ◧	Square With Left Half Black
(char-name '|sqfr| (integer->char #x025E8))			; ◨	Square With Right Half Black
(char-name '|squareulblack| (integer->char #x025E9))			; ◩	Square With Upper Left Diagonal Half Black
(char-name '|sqfse| (integer->char #x025EA))			; ◪	Square With Lower Right Diagonal Half Black
(char-name '|boxbar| (integer->char #x025EB))			; ◫	White Square With Vertical Bisecting Line
(char-name '|trianglecdot| (integer->char #x025EC))			; ◬	White Up-Pointing Triangle With Dot / White Up Pointing Triangle With Dot
(char-name '|triangleleftblack| (integer->char #x025ED))			; ◭	Up-Pointing Triangle With Left Half Black / Up Pointing Triangle With Left Half Black
(char-name '|trianglerightblack| (integer->char #x025EE))			; ◮	Up-Pointing Triangle With Right Half Black / Up Pointing Triangle With Right Half Black
(char-name '|lgwhtcircle| (integer->char #x025EF))			; ◯	Large Circle
(char-name '|squareulquad| (integer->char #x025F0))			; ◰	White Square With Upper Left Quadrant
(char-name '|squarellquad| (integer->char #x025F1))			; ◱	White Square With Lower Left Quadrant
(char-name '|squarelrquad| (integer->char #x025F2))			; ◲	White Square With Lower Right Quadrant
(char-name '|squareurquad| (integer->char #x025F3))			; ◳	White Square With Upper Right Quadrant
(char-name '|circleulquad| (integer->char #x025F4))			; ◴	White Circle With Upper Left Quadrant
(char-name '|circlellquad| (integer->char #x025F5))			; ◵	White Circle With Lower Left Quadrant
(char-name '|circlelrquad| (integer->char #x025F6))			; ◶	White Circle With Lower Right Quadrant
(char-name '|circleurquad| (integer->char #x025F7))			; ◷	White Circle With Upper Right Quadrant
(char-name '|ultriangle| (integer->char #x025F8))			; ◸	Upper Left Triangle
(char-name '|urtriangle| (integer->char #x025F9))			; ◹	Upper Right Triangle
(char-name '|lltriangle| (integer->char #x025FA))			; ◺	Lower Left Triangle
(char-name '|mdwhtsquare| (integer->char #x025FB))			; ◻	White Medium Square
(char-name '|:white_medium_square:| (integer->char #x025FB))			; ◻	White Medium Square
(char-name '|mdblksquare| (integer->char #x025FC))			; ◼	Black Medium Square
(char-name '|:black_medium_square:| (integer->char #x025FC))			; ◼	Black Medium Square
(char-name '|mdsmwhtsquare| (integer->char #x025FD))			; ◽	White Medium Small Square
(char-name '|:white_medium_small_square:| (integer->char #x025FD))			; ◽	White Medium Small Square
(char-name '|mdsmblksquare| (integer->char #x025FE))			; ◾	Black Medium Small Square
(char-name '|:black_medium_small_square:| (integer->char #x025FE))			; ◾	Black Medium Small Square
(char-name '|lrtriangle| (integer->char #x025FF))			; ◿	Lower Right Triangle
(char-name '|:sunny:| (integer->char #x02600))			; ☀	Black Sun With Rays
(char-name '|:cloud:| (integer->char #x02601))			; ☁	Cloud
(char-name '|bigstar| (integer->char #x02605))			; ★	Black Star
(char-name '|bigwhitestar| (integer->char #x02606))			; ☆	White Star
(char-name '|astrosun| (integer->char #x02609))			; ☉	Sun
(char-name '|:phone:| (integer->char #x0260E))			; ☎	Black Telephone
(char-name '|:ballot_box_with_check:| (integer->char #x02611))			; ☑	Ballot Box With Check
(char-name '|:umbrella:| (integer->char #x02614))			; ☔	Umbrella With Rain Drops
(char-name '|:coffee:| (integer->char #x02615))			; ☕	Hot Beverage
(char-name '|:point_up:| (integer->char #x0261D))			; ☝	White Up Pointing Index
(char-name '|danger| (integer->char #x02621))			; ☡	Caution Sign
(char-name '|:relaxed:| (integer->char #x0263A))			; ☺	White Smiling Face
(char-name '|blacksmiley| (integer->char #x0263B))			; ☻	Black Smiling Face
(char-name '|sun| (integer->char #x0263C))			; ☼	White Sun With Rays
(char-name '|rightmoon| (integer->char #x0263D))			; ☽	First Quarter Moon
(char-name '|leftmoon| (integer->char #x0263E))			; ☾	Last Quarter Moon
(char-name '|mercury| (integer->char #x0263F))			; ☿	Mercury
(char-name '|venus| (integer->char #x02640))			; ♀	Female Sign
(char-name '|female| (integer->char #x02640))			; ♀	Female Sign
(char-name '|male| (integer->char #x02642))			; ♂	Male Sign
(char-name '|mars| (integer->char #x02642))			; ♂	Male Sign
(char-name '|jupiter| (integer->char #x02643))			; ♃	Jupiter
(char-name '|saturn| (integer->char #x02644))			; ♄	Saturn
(char-name '|uranus| (integer->char #x02645))			; ♅	Uranus
(char-name '|neptune| (integer->char #x02646))			; ♆	Neptune
(char-name '|pluto| (integer->char #x02647))			; ♇	Pluto
(char-name '|aries| (integer->char #x02648))			; ♈	Aries
(char-name '|:aries:| (integer->char #x02648))			; ♈	Aries
(char-name '|taurus| (integer->char #x02649))			; ♉	Taurus
(char-name '|:taurus:| (integer->char #x02649))			; ♉	Taurus
(char-name '|gemini| (integer->char #x0264A))			; ♊	Gemini
(char-name '|:gemini:| (integer->char #x0264A))			; ♊	Gemini
(char-name '|cancer| (integer->char #x0264B))			; ♋	Cancer
(char-name '|:cancer:| (integer->char #x0264B))			; ♋	Cancer
(char-name '|leo| (integer->char #x0264C))			; ♌	Leo
(char-name '|:leo:| (integer->char #x0264C))			; ♌	Leo
(char-name '|virgo| (integer->char #x0264D))			; ♍	Virgo
(char-name '|:virgo:| (integer->char #x0264D))			; ♍	Virgo
(char-name '|libra| (integer->char #x0264E))			; ♎	Libra
(char-name '|:libra:| (integer->char #x0264E))			; ♎	Libra
(char-name '|scorpio| (integer->char #x0264F))			; ♏	Scorpius
(char-name '|:scorpius:| (integer->char #x0264F))			; ♏	Scorpius
(char-name '|sagittarius| (integer->char #x02650))			; ♐	Sagittarius
(char-name '|:sagittarius:| (integer->char #x02650))			; ♐	Sagittarius
(char-name '|capricornus| (integer->char #x02651))			; ♑	Capricorn
(char-name '|:capricorn:| (integer->char #x02651))			; ♑	Capricorn
(char-name '|aquarius| (integer->char #x02652))			; ♒	Aquarius
(char-name '|:aquarius:| (integer->char #x02652))			; ♒	Aquarius
(char-name '|pisces| (integer->char #x02653))			; ♓	Pisces
(char-name '|:pisces:| (integer->char #x02653))			; ♓	Pisces
(char-name '|spadesuit| (integer->char #x02660))			; ♠	Black Spade Suit
(char-name '|:spades:| (integer->char #x02660))			; ♠	Black Spade Suit
(char-name '|heartsuit| (integer->char #x02661))			; ♡	White Heart Suit
(char-name '|diamondsuit| (integer->char #x02662))			; ♢	White Diamond Suit
(char-name '|clubsuit| (integer->char #x02663))			; ♣	Black Club Suit
(char-name '|:clubs:| (integer->char #x02663))			; ♣	Black Club Suit
(char-name '|varspadesuit| (integer->char #x02664))			; ♤	White Spade Suit
(char-name '|varheartsuit| (integer->char #x02665))			; ♥	Black Heart Suit
(char-name '|:hearts:| (integer->char #x02665))			; ♥	Black Heart Suit
(char-name '|vardiamondsuit| (integer->char #x02666))			; ♦	Black Diamond Suit
(char-name '|:diamonds:| (integer->char #x02666))			; ♦	Black Diamond Suit
(char-name '|varclubsuit| (integer->char #x02667))			; ♧	White Club Suit
(char-name '|:hotsprings:| (integer->char #x02668))			; ♨	Hot Springs
(char-name '|quarternote| (integer->char #x02669))			; ♩	Quarter Note
(char-name '|eighthnote| (integer->char #x0266A))			; ♪	Eighth Note
(char-name '|twonotes| (integer->char #x0266B))			; ♫	Beamed Eighth Notes / Barred Eighth Notes
(char-name '|flat| (integer->char #x0266D))			; ♭	Music Flat Sign / Flat
(char-name '|natural| (integer->char #x0266E))			; ♮	Music Natural Sign / Natural
(char-name '|sharp| (integer->char #x0266F))			; ♯	Music Sharp Sign / Sharp
(char-name '|:recycle:| (integer->char #x0267B))			; ♻	Black Universal Recycling Symbol
(char-name '|acidfree| (integer->char #x0267E))			; ♾	Permanent Paper Sign
(char-name '|:wheelchair:| (integer->char #x0267F))			; ♿	Wheelchair Symbol
(char-name '|dicei| (integer->char #x02680))			; ⚀	Die Face-1
(char-name '|diceii| (integer->char #x02681))			; ⚁	Die Face-2
(char-name '|diceiii| (integer->char #x02682))			; ⚂	Die Face-3
(char-name '|diceiv| (integer->char #x02683))			; ⚃	Die Face-4
(char-name '|dicev| (integer->char #x02684))			; ⚄	Die Face-5
(char-name '|dicevi| (integer->char #x02685))			; ⚅	Die Face-6
(char-name '|circledrightdot| (integer->char #x02686))			; ⚆	White Circle With Dot Right
(char-name '|circledtwodots| (integer->char #x02687))			; ⚇	White Circle With Two Dots
(char-name '|blackcircledrightdot| (integer->char #x02688))			; ⚈	Black Circle With White Dot Right
(char-name '|blackcircledtwodots| (integer->char #x02689))			; ⚉	Black Circle With Two White Dots
(char-name '|:anchor:| (integer->char #x02693))			; ⚓	Anchor
(char-name '|:warning:| (integer->char #x026A0))			; ⚠	Warning Sign
(char-name '|:zap:| (integer->char #x026A1))			; ⚡	High Voltage Sign
(char-name '|hermaphrodite| (integer->char #x026A5))			; ⚥	Male And Female Sign
(char-name '|mdwhtcircle| (integer->char #x026AA))			; ⚪	Medium White Circle
(char-name '|:white_circle:| (integer->char #x026AA))			; ⚪	Medium White Circle
(char-name '|mdblkcircle| (integer->char #x026AB))			; ⚫	Medium Black Circle
(char-name '|:black_circle:| (integer->char #x026AB))			; ⚫	Medium Black Circle
(char-name '|mdsmwhtcircle| (integer->char #x026AC))			; ⚬	Medium Small White Circle
(char-name '|neuter| (integer->char #x026B2))			; ⚲	Neuter
(char-name '|:soccer:| (integer->char #x026BD))			; ⚽	Soccer Ball
(char-name '|:baseball:| (integer->char #x026BE))			; ⚾	Baseball
(char-name '|:snowman:| (integer->char #x026C4))			; ⛄	Snowman Without Snow
(char-name '|:partly_sunny:| (integer->char #x026C5))			; ⛅	Sun Behind Cloud
(char-name '|:ophiuchus:| (integer->char #x026CE))			; ⛎	Ophiuchus
(char-name '|:no_entry:| (integer->char #x026D4))			; ⛔	No Entry
(char-name '|:church:| (integer->char #x026EA))			; ⛪	Church
(char-name '|:fountain:| (integer->char #x026F2))			; ⛲	Fountain
(char-name '|:golf:| (integer->char #x026F3))			; ⛳	Flag In Hole
(char-name '|:boat:| (integer->char #x026F5))			; ⛵	Sailboat
(char-name '|:tent:| (integer->char #x026FA))			; ⛺	Tent
(char-name '|:fuelpump:| (integer->char #x026FD))			; ⛽	Fuel Pump
(char-name '|:scissors:| (integer->char #x02702))			; ✂	Black Scissors
(char-name '|:white_check_mark:| (integer->char #x02705))			; ✅	White Heavy Check Mark
(char-name '|:airplane:| (integer->char #x02708))			; ✈	Airplane
(char-name '|:email:| (integer->char #x02709))			; ✉	Envelope
(char-name '|:fist:| (integer->char #x0270A))			; ✊	Raised Fist
(char-name '|:hand:| (integer->char #x0270B))			; ✋	Raised Hand
(char-name '|:v:| (integer->char #x0270C))			; ✌	Victory Hand
(char-name '|:pencil2:| (integer->char #x0270F))			; ✏	Pencil
(char-name '|:black_nib:| (integer->char #x02712))			; ✒	Black Nib
(char-name '|checkmark| (integer->char #x02713))			; ✓	Check Mark
(char-name '|:heavy_check_mark:| (integer->char #x02714))			; ✔	Heavy Check Mark
(char-name '|:heavy_multiplication_x:| (integer->char #x02716))			; ✖	Heavy Multiplication X
(char-name '|maltese| (integer->char #x02720))			; ✠	Maltese Cross
(char-name '|:sparkles:| (integer->char #x02728))			; ✨	Sparkles
(char-name '|circledstar| (integer->char #x0272A))			; ✪	Circled White Star
(char-name '|:eight_spoked_asterisk:| (integer->char #x02733))			; ✳	Eight Spoked Asterisk
(char-name '|:eight_pointed_black_star:| (integer->char #x02734))			; ✴	Eight Pointed Black Star
(char-name '|varstar| (integer->char #x02736))			; ✶	Six Pointed Black Star
(char-name '|dingasterisk| (integer->char #x0273D))			; ✽	Heavy Teardrop-Spoked Asterisk
(char-name '|:snowflake:| (integer->char #x02744))			; ❄	Snowflake
(char-name '|:sparkle:| (integer->char #x02747))			; ❇	Sparkle
(char-name '|:x:| (integer->char #x0274C))			; ❌	Cross Mark
(char-name '|:negative_squared_cross_mark:| (integer->char #x0274E))			; ❎	Negative Squared Cross Mark
(char-name '|:question:| (integer->char #x02753))			; ❓	Black Question Mark Ornament
(char-name '|:grey_question:| (integer->char #x02754))			; ❔	White Question Mark Ornament
(char-name '|:grey_exclamation:| (integer->char #x02755))			; ❕	White Exclamation Mark Ornament
(char-name '|:exclamation:| (integer->char #x02757))			; ❗	Heavy Exclamation Mark Symbol
(char-name '|:heart:| (integer->char #x02764))			; ❤	Heavy Black Heart
(char-name '|:heavy_plus_sign:| (integer->char #x02795))			; ➕	Heavy Plus Sign
(char-name '|:heavy_minus_sign:| (integer->char #x02796))			; ➖	Heavy Minus Sign
(char-name '|:heavy_division_sign:| (integer->char #x02797))			; ➗	Heavy Division Sign
(char-name '|draftingarrow| (integer->char #x0279B))			; ➛	Drafting Point Rightwards Arrow / Drafting Point Right Arrow
(char-name '|:arrow_right:| (integer->char #x027A1))			; ➡	Black Rightwards Arrow / Black Right Arrow
(char-name '|:curly_loop:| (integer->char #x027B0))			; ➰	Curly Loop
(char-name '|:loop:| (integer->char #x027BF))			; ➿	Double Curly Loop
(char-name '|threedangle| (integer->char #x027C0))			; ⟀	Three Dimensional Angle
(char-name '|whiteinwhitetriangle| (integer->char #x027C1))			; ⟁	White Triangle Containing Small White Triangle
(char-name '|perp| (integer->char #x027C2))			; ⟂	Perpendicular
(char-name '|bsolhsub| (integer->char #x027C8))			; ⟈	Reverse Solidus Preceding Subset
(char-name '|suphsol| (integer->char #x027C9))			; ⟉	Superset Preceding Solidus
(char-name '|wedgedot| (integer->char #x027D1))			; ⟑	And With Dot
(char-name '|upin| (integer->char #x027D2))			; ⟒	Element Of Opening Upwards
(char-name '|leftouterjoin| (integer->char #x027D5))			; ⟕	Left Outer Join
(char-name '|rightouterjoin| (integer->char #x027D6))			; ⟖	Right Outer Join
(char-name '|fullouterjoin| (integer->char #x027D7))			; ⟗	Full Outer Join
(char-name '|bigbot| (integer->char #x027D8))			; ⟘	Large Up Tack
(char-name '|bigtop| (integer->char #x027D9))			; ⟙	Large Down Tack
(char-name '|llbracket| (integer->char #x027E6))			; ⟦	Mathematical Left White Square Bracket
(char-name '|openbracketleft| (integer->char #x027E6))			; ⟦	Mathematical Left White Square Bracket
(char-name '|openbracketright| (integer->char #x027E7))			; ⟧	Mathematical Right White Square Bracket
(char-name '|rrbracket| (integer->char #x027E7))			; ⟧	Mathematical Right White Square Bracket
(char-name '|langle| (integer->char #x027E8))			; ⟨	Mathematical Left Angle Bracket
(char-name '|rangle| (integer->char #x027E9))			; ⟩	Mathematical Right Angle Bracket
(char-name '|UUparrow| (integer->char #x027F0))			; ⟰	Upwards Quadruple Arrow
(char-name '|DDownarrow| (integer->char #x027F1))			; ⟱	Downwards Quadruple Arrow
(char-name '|longleftarrow| (integer->char #x027F5))			; ⟵	Long Leftwards Arrow
(char-name '|longrightarrow| (integer->char #x027F6))			; ⟶	Long Rightwards Arrow
(char-name '|longleftrightarrow| (integer->char #x027F7))			; ⟷	Long Left Right Arrow
(char-name '|impliedby| (integer->char #x027F8))			; ⟸	Long Leftwards Double Arrow
(char-name '|Longleftarrow| (integer->char #x027F8))			; ⟸	Long Leftwards Double Arrow
(char-name '|implies| (integer->char #x027F9))			; ⟹	Long Rightwards Double Arrow
(char-name '|Longrightarrow| (integer->char #x027F9))			; ⟹	Long Rightwards Double Arrow
(char-name '|Longleftrightarrow| (integer->char #x027FA))			; ⟺	Long Left Right Double Arrow
(char-name '|iff| (integer->char #x027FA))			; ⟺	Long Left Right Double Arrow
(char-name '|longmapsfrom| (integer->char #x027FB))			; ⟻	Long Leftwards Arrow From Bar
(char-name '|longmapsto| (integer->char #x027FC))			; ⟼	Long Rightwards Arrow From Bar
(char-name '|Longmapsfrom| (integer->char #x027FD))			; ⟽	Long Leftwards Double Arrow From Bar
(char-name '|Longmapsto| (integer->char #x027FE))			; ⟾	Long Rightwards Double Arrow From Bar
(char-name '|longrightsquigarrow| (integer->char #x027FF))			; ⟿	Long Rightwards Squiggle Arrow
(char-name '|nvtwoheadrightarrow| (integer->char #x02900))			; ⤀	Rightwards Two-Headed Arrow With Vertical Stroke
(char-name '|nVtwoheadrightarrow| (integer->char #x02901))			; ⤁	Rightwards Two-Headed Arrow With Double Vertical Stroke
(char-name '|nvLeftarrow| (integer->char #x02902))			; ⤂	Leftwards Double Arrow With Vertical Stroke
(char-name '|nvRightarrow| (integer->char #x02903))			; ⤃	Rightwards Double Arrow With Vertical Stroke
(char-name '|nvLeftrightarrow| (integer->char #x02904))			; ⤄	Left Right Double Arrow With Vertical Stroke
(char-name '|twoheadmapsto| (integer->char #x02905))			; ⤅	Rightwards Two-Headed Arrow From Bar
(char-name '|Mapsfrom| (integer->char #x02906))			; ⤆	Leftwards Double Arrow From Bar
(char-name '|Mapsto| (integer->char #x02907))			; ⤇	Rightwards Double Arrow From Bar
(char-name '|downarrowbarred| (integer->char #x02908))			; ⤈	Downwards Arrow With Horizontal Stroke
(char-name '|uparrowbarred| (integer->char #x02909))			; ⤉	Upwards Arrow With Horizontal Stroke
(char-name '|Uuparrow| (integer->char #x0290A))			; ⤊	Upwards Triple Arrow
(char-name '|Ddownarrow| (integer->char #x0290B))			; ⤋	Downwards Triple Arrow
(char-name '|leftbkarrow| (integer->char #x0290C))			; ⤌	Leftwards Double Dash Arrow
(char-name '|bkarow| (integer->char #x0290D))			; ⤍	Rightwards Double Dash Arrow
(char-name '|leftdbkarrow| (integer->char #x0290E))			; ⤎	Leftwards Triple Dash Arrow
(char-name '|dbkarow| (integer->char #x0290F))			; ⤏	Rightwards Triple Dash Arrow
(char-name '|drbkarrow| (integer->char #x02910))			; ⤐	Rightwards Two-Headed Triple Dash Arrow
(char-name '|rightdotarrow| (integer->char #x02911))			; ⤑	Rightwards Arrow With Dotted Stem
(char-name '|UpArrowBar| (integer->char #x02912))			; ⤒	Upwards Arrow To Bar
(char-name '|DownArrowBar| (integer->char #x02913))			; ⤓	Downwards Arrow To Bar
(char-name '|nvrightarrowtail| (integer->char #x02914))			; ⤔	Rightwards Arrow With Tail With Vertical Stroke
(char-name '|nVrightarrowtail| (integer->char #x02915))			; ⤕	Rightwards Arrow With Tail With Double Vertical Stroke
(char-name '|twoheadrightarrowtail| (integer->char #x02916))			; ⤖	Rightwards Two-Headed Arrow With Tail
(char-name '|nvtwoheadrightarrowtail| (integer->char #x02917))			; ⤗	Rightwards Two-Headed Arrow With Tail With Vertical Stroke
(char-name '|nVtwoheadrightarrowtail| (integer->char #x02918))			; ⤘	Rightwards Two-Headed Arrow With Tail With Double Vertical Stroke
(char-name '|diamondleftarrow| (integer->char #x0291D))			; ⤝	Leftwards Arrow To Black Diamond
(char-name '|rightarrowdiamond| (integer->char #x0291E))			; ⤞	Rightwards Arrow To Black Diamond
(char-name '|diamondleftarrowbar| (integer->char #x0291F))			; ⤟	Leftwards Arrow From Bar To Black Diamond
(char-name '|barrightarrowdiamond| (integer->char #x02920))			; ⤠	Rightwards Arrow From Bar To Black Diamond
(char-name '|hksearow| (integer->char #x02925))			; ⤥	South East Arrow With Hook
(char-name '|hkswarow| (integer->char #x02926))			; ⤦	South West Arrow With Hook
(char-name '|tona| (integer->char #x02927))			; ⤧	North West Arrow And North East Arrow
(char-name '|toea| (integer->char #x02928))			; ⤨	North East Arrow And South East Arrow
(char-name '|tosa| (integer->char #x02929))			; ⤩	South East Arrow And South West Arrow
(char-name '|towa| (integer->char #x0292A))			; ⤪	South West Arrow And North West Arrow
(char-name '|rdiagovfdiag| (integer->char #x0292B))			; ⤫	Rising Diagonal Crossing Falling Diagonal
(char-name '|fdiagovrdiag| (integer->char #x0292C))			; ⤬	Falling Diagonal Crossing Rising Diagonal
(char-name '|seovnearrow| (integer->char #x0292D))			; ⤭	South East Arrow Crossing North East Arrow
(char-name '|neovsearrow| (integer->char #x0292E))			; ⤮	North East Arrow Crossing South East Arrow
(char-name '|fdiagovnearrow| (integer->char #x0292F))			; ⤯	Falling Diagonal Crossing North East Arrow
(char-name '|rdiagovsearrow| (integer->char #x02930))			; ⤰	Rising Diagonal Crossing South East Arrow
(char-name '|neovnwarrow| (integer->char #x02931))			; ⤱	North East Arrow Crossing North West Arrow
(char-name '|nwovnearrow| (integer->char #x02932))			; ⤲	North West Arrow Crossing North East Arrow
(char-name '|:arrow_heading_up:| (integer->char #x02934))			; ⤴	Arrow Pointing Rightwards Then Curving Upwards
(char-name '|:arrow_heading_down:| (integer->char #x02935))			; ⤵	Arrow Pointing Rightwards Then Curving Downwards
(char-name '|Rlarr| (integer->char #x02942))			; ⥂	Rightwards Arrow Above Short Leftwards Arrow
(char-name '|rLarr| (integer->char #x02944))			; ⥄	Short Rightwards Arrow Above Leftwards Arrow
(char-name '|rightarrowplus| (integer->char #x02945))			; ⥅	Rightwards Arrow With Plus Below
(char-name '|leftarrowplus| (integer->char #x02946))			; ⥆	Leftwards Arrow With Plus Below
(char-name '|rarrx| (integer->char #x02947))			; ⥇	Rightwards Arrow Through X
(char-name '|leftrightarrowcircle| (integer->char #x02948))			; ⥈	Left Right Arrow Through Small Circle
(char-name '|twoheaduparrowcircle| (integer->char #x02949))			; ⥉	Upwards Two-Headed Arrow From Small Circle
(char-name '|leftrightharpoonupdown| (integer->char #x0294A))			; ⥊	Left Barb Up Right Barb Down Harpoon
(char-name '|leftrightharpoondownup| (integer->char #x0294B))			; ⥋	Left Barb Down Right Barb Up Harpoon
(char-name '|updownharpoonrightleft| (integer->char #x0294C))			; ⥌	Up Barb Right Down Barb Left Harpoon
(char-name '|updownharpoonleftright| (integer->char #x0294D))			; ⥍	Up Barb Left Down Barb Right Harpoon
(char-name '|LeftRightVector| (integer->char #x0294E))			; ⥎	Left Barb Up Right Barb Up Harpoon
(char-name '|RightUpDownVector| (integer->char #x0294F))			; ⥏	Up Barb Right Down Barb Right Harpoon
(char-name '|DownLeftRightVector| (integer->char #x02950))			; ⥐	Left Barb Down Right Barb Down Harpoon
(char-name '|LeftUpDownVector| (integer->char #x02951))			; ⥑	Up Barb Left Down Barb Left Harpoon
(char-name '|LeftVectorBar| (integer->char #x02952))			; ⥒	Leftwards Harpoon With Barb Up To Bar
(char-name '|RightVectorBar| (integer->char #x02953))			; ⥓	Rightwards Harpoon With Barb Up To Bar
(char-name '|RightUpVectorBar| (integer->char #x02954))			; ⥔	Upwards Harpoon With Barb Right To Bar
(char-name '|RightDownVectorBar| (integer->char #x02955))			; ⥕	Downwards Harpoon With Barb Right To Bar
(char-name '|DownLeftVectorBar| (integer->char #x02956))			; ⥖	Leftwards Harpoon With Barb Down To Bar
(char-name '|DownRightVectorBar| (integer->char #x02957))			; ⥗	Rightwards Harpoon With Barb Down To Bar
(char-name '|LeftUpVectorBar| (integer->char #x02958))			; ⥘	Upwards Harpoon With Barb Left To Bar
(char-name '|LeftDownVectorBar| (integer->char #x02959))			; ⥙	Downwards Harpoon With Barb Left To Bar
(char-name '|LeftTeeVector| (integer->char #x0295A))			; ⥚	Leftwards Harpoon With Barb Up From Bar
(char-name '|RightTeeVector| (integer->char #x0295B))			; ⥛	Rightwards Harpoon With Barb Up From Bar
(char-name '|RightUpTeeVector| (integer->char #x0295C))			; ⥜	Upwards Harpoon With Barb Right From Bar
(char-name '|RightDownTeeVector| (integer->char #x0295D))			; ⥝	Downwards Harpoon With Barb Right From Bar
(char-name '|DownLeftTeeVector| (integer->char #x0295E))			; ⥞	Leftwards Harpoon With Barb Down From Bar
(char-name '|DownRightTeeVector| (integer->char #x0295F))			; ⥟	Rightwards Harpoon With Barb Down From Bar
(char-name '|LeftUpTeeVector| (integer->char #x02960))			; ⥠	Upwards Harpoon With Barb Left From Bar
(char-name '|LeftDownTeeVector| (integer->char #x02961))			; ⥡	Downwards Harpoon With Barb Left From Bar
(char-name '|leftharpoonsupdown| (integer->char #x02962))			; ⥢	Leftwards Harpoon With Barb Up Above Leftwards Harpoon With Barb Down
(char-name '|upharpoonsleftright| (integer->char #x02963))			; ⥣	Upwards Harpoon With Barb Left Beside Upwards Harpoon With Barb Right
(char-name '|rightharpoonsupdown| (integer->char #x02964))			; ⥤	Rightwards Harpoon With Barb Up Above Rightwards Harpoon With Barb Down
(char-name '|downharpoonsleftright| (integer->char #x02965))			; ⥥	Downwards Harpoon With Barb Left Beside Downwards Harpoon With Barb Right
(char-name '|leftrightharpoonsup| (integer->char #x02966))			; ⥦	Leftwards Harpoon With Barb Up Above Rightwards Harpoon With Barb Up
(char-name '|leftrightharpoonsdown| (integer->char #x02967))			; ⥧	Leftwards Harpoon With Barb Down Above Rightwards Harpoon With Barb Down
(char-name '|rightleftharpoonsup| (integer->char #x02968))			; ⥨	Rightwards Harpoon With Barb Up Above Leftwards Harpoon With Barb Up
(char-name '|rightleftharpoonsdown| (integer->char #x02969))			; ⥩	Rightwards Harpoon With Barb Down Above Leftwards Harpoon With Barb Down
(char-name '|leftharpoonupdash| (integer->char #x0296A))			; ⥪	Leftwards Harpoon With Barb Up Above Long Dash
(char-name '|dashleftharpoondown| (integer->char #x0296B))			; ⥫	Leftwards Harpoon With Barb Down Below Long Dash
(char-name '|rightharpoonupdash| (integer->char #x0296C))			; ⥬	Rightwards Harpoon With Barb Up Above Long Dash
(char-name '|dashrightharpoondown| (integer->char #x0296D))			; ⥭	Rightwards Harpoon With Barb Down Below Long Dash
(char-name '|UpEquilibrium| (integer->char #x0296E))			; ⥮	Upwards Harpoon With Barb Left Beside Downwards Harpoon With Barb Right
(char-name '|ReverseUpEquilibrium| (integer->char #x0296F))			; ⥯	Downwards Harpoon With Barb Left Beside Upwards Harpoon With Barb Right
(char-name '|RoundImplies| (integer->char #x02970))			; ⥰	Right Double Arrow With Rounded Head
(char-name '|Vvert| (integer->char #x02980))			; ⦀	Triple Vertical Bar Delimiter
(char-name '|Elroang| (integer->char #x02986))			; ⦆	Right White Parenthesis
(char-name '|ddfnc| (integer->char #x02999))			; ⦙	Dotted Fence
(char-name '|measuredangleleft| (integer->char #x0299B))			; ⦛	Measured Angle Opening Left
(char-name '|Angle| (integer->char #x0299C))			; ⦜	Right Angle Variant With Square
(char-name '|rightanglemdot| (integer->char #x0299D))			; ⦝	Measured Right Angle With Dot
(char-name '|angles| (integer->char #x0299E))			; ⦞	Angle With S Inside
(char-name '|angdnr| (integer->char #x0299F))			; ⦟	Acute Angle
(char-name '|lpargt| (integer->char #x029A0))			; ⦠	Spherical Angle Opening Left
(char-name '|sphericalangleup| (integer->char #x029A1))			; ⦡	Spherical Angle Opening Up
(char-name '|turnangle| (integer->char #x029A2))			; ⦢	Turned Angle
(char-name '|revangle| (integer->char #x029A3))			; ⦣	Reversed Angle
(char-name '|angleubar| (integer->char #x029A4))			; ⦤	Angle With Underbar
(char-name '|revangleubar| (integer->char #x029A5))			; ⦥	Reversed Angle With Underbar
(char-name '|wideangledown| (integer->char #x029A6))			; ⦦	Oblique Angle Opening Up
(char-name '|wideangleup| (integer->char #x029A7))			; ⦧	Oblique Angle Opening Down
(char-name '|measanglerutone| (integer->char #x029A8))			; ⦨	Measured Angle With Open Arm Ending In Arrow Pointing Up And Right
(char-name '|measanglelutonw| (integer->char #x029A9))			; ⦩	Measured Angle With Open Arm Ending In Arrow Pointing Up And Left
(char-name '|measanglerdtose| (integer->char #x029AA))			; ⦪	Measured Angle With Open Arm Ending In Arrow Pointing Down And Right
(char-name '|measangleldtosw| (integer->char #x029AB))			; ⦫	Measured Angle With Open Arm Ending In Arrow Pointing Down And Left
(char-name '|measangleurtone| (integer->char #x029AC))			; ⦬	Measured Angle With Open Arm Ending In Arrow Pointing Right And Up
(char-name '|measangleultonw| (integer->char #x029AD))			; ⦭	Measured Angle With Open Arm Ending In Arrow Pointing Left And Up
(char-name '|measangledrtose| (integer->char #x029AE))			; ⦮	Measured Angle With Open Arm Ending In Arrow Pointing Right And Down
(char-name '|measangledltosw| (integer->char #x029AF))			; ⦯	Measured Angle With Open Arm Ending In Arrow Pointing Left And Down
(char-name '|revemptyset| (integer->char #x029B0))			; ⦰	Reversed Empty Set
(char-name '|emptysetobar| (integer->char #x029B1))			; ⦱	Empty Set With Overbar
(char-name '|emptysetocirc| (integer->char #x029B2))			; ⦲	Empty Set With Small Circle Above
(char-name '|emptysetoarr| (integer->char #x029B3))			; ⦳	Empty Set With Right Arrow Above
(char-name '|emptysetoarrl| (integer->char #x029B4))			; ⦴	Empty Set With Left Arrow Above
(char-name '|circledparallel| (integer->char #x029B7))			; ⦷	Circled Parallel
(char-name '|obslash| (integer->char #x029B8))			; ⦸	Circled Reverse Solidus
(char-name '|odotslashdot| (integer->char #x029BC))			; ⦼	Circled Anticlockwise-Rotated Division Sign
(char-name '|circledwhitebullet| (integer->char #x029BE))			; ⦾	Circled White Bullet
(char-name '|circledbullet| (integer->char #x029BF))			; ⦿	Circled Bullet
(char-name '|olessthan| (integer->char #x029C0))			; ⧀	Circled Less-Than
(char-name '|ogreaterthan| (integer->char #x029C1))			; ⧁	Circled Greater-Than
(char-name '|boxdiag| (integer->char #x029C4))			; ⧄	Squared Rising Diagonal Slash
(char-name '|boxbslash| (integer->char #x029C5))			; ⧅	Squared Falling Diagonal Slash
(char-name '|boxast| (integer->char #x029C6))			; ⧆	Squared Asterisk
(char-name '|boxcircle| (integer->char #x029C7))			; ⧇	Squared Small Circle
(char-name '|Lap| (integer->char #x029CA))			; ⧊	Triangle With Dot Above
(char-name '|defas| (integer->char #x029CB))			; ⧋	Triangle With Underbar
(char-name '|LeftTriangleBar| (integer->char #x029CF))			; ⧏	Left Triangle Beside Vertical Bar
;(char-name '|NotLeftTriangleBar|  U+029CF + U+00338)			; ⧏̸	Left Triangle Beside Vertical Bar + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|RightTriangleBar| (integer->char #x029D0))			; ⧐	Vertical Bar Beside Right Triangle
;(char-name '|NotRightTriangleBar|  U+029D0 + U+00338)			; ⧐̸	Vertical Bar Beside Right Triangle + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|dualmap| (integer->char #x029DF))			; ⧟	Double-Ended Multimap
(char-name '|lrtriangleeq| (integer->char #x029E1))			; ⧡	Increases As
(char-name '|shuffle| (integer->char #x029E2))			; ⧢	Shuffle Product
(char-name '|eparsl| (integer->char #x029E3))			; ⧣	Equals Sign And Slanted Parallel
(char-name '|smeparsl| (integer->char #x029E4))			; ⧤	Equals Sign And Slanted Parallel With Tilde Above
(char-name '|eqvparsl| (integer->char #x029E5))			; ⧥	Identical To And Slanted Parallel
(char-name '|blacklozenge| (integer->char #x029EB))			; ⧫	Black Lozenge
(char-name '|RuleDelayed| (integer->char #x029F4))			; ⧴	Rule-Delayed
(char-name '|dsol| (integer->char #x029F6))			; ⧶	Solidus With Overbar
(char-name '|rsolbar| (integer->char #x029F7))			; ⧷	Reverse Solidus With Horizontal Stroke
(char-name '|doubleplus| (integer->char #x029FA))			; ⧺	Double Plus
(char-name '|tripleplus| (integer->char #x029FB))			; ⧻	Triple Plus
(char-name '|bigodot| (integer->char #x02A00))			; ⨀	N-Ary Circled Dot Operator
(char-name '|bigoplus| (integer->char #x02A01))			; ⨁	N-Ary Circled Plus Operator
(char-name '|bigotimes| (integer->char #x02A02))			; ⨂	N-Ary Circled Times Operator
(char-name '|bigcupdot| (integer->char #x02A03))			; ⨃	N-Ary Union Operator With Dot
(char-name '|biguplus| (integer->char #x02A04))			; ⨄	N-Ary Union Operator With Plus
(char-name '|bigsqcap| (integer->char #x02A05))			; ⨅	N-Ary Square Intersection Operator
(char-name '|bigsqcup| (integer->char #x02A06))			; ⨆	N-Ary Square Union Operator
(char-name '|conjquant| (integer->char #x02A07))			; ⨇	Two Logical And Operator
(char-name '|disjquant| (integer->char #x02A08))			; ⨈	Two Logical Or Operator
(char-name '|bigtimes| (integer->char #x02A09))			; ⨉	N-Ary Times Operator
(char-name '|modtwosum| (integer->char #x02A0A))			; ⨊	Modulo Two Sum
(char-name '|sumint| (integer->char #x02A0B))			; ⨋	Summation With Integral
(char-name '|iiiint| (integer->char #x02A0C))			; ⨌	Quadruple Integral Operator
(char-name '|intbar| (integer->char #x02A0D))			; ⨍	Finite Part Integral
(char-name '|intBar| (integer->char #x02A0E))			; ⨎	Integral With Double Stroke
(char-name '|clockoint| (integer->char #x02A0F))			; ⨏	Integral Average With Slash
(char-name '|cirfnint| (integer->char #x02A10))			; ⨐	Circulation Function
(char-name '|awint| (integer->char #x02A11))			; ⨑	Anticlockwise Integration
(char-name '|rppolint| (integer->char #x02A12))			; ⨒	Line Integration With Rectangular Path Around Pole
(char-name '|scpolint| (integer->char #x02A13))			; ⨓	Line Integration With Semicircular Path Around Pole
(char-name '|npolint| (integer->char #x02A14))			; ⨔	Line Integration Not Including The Pole
(char-name '|pointint| (integer->char #x02A15))			; ⨕	Integral Around A Point Operator
(char-name '|sqrint| (integer->char #x02A16))			; ⨖	Quaternion Integral Operator
(char-name '|intx| (integer->char #x02A18))			; ⨘	Integral With Times Sign
(char-name '|intcap| (integer->char #x02A19))			; ⨙	Integral With Intersection
(char-name '|intcup| (integer->char #x02A1A))			; ⨚	Integral With Union
(char-name '|upint| (integer->char #x02A1B))			; ⨛	Integral With Overbar
(char-name '|lowint| (integer->char #x02A1C))			; ⨜	Integral With Underbar
(char-name '|Join| (integer->char #x02A1D))			; ⨝	Join
(char-name '|join| (integer->char #x02A1D))			; ⨝	Join
(char-name '|bbsemi| (integer->char #x02A1F))			; ⨟	Z Notation Schema Composition
(char-name '|ringplus| (integer->char #x02A22))			; ⨢	Plus Sign With Small Circle Above
(char-name '|plushat| (integer->char #x02A23))			; ⨣	Plus Sign With Circumflex Accent Above
(char-name '|simplus| (integer->char #x02A24))			; ⨤	Plus Sign With Tilde Above
(char-name '|plusdot| (integer->char #x02A25))			; ⨥	Plus Sign With Dot Below
(char-name '|plussim| (integer->char #x02A26))			; ⨦	Plus Sign With Tilde Below
(char-name '|plussubtwo| (integer->char #x02A27))			; ⨧	Plus Sign With Subscript Two
(char-name '|plustrif| (integer->char #x02A28))			; ⨨	Plus Sign With Black Triangle
(char-name '|commaminus| (integer->char #x02A29))			; ⨩	Minus Sign With Comma Above
(char-name '|minusdot| (integer->char #x02A2A))			; ⨪	Minus Sign With Dot Below
(char-name '|minusfdots| (integer->char #x02A2B))			; ⨫	Minus Sign With Falling Dots
(char-name '|minusrdots| (integer->char #x02A2C))			; ⨬	Minus Sign With Rising Dots
(char-name '|opluslhrim| (integer->char #x02A2D))			; ⨭	Plus Sign In Left Half Circle
(char-name '|oplusrhrim| (integer->char #x02A2E))			; ⨮	Plus Sign In Right Half Circle
(char-name '|Times| (integer->char #x02A2F))			; ⨯	Vector Or Cross Product
(char-name '|dottimes| (integer->char #x02A30))			; ⨰	Multiplication Sign With Dot Above
(char-name '|timesbar| (integer->char #x02A31))			; ⨱	Multiplication Sign With Underbar
(char-name '|btimes| (integer->char #x02A32))			; ⨲	Semidirect Product With Bottom Closed
(char-name '|smashtimes| (integer->char #x02A33))			; ⨳	Smash Product
(char-name '|otimeslhrim| (integer->char #x02A34))			; ⨴	Multiplication Sign In Left Half Circle
(char-name '|otimesrhrim| (integer->char #x02A35))			; ⨵	Multiplication Sign In Right Half Circle
(char-name '|otimeshat| (integer->char #x02A36))			; ⨶	Circled Multiplication Sign With Circumflex Accent
(char-name '|Otimes| (integer->char #x02A37))			; ⨷	Multiplication Sign In Double Circle
(char-name '|odiv| (integer->char #x02A38))			; ⨸	Circled Division Sign
(char-name '|triangleplus| (integer->char #x02A39))			; ⨹	Plus Sign In Triangle
(char-name '|triangleminus| (integer->char #x02A3A))			; ⨺	Minus Sign In Triangle
(char-name '|triangletimes| (integer->char #x02A3B))			; ⨻	Multiplication Sign In Triangle
(char-name '|intprod| (integer->char #x02A3C))			; ⨼	Interior Product
(char-name '|intprodr| (integer->char #x02A3D))			; ⨽	Righthand Interior Product
(char-name '|amalg| (integer->char #x02A3F))			; ⨿	Amalgamation Or Coproduct
(char-name '|capdot| (integer->char #x02A40))			; ⩀	Intersection With Dot
(char-name '|uminus| (integer->char #x02A41))			; ⩁	Union With Minus Sign
(char-name '|barcup| (integer->char #x02A42))			; ⩂	Union With Overbar
(char-name '|barcap| (integer->char #x02A43))			; ⩃	Intersection With Overbar
(char-name '|capwedge| (integer->char #x02A44))			; ⩄	Intersection With Logical And
(char-name '|cupvee| (integer->char #x02A45))			; ⩅	Union With Logical Or
(char-name '|twocups| (integer->char #x02A4A))			; ⩊	Union Beside And Joined With Union
(char-name '|twocaps| (integer->char #x02A4B))			; ⩋	Intersection Beside And Joined With Intersection
(char-name '|closedvarcup| (integer->char #x02A4C))			; ⩌	Closed Union With Serifs
(char-name '|closedvarcap| (integer->char #x02A4D))			; ⩍	Closed Intersection With Serifs
(char-name '|Sqcap| (integer->char #x02A4E))			; ⩎	Double Square Intersection
(char-name '|Sqcup| (integer->char #x02A4F))			; ⩏	Double Square Union
(char-name '|closedvarcupsmashprod| (integer->char #x02A50))			; ⩐	Closed Union With Serifs And Smash Product
(char-name '|wedgeodot| (integer->char #x02A51))			; ⩑	Logical And With Dot Above
(char-name '|veeodot| (integer->char #x02A52))			; ⩒	Logical Or With Dot Above
(char-name '|And| (integer->char #x02A53))			; ⩓	Double Logical And
(char-name '|Or| (integer->char #x02A54))			; ⩔	Double Logical Or
(char-name '|wedgeonwedge| (integer->char #x02A55))			; ⩕	Two Intersecting Logical And
(char-name '|ElOr| (integer->char #x02A56))			; ⩖	Two Intersecting Logical Or
(char-name '|bigslopedvee| (integer->char #x02A57))			; ⩗	Sloping Large Or
(char-name '|bigslopedwedge| (integer->char #x02A58))			; ⩘	Sloping Large And
(char-name '|wedgemidvert| (integer->char #x02A5A))			; ⩚	Logical And With Middle Stem
(char-name '|veemidvert| (integer->char #x02A5B))			; ⩛	Logical Or With Middle Stem
(char-name '|midbarwedge| (integer->char #x02A5C))			; ⩜	Logical And With Horizontal Dash
(char-name '|midbarvee| (integer->char #x02A5D))			; ⩝	Logical Or With Horizontal Dash
(char-name '|perspcorrespond| (integer->char #x02A5E))			; ⩞	Logical And With Double Overbar
(char-name '|minhat| (integer->char #x02A5F))			; ⩟	Logical And With Underbar
(char-name '|wedgedoublebar| (integer->char #x02A60))			; ⩠	Logical And With Double Underbar
(char-name '|varveebar| (integer->char #x02A61))			; ⩡	Small Vee With Underbar
(char-name '|doublebarvee| (integer->char #x02A62))			; ⩢	Logical Or With Double Overbar
(char-name '|veedoublebar| (integer->char #x02A63))			; ⩣	Logical Or With Double Underbar
(char-name '|eqdot| (integer->char #x02A66))			; ⩦	Equals Sign With Dot Below
(char-name '|dotequiv| (integer->char #x02A67))			; ⩧	Identical With Dot Above
(char-name '|dotsim| (integer->char #x02A6A))			; ⩪	Tilde Operator With Dot Above
(char-name '|simrdots| (integer->char #x02A6B))			; ⩫	Tilde Operator With Rising Dots
(char-name '|simminussim| (integer->char #x02A6C))			; ⩬	Similar Minus Similar
(char-name '|congdot| (integer->char #x02A6D))			; ⩭	Congruent With Dot Above
(char-name '|asteq| (integer->char #x02A6E))			; ⩮	Equals With Asterisk
(char-name '|hatapprox| (integer->char #x02A6F))			; ⩯	Almost Equal To With Circumflex Accent
(char-name '|approxeqq| (integer->char #x02A70))			; ⩰	Approximately Equal Or Equal To
(char-name '|eqqplus| (integer->char #x02A71))			; ⩱	Equals Sign Above Plus Sign
(char-name '|pluseqq| (integer->char #x02A72))			; ⩲	Plus Sign Above Equals Sign
(char-name '|eqqsim| (integer->char #x02A73))			; ⩳	Equals Sign Above Tilde Operator
(char-name '|Coloneq| (integer->char #x02A74))			; ⩴	Double Colon Equal
(char-name '|Equal| (integer->char #x02A75))			; ⩵	Two Consecutive Equals Signs
(char-name '|eqeqeq| (integer->char #x02A76))			; ⩶	Three Consecutive Equals Signs
(char-name '|ddotseq| (integer->char #x02A77))			; ⩷	Equals Sign With Two Dots Above And Two Dots Below
(char-name '|equivDD| (integer->char #x02A78))			; ⩸	Equivalent With Four Dots Above
(char-name '|ltcir| (integer->char #x02A79))			; ⩹	Less-Than With Circle Inside
(char-name '|gtcir| (integer->char #x02A7A))			; ⩺	Greater-Than With Circle Inside
(char-name '|ltquest| (integer->char #x02A7B))			; ⩻	Less-Than With Question Mark Above
(char-name '|gtquest| (integer->char #x02A7C))			; ⩼	Greater-Than With Question Mark Above
(char-name '|leqslant| (integer->char #x02A7D))			; ⩽	Less-Than Or Slanted Equal To
;(char-name '|nleqslant|  U+02A7D + U+00338)			; ⩽̸	Less-Than Or Slanted Equal To + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|geqslant| (integer->char #x02A7E))			; ⩾	Greater-Than Or Slanted Equal To
;(char-name '|ngeqslant|  U+02A7E + U+00338)			; ⩾̸	Greater-Than Or Slanted Equal To + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|lesdot| (integer->char #x02A7F))			; ⩿	Less-Than Or Slanted Equal To With Dot Inside
(char-name '|gesdot| (integer->char #x02A80))			; ⪀	Greater-Than Or Slanted Equal To With Dot Inside
(char-name '|lesdoto| (integer->char #x02A81))			; ⪁	Less-Than Or Slanted Equal To With Dot Above
(char-name '|gesdoto| (integer->char #x02A82))			; ⪂	Greater-Than Or Slanted Equal To With Dot Above
(char-name '|lesdotor| (integer->char #x02A83))			; ⪃	Less-Than Or Slanted Equal To With Dot Above Right
(char-name '|gesdotol| (integer->char #x02A84))			; ⪄	Greater-Than Or Slanted Equal To With Dot Above Left
(char-name '|lessapprox| (integer->char #x02A85))			; ⪅	Less-Than Or Approximate
(char-name '|gtrapprox| (integer->char #x02A86))			; ⪆	Greater-Than Or Approximate
(char-name '|lneq| (integer->char #x02A87))			; ⪇	Less-Than And Single-Line Not Equal To
(char-name '|gneq| (integer->char #x02A88))			; ⪈	Greater-Than And Single-Line Not Equal To
(char-name '|lnapprox| (integer->char #x02A89))			; ⪉	Less-Than And Not Approximate
(char-name '|gnapprox| (integer->char #x02A8A))			; ⪊	Greater-Than And Not Approximate
(char-name '|lesseqqgtr| (integer->char #x02A8B))			; ⪋	Less-Than Above Double-Line Equal Above Greater-Than
(char-name '|gtreqqless| (integer->char #x02A8C))			; ⪌	Greater-Than Above Double-Line Equal Above Less-Than
(char-name '|lsime| (integer->char #x02A8D))			; ⪍	Less-Than Above Similar Or Equal
(char-name '|gsime| (integer->char #x02A8E))			; ⪎	Greater-Than Above Similar Or Equal
(char-name '|lsimg| (integer->char #x02A8F))			; ⪏	Less-Than Above Similar Above Greater-Than
(char-name '|gsiml| (integer->char #x02A90))			; ⪐	Greater-Than Above Similar Above Less-Than
(char-name '|lgE| (integer->char #x02A91))			; ⪑	Less-Than Above Greater-Than Above Double-Line Equal
(char-name '|glE| (integer->char #x02A92))			; ⪒	Greater-Than Above Less-Than Above Double-Line Equal
(char-name '|lesges| (integer->char #x02A93))			; ⪓	Less-Than Above Slanted Equal Above Greater-Than Above Slanted Equal
(char-name '|gesles| (integer->char #x02A94))			; ⪔	Greater-Than Above Slanted Equal Above Less-Than Above Slanted Equal
(char-name '|eqslantless| (integer->char #x02A95))			; ⪕	Slanted Equal To Or Less-Than
(char-name '|eqslantgtr| (integer->char #x02A96))			; ⪖	Slanted Equal To Or Greater-Than
(char-name '|elsdot| (integer->char #x02A97))			; ⪗	Slanted Equal To Or Less-Than With Dot Inside
(char-name '|egsdot| (integer->char #x02A98))			; ⪘	Slanted Equal To Or Greater-Than With Dot Inside
(char-name '|eqqless| (integer->char #x02A99))			; ⪙	Double-Line Equal To Or Less-Than
(char-name '|eqqgtr| (integer->char #x02A9A))			; ⪚	Double-Line Equal To Or Greater-Than
(char-name '|eqqslantless| (integer->char #x02A9B))			; ⪛	Double-Line Slanted Equal To Or Less-Than
(char-name '|eqqslantgtr| (integer->char #x02A9C))			; ⪜	Double-Line Slanted Equal To Or Greater-Than
(char-name '|simless| (integer->char #x02A9D))			; ⪝	Similar Or Less-Than
(char-name '|simgtr| (integer->char #x02A9E))			; ⪞	Similar Or Greater-Than
(char-name '|simlE| (integer->char #x02A9F))			; ⪟	Similar Above Less-Than Above Equals Sign
(char-name '|simgE| (integer->char #x02AA0))			; ⪠	Similar Above Greater-Than Above Equals Sign
(char-name '|NestedLessLess| (integer->char #x02AA1))			; ⪡	Double Nested Less-Than
;(char-name '|NotNestedLessLess|  U+02AA1 + U+00338)			; ⪡̸	Double Nested Less-Than + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|NestedGreaterGreater| (integer->char #x02AA2))			; ⪢	Double Nested Greater-Than
;(char-name '|NotNestedGreaterGreater|  U+02AA2 + U+00338)			; ⪢̸	Double Nested Greater-Than + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|partialmeetcontraction| (integer->char #x02AA3))			; ⪣	Double Nested Less-Than With Underbar
(char-name '|glj| (integer->char #x02AA4))			; ⪤	Greater-Than Overlapping Less-Than
(char-name '|gla| (integer->char #x02AA5))			; ⪥	Greater-Than Beside Less-Than
(char-name '|ltcc| (integer->char #x02AA6))			; ⪦	Less-Than Closed By Curve
(char-name '|gtcc| (integer->char #x02AA7))			; ⪧	Greater-Than Closed By Curve
(char-name '|lescc| (integer->char #x02AA8))			; ⪨	Less-Than Closed By Curve Above Slanted Equal
(char-name '|gescc| (integer->char #x02AA9))			; ⪩	Greater-Than Closed By Curve Above Slanted Equal
(char-name '|smt| (integer->char #x02AAA))			; ⪪	Smaller Than
(char-name '|lat| (integer->char #x02AAB))			; ⪫	Larger Than
(char-name '|smte| (integer->char #x02AAC))			; ⪬	Smaller Than Or Equal To
(char-name '|late| (integer->char #x02AAD))			; ⪭	Larger Than Or Equal To
(char-name '|bumpeqq| (integer->char #x02AAE))			; ⪮	Equals Sign With Bumpy Above
(char-name '|preceq| (integer->char #x02AAF))			; ⪯	Precedes Above Single-Line Equals Sign
;(char-name '|npreceq|  U+02AAF + U+00338)			; ⪯̸	Precedes Above Single-Line Equals Sign + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|succeq| (integer->char #x02AB0))			; ⪰	Succeeds Above Single-Line Equals Sign
;(char-name '|nsucceq|  U+02AB0 + U+00338)			; ⪰̸	Succeeds Above Single-Line Equals Sign + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|precneq| (integer->char #x02AB1))			; ⪱	Precedes Above Single-Line Not Equal To
(char-name '|succneq| (integer->char #x02AB2))			; ⪲	Succeeds Above Single-Line Not Equal To
(char-name '|preceqq| (integer->char #x02AB3))			; ⪳	Precedes Above Equals Sign
(char-name '|succeqq| (integer->char #x02AB4))			; ⪴	Succeeds Above Equals Sign
(char-name '|precneqq| (integer->char #x02AB5))			; ⪵	Precedes Above Not Equal To
(char-name '|succneqq| (integer->char #x02AB6))			; ⪶	Succeeds Above Not Equal To
(char-name '|precapprox| (integer->char #x02AB7))			; ⪷	Precedes Above Almost Equal To
(char-name '|succapprox| (integer->char #x02AB8))			; ⪸	Succeeds Above Almost Equal To
(char-name '|precnapprox| (integer->char #x02AB9))			; ⪹	Precedes Above Not Almost Equal To
(char-name '|succnapprox| (integer->char #x02ABA))			; ⪺	Succeeds Above Not Almost Equal To
(char-name '|Prec| (integer->char #x02ABB))			; ⪻	Double Precedes
(char-name '|Succ| (integer->char #x02ABC))			; ⪼	Double Succeeds
(char-name '|subsetdot| (integer->char #x02ABD))			; ⪽	Subset With Dot
(char-name '|supsetdot| (integer->char #x02ABE))			; ⪾	Superset With Dot
(char-name '|subsetplus| (integer->char #x02ABF))			; ⪿	Subset With Plus Sign Below
(char-name '|supsetplus| (integer->char #x02AC0))			; ⫀	Superset With Plus Sign Below
(char-name '|submult| (integer->char #x02AC1))			; ⫁	Subset With Multiplication Sign Below
(char-name '|supmult| (integer->char #x02AC2))			; ⫂	Superset With Multiplication Sign Below
(char-name '|subedot| (integer->char #x02AC3))			; ⫃	Subset Of Or Equal To With Dot Above
(char-name '|supedot| (integer->char #x02AC4))			; ⫄	Superset Of Or Equal To With Dot Above
(char-name '|subseteqq| (integer->char #x02AC5))			; ⫅	Subset Of Above Equals Sign
;(char-name '|nsubseteqq|  U+02AC5 + U+00338)			; ⫅̸	Subset Of Above Equals Sign + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|supseteqq| (integer->char #x02AC6))			; ⫆	Superset Of Above Equals Sign
;(char-name '|nsupseteqq|  U+02AC6 + U+00338)			; ⫆̸	Superset Of Above Equals Sign + Combining Long Solidus Overlay / Non-Spacing Long Slash Overlay
(char-name '|subsim| (integer->char #x02AC7))			; ⫇	Subset Of Above Tilde Operator
(char-name '|supsim| (integer->char #x02AC8))			; ⫈	Superset Of Above Tilde Operator
(char-name '|subsetapprox| (integer->char #x02AC9))			; ⫉	Subset Of Above Almost Equal To
(char-name '|supsetapprox| (integer->char #x02ACA))			; ⫊	Superset Of Above Almost Equal To
(char-name '|subsetneqq| (integer->char #x02ACB))			; ⫋	Subset Of Above Not Equal To
(char-name '|supsetneqq| (integer->char #x02ACC))			; ⫌	Superset Of Above Not Equal To
(char-name '|lsqhook| (integer->char #x02ACD))			; ⫍	Square Left Open Box Operator
(char-name '|rsqhook| (integer->char #x02ACE))			; ⫎	Square Right Open Box Operator
(char-name '|csub| (integer->char #x02ACF))			; ⫏	Closed Subset
(char-name '|csup| (integer->char #x02AD0))			; ⫐	Closed Superset
(char-name '|csube| (integer->char #x02AD1))			; ⫑	Closed Subset Or Equal To
(char-name '|csupe| (integer->char #x02AD2))			; ⫒	Closed Superset Or Equal To
(char-name '|subsup| (integer->char #x02AD3))			; ⫓	Subset Above Superset
(char-name '|supsub| (integer->char #x02AD4))			; ⫔	Superset Above Subset
(char-name '|subsub| (integer->char #x02AD5))			; ⫕	Subset Above Subset
(char-name '|supsup| (integer->char #x02AD6))			; ⫖	Superset Above Superset
(char-name '|suphsub| (integer->char #x02AD7))			; ⫗	Superset Beside Subset
(char-name '|supdsub| (integer->char #x02AD8))			; ⫘	Superset Beside And Joined By Dash With Subset
(char-name '|forkv| (integer->char #x02AD9))			; ⫙	Element Of Opening Downwards
(char-name '|mlcp| (integer->char #x02ADB))			; ⫛	Transversal Intersection
(char-name '|forks| (integer->char #x02ADC))			; ⫝̸	Forking
(char-name '|forksnot| (integer->char #x02ADD))			; ⫝	Nonforking
(char-name '|dashV| (integer->char #x02AE3))			; ⫣	Double Vertical Bar Left Turnstile
(char-name '|Dashv| (integer->char #x02AE4))			; ⫤	Vertical Bar Double Left Turnstile
(char-name '|interleave| (integer->char #x02AF4))			; ⫴	Triple Vertical Bar Binary Relation
(char-name '|tdcol| (integer->char #x02AF6))			; ⫶	Triple Colon Operator
(char-name '|lllnest| (integer->char #x02AF7))			; ⫷	Triple Nested Less-Than
(char-name '|gggnest| (integer->char #x02AF8))			; ⫸	Triple Nested Greater-Than
(char-name '|leqqslant| (integer->char #x02AF9))			; ⫹	Double-Line Slanted Less-Than Or Equal To
(char-name '|geqqslant| (integer->char #x02AFA))			; ⫺	Double-Line Slanted Greater-Than Or Equal To
(char-name '|:arrow_left:| (integer->char #x02B05))			; ⬅	Leftwards Black Arrow
(char-name '|:arrow_up:| (integer->char #x02B06))			; ⬆	Upwards Black Arrow
(char-name '|:arrow_down:| (integer->char #x02B07))			; ⬇	Downwards Black Arrow
(char-name '|squaretopblack| (integer->char #x02B12))			; ⬒	Square With Top Half Black
(char-name '|squarebotblack| (integer->char #x02B13))			; ⬓	Square With Bottom Half Black
(char-name '|squareurblack| (integer->char #x02B14))			; ⬔	Square With Upper Right Diagonal Half Black
(char-name '|squarellblack| (integer->char #x02B15))			; ⬕	Square With Lower Left Diagonal Half Black
(char-name '|diamondleftblack| (integer->char #x02B16))			; ⬖	Diamond With Left Half Black
(char-name '|diamondrightblack| (integer->char #x02B17))			; ⬗	Diamond With Right Half Black
(char-name '|diamondtopblack| (integer->char #x02B18))			; ⬘	Diamond With Top Half Black
(char-name '|diamondbotblack| (integer->char #x02B19))			; ⬙	Diamond With Bottom Half Black
(char-name '|dottedsquare| (integer->char #x02B1A))			; ⬚	Dotted Square
(char-name '|lgblksquare| (integer->char #x02B1B))			; ⬛	Black Large Square
(char-name '|:black_large_square:| (integer->char #x02B1B))			; ⬛	Black Large Square
(char-name '|lgwhtsquare| (integer->char #x02B1C))			; ⬜	White Large Square
(char-name '|:white_large_square:| (integer->char #x02B1C))			; ⬜	White Large Square
(char-name '|vysmblksquare| (integer->char #x02B1D))			; ⬝	Black Very Small Square
(char-name '|vysmwhtsquare| (integer->char #x02B1E))			; ⬞	White Very Small Square
(char-name '|pentagonblack| (integer->char #x02B1F))			; ⬟	Black Pentagon
(char-name '|pentagon| (integer->char #x02B20))			; ⬠	White Pentagon
(char-name '|varhexagon| (integer->char #x02B21))			; ⬡	White Hexagon
(char-name '|varhexagonblack| (integer->char #x02B22))			; ⬢	Black Hexagon
(char-name '|hexagonblack| (integer->char #x02B23))			; ⬣	Horizontal Black Hexagon
(char-name '|lgblkcircle| (integer->char #x02B24))			; ⬤	Black Large Circle
(char-name '|mdblkdiamond| (integer->char #x02B25))			; ⬥	Black Medium Diamond
(char-name '|mdwhtdiamond| (integer->char #x02B26))			; ⬦	White Medium Diamond
(char-name '|mdblklozenge| (integer->char #x02B27))			; ⬧	Black Medium Lozenge
(char-name '|mdwhtlozenge| (integer->char #x02B28))			; ⬨	White Medium Lozenge
(char-name '|smblkdiamond| (integer->char #x02B29))			; ⬩	Black Small Diamond
(char-name '|smblklozenge| (integer->char #x02B2A))			; ⬪	Black Small Lozenge
(char-name '|smwhtlozenge| (integer->char #x02B2B))			; ⬫	White Small Lozenge
(char-name '|blkhorzoval| (integer->char #x02B2C))			; ⬬	Black Horizontal Ellipse
(char-name '|whthorzoval| (integer->char #x02B2D))			; ⬭	White Horizontal Ellipse
(char-name '|blkvertoval| (integer->char #x02B2E))			; ⬮	Black Vertical Ellipse
(char-name '|whtvertoval| (integer->char #x02B2F))			; ⬯	White Vertical Ellipse
(char-name '|circleonleftarrow| (integer->char #x02B30))			; ⬰	Left Arrow With Small Circle
(char-name '|leftthreearrows| (integer->char #x02B31))			; ⬱	Three Leftwards Arrows
(char-name '|leftarrowonoplus| (integer->char #x02B32))			; ⬲	Left Arrow With Circled Plus
(char-name '|longleftsquigarrow| (integer->char #x02B33))			; ⬳	Long Leftwards Squiggle Arrow
(char-name '|nvtwoheadleftarrow| (integer->char #x02B34))			; ⬴	Leftwards Two-Headed Arrow With Vertical Stroke
(char-name '|nVtwoheadleftarrow| (integer->char #x02B35))			; ⬵	Leftwards Two-Headed Arrow With Double Vertical Stroke
(char-name '|twoheadmapsfrom| (integer->char #x02B36))			; ⬶	Leftwards Two-Headed Arrow From Bar
(char-name '|twoheadleftdbkarrow| (integer->char #x02B37))			; ⬷	Leftwards Two-Headed Triple Dash Arrow
(char-name '|leftdotarrow| (integer->char #x02B38))			; ⬸	Leftwards Arrow With Dotted Stem
(char-name '|nvleftarrowtail| (integer->char #x02B39))			; ⬹	Leftwards Arrow With Tail With Vertical Stroke
(char-name '|nVleftarrowtail| (integer->char #x02B3A))			; ⬺	Leftwards Arrow With Tail With Double Vertical Stroke
(char-name '|twoheadleftarrowtail| (integer->char #x02B3B))			; ⬻	Leftwards Two-Headed Arrow With Tail
(char-name '|nvtwoheadleftarrowtail| (integer->char #x02B3C))			; ⬼	Leftwards Two-Headed Arrow With Tail With Vertical Stroke
(char-name '|nVtwoheadleftarrowtail| (integer->char #x02B3D))			; ⬽	Leftwards Two-Headed Arrow With Tail With Double Vertical Stroke
(char-name '|leftarrowx| (integer->char #x02B3E))			; ⬾	Leftwards Arrow Through X
(char-name '|leftcurvedarrow| (integer->char #x02B3F))			; ⬿	Wave Arrow Pointing Directly Left
(char-name '|equalleftarrow| (integer->char #x02B40))			; ⭀	Equals Sign Above Leftwards Arrow
(char-name '|bsimilarleftarrow| (integer->char #x02B41))			; ⭁	Reverse Tilde Operator Above Leftwards Arrow
(char-name '|leftarrowbackapprox| (integer->char #x02B42))			; ⭂	Leftwards Arrow Above Reverse Almost Equal To
(char-name '|rightarrowgtr| (integer->char #x02B43))			; ⭃	Rightwards Arrow Through Greater-Than
(char-name '|rightarrowsupset| (integer->char #x02B44))			; ⭄	Rightwards Arrow Through Superset
(char-name '|LLeftarrow| (integer->char #x02B45))			; ⭅	Leftwards Quadruple Arrow
(char-name '|RRightarrow| (integer->char #x02B46))			; ⭆	Rightwards Quadruple Arrow
(char-name '|bsimilarrightarrow| (integer->char #x02B47))			; ⭇	Reverse Tilde Operator Above Rightwards Arrow
(char-name '|rightarrowbackapprox| (integer->char #x02B48))			; ⭈	Rightwards Arrow Above Reverse Almost Equal To
(char-name '|similarleftarrow| (integer->char #x02B49))			; ⭉	Tilde Operator Above Leftwards Arrow
(char-name '|leftarrowapprox| (integer->char #x02B4A))			; ⭊	Leftwards Arrow Above Almost Equal To
(char-name '|leftarrowbsimilar| (integer->char #x02B4B))			; ⭋	Leftwards Arrow Above Reverse Tilde Operator
(char-name '|rightarrowbsimilar| (integer->char #x02B4C))			; ⭌	Rightwards Arrow Above Reverse Tilde Operator
(char-name '|medwhitestar| (integer->char #x02B50))			; ⭐	White Medium Star
(char-name '|:star:| (integer->char #x02B50))			; ⭐	White Medium Star
(char-name '|medblackstar| (integer->char #x02B51))			; ⭑	Black Small Star
(char-name '|smwhitestar| (integer->char #x02B52))			; ⭒	White Small Star
(char-name '|rightpentagonblack| (integer->char #x02B53))			; ⭓	Black Right-Pointing Pentagon
(char-name '|rightpentagon| (integer->char #x02B54))			; ⭔	White Right-Pointing Pentagon
(char-name '|:o:| (integer->char #x02B55))			; ⭕	Heavy Large Circle
(char-name '|_j| (integer->char #x02C7C))			; ⱼ	Latin Subscript Small Letter J
(char-name '|^V| (integer->char #x02C7D))			; ⱽ	Modifier Letter Capital V
(char-name '|postalmark| (integer->char #x03012))			; 〒	Postal Mark
(char-name '|:wavy_dash:| (integer->char #x03030))			; 〰	Wavy Dash
(char-name '|:part_alternation_mark:| (integer->char #x0303D))			; 〽	Part Alternation Mark
(char-name '|:congratulations:| (integer->char #x03297))			; ㊗	Circled Ideograph Congratulation
(char-name '|:secret:| (integer->char #x03299))			; ㊙	Circled Ideograph Secret
(char-name '|bfA| (integer->char #x1D400))			; 𝐀	Mathematical Bold Capital A
(char-name '|bfB| (integer->char #x1D401))			; 𝐁	Mathematical Bold Capital B
(char-name '|bfC| (integer->char #x1D402))			; 𝐂	Mathematical Bold Capital C
(char-name '|bfD| (integer->char #x1D403))			; 𝐃	Mathematical Bold Capital D
(char-name '|bfE| (integer->char #x1D404))			; 𝐄	Mathematical Bold Capital E
(char-name '|bfF| (integer->char #x1D405))			; 𝐅	Mathematical Bold Capital F
(char-name '|bfG| (integer->char #x1D406))			; 𝐆	Mathematical Bold Capital G
(char-name '|bfH| (integer->char #x1D407))			; 𝐇	Mathematical Bold Capital H
(char-name '|bfI| (integer->char #x1D408))			; 𝐈	Mathematical Bold Capital I
(char-name '|bfJ| (integer->char #x1D409))			; 𝐉	Mathematical Bold Capital J
(char-name '|bfK| (integer->char #x1D40A))			; 𝐊	Mathematical Bold Capital K
(char-name '|bfL| (integer->char #x1D40B))			; 𝐋	Mathematical Bold Capital L
(char-name '|bfM| (integer->char #x1D40C))			; 𝐌	Mathematical Bold Capital M
(char-name '|bfN| (integer->char #x1D40D))			; 𝐍	Mathematical Bold Capital N
(char-name '|bfO| (integer->char #x1D40E))			; 𝐎	Mathematical Bold Capital O
(char-name '|bfP| (integer->char #x1D40F))			; 𝐏	Mathematical Bold Capital P
(char-name '|bfQ| (integer->char #x1D410))			; 𝐐	Mathematical Bold Capital Q
(char-name '|bfR| (integer->char #x1D411))			; 𝐑	Mathematical Bold Capital R
(char-name '|bfS| (integer->char #x1D412))			; 𝐒	Mathematical Bold Capital S
(char-name '|bfT| (integer->char #x1D413))			; 𝐓	Mathematical Bold Capital T
(char-name '|bfU| (integer->char #x1D414))			; 𝐔	Mathematical Bold Capital U
(char-name '|bfV| (integer->char #x1D415))			; 𝐕	Mathematical Bold Capital V
(char-name '|bfW| (integer->char #x1D416))			; 𝐖	Mathematical Bold Capital W
(char-name '|bfX| (integer->char #x1D417))			; 𝐗	Mathematical Bold Capital X
(char-name '|bfY| (integer->char #x1D418))			; 𝐘	Mathematical Bold Capital Y
(char-name '|bfZ| (integer->char #x1D419))			; 𝐙	Mathematical Bold Capital Z
(char-name '|bfa| (integer->char #x1D41A))			; 𝐚	Mathematical Bold Small A
(char-name '|bfb| (integer->char #x1D41B))			; 𝐛	Mathematical Bold Small B
(char-name '|bfc| (integer->char #x1D41C))			; 𝐜	Mathematical Bold Small C
(char-name '|bfd| (integer->char #x1D41D))			; 𝐝	Mathematical Bold Small D
(char-name '|bfe| (integer->char #x1D41E))			; 𝐞	Mathematical Bold Small E
(char-name '|bff| (integer->char #x1D41F))			; 𝐟	Mathematical Bold Small F
(char-name '|bfg| (integer->char #x1D420))			; 𝐠	Mathematical Bold Small G
(char-name '|bfh| (integer->char #x1D421))			; 𝐡	Mathematical Bold Small H
(char-name '|bfi| (integer->char #x1D422))			; 𝐢	Mathematical Bold Small I
(char-name '|bfj| (integer->char #x1D423))			; 𝐣	Mathematical Bold Small J
(char-name '|bfk| (integer->char #x1D424))			; 𝐤	Mathematical Bold Small K
(char-name '|bfl| (integer->char #x1D425))			; 𝐥	Mathematical Bold Small L
(char-name '|bfm| (integer->char #x1D426))			; 𝐦	Mathematical Bold Small M
(char-name '|bfn| (integer->char #x1D427))			; 𝐧	Mathematical Bold Small N
(char-name '|bfo| (integer->char #x1D428))			; 𝐨	Mathematical Bold Small O
(char-name '|bfp| (integer->char #x1D429))			; 𝐩	Mathematical Bold Small P
(char-name '|bfq| (integer->char #x1D42A))			; 𝐪	Mathematical Bold Small Q
(char-name '|bfr| (integer->char #x1D42B))			; 𝐫	Mathematical Bold Small R
(char-name '|bfs| (integer->char #x1D42C))			; 𝐬	Mathematical Bold Small S
(char-name '|bft| (integer->char #x1D42D))			; 𝐭	Mathematical Bold Small T
(char-name '|bfu| (integer->char #x1D42E))			; 𝐮	Mathematical Bold Small U
(char-name '|bfv| (integer->char #x1D42F))			; 𝐯	Mathematical Bold Small V
(char-name '|bfw| (integer->char #x1D430))			; 𝐰	Mathematical Bold Small W
(char-name '|bfx| (integer->char #x1D431))			; 𝐱	Mathematical Bold Small X
(char-name '|bfy| (integer->char #x1D432))			; 𝐲	Mathematical Bold Small Y
(char-name '|bfz| (integer->char #x1D433))			; 𝐳	Mathematical Bold Small Z
(char-name '|itA| (integer->char #x1D434))			; 𝐴	Mathematical Italic Capital A
(char-name '|itB| (integer->char #x1D435))			; 𝐵	Mathematical Italic Capital B
(char-name '|itC| (integer->char #x1D436))			; 𝐶	Mathematical Italic Capital C
(char-name '|itD| (integer->char #x1D437))			; 𝐷	Mathematical Italic Capital D
(char-name '|itE| (integer->char #x1D438))			; 𝐸	Mathematical Italic Capital E
(char-name '|itF| (integer->char #x1D439))			; 𝐹	Mathematical Italic Capital F
(char-name '|itG| (integer->char #x1D43A))			; 𝐺	Mathematical Italic Capital G
(char-name '|itH| (integer->char #x1D43B))			; 𝐻	Mathematical Italic Capital H
(char-name '|itI| (integer->char #x1D43C))			; 𝐼	Mathematical Italic Capital I
(char-name '|itJ| (integer->char #x1D43D))			; 𝐽	Mathematical Italic Capital J
(char-name '|itK| (integer->char #x1D43E))			; 𝐾	Mathematical Italic Capital K
(char-name '|itL| (integer->char #x1D43F))			; 𝐿	Mathematical Italic Capital L
(char-name '|itM| (integer->char #x1D440))			; 𝑀	Mathematical Italic Capital M
(char-name '|itN| (integer->char #x1D441))			; 𝑁	Mathematical Italic Capital N
(char-name '|itO| (integer->char #x1D442))			; 𝑂	Mathematical Italic Capital O
(char-name '|itP| (integer->char #x1D443))			; 𝑃	Mathematical Italic Capital P
(char-name '|itQ| (integer->char #x1D444))			; 𝑄	Mathematical Italic Capital Q
(char-name '|itR| (integer->char #x1D445))			; 𝑅	Mathematical Italic Capital R
(char-name '|itS| (integer->char #x1D446))			; 𝑆	Mathematical Italic Capital S
(char-name '|itT| (integer->char #x1D447))			; 𝑇	Mathematical Italic Capital T
(char-name '|itU| (integer->char #x1D448))			; 𝑈	Mathematical Italic Capital U
(char-name '|itV| (integer->char #x1D449))			; 𝑉	Mathematical Italic Capital V
(char-name '|itW| (integer->char #x1D44A))			; 𝑊	Mathematical Italic Capital W
(char-name '|itX| (integer->char #x1D44B))			; 𝑋	Mathematical Italic Capital X
(char-name '|itY| (integer->char #x1D44C))			; 𝑌	Mathematical Italic Capital Y
(char-name '|itZ| (integer->char #x1D44D))			; 𝑍	Mathematical Italic Capital Z
(char-name '|ita| (integer->char #x1D44E))			; 𝑎	Mathematical Italic Small A
(char-name '|itb| (integer->char #x1D44F))			; 𝑏	Mathematical Italic Small B
(char-name '|itc| (integer->char #x1D450))			; 𝑐	Mathematical Italic Small C
(char-name '|itd| (integer->char #x1D451))			; 𝑑	Mathematical Italic Small D
(char-name '|ite| (integer->char #x1D452))			; 𝑒	Mathematical Italic Small E
(char-name '|itf| (integer->char #x1D453))			; 𝑓	Mathematical Italic Small F
(char-name '|itg| (integer->char #x1D454))			; 𝑔	Mathematical Italic Small G
(char-name '|iti| (integer->char #x1D456))			; 𝑖	Mathematical Italic Small I
(char-name '|itj| (integer->char #x1D457))			; 𝑗	Mathematical Italic Small J
(char-name '|itk| (integer->char #x1D458))			; 𝑘	Mathematical Italic Small K
(char-name '|itl| (integer->char #x1D459))			; 𝑙	Mathematical Italic Small L
(char-name '|itm| (integer->char #x1D45A))			; 𝑚	Mathematical Italic Small M
(char-name '|itn| (integer->char #x1D45B))			; 𝑛	Mathematical Italic Small N
(char-name '|ito| (integer->char #x1D45C))			; 𝑜	Mathematical Italic Small O
(char-name '|itp| (integer->char #x1D45D))			; 𝑝	Mathematical Italic Small P
(char-name '|itq| (integer->char #x1D45E))			; 𝑞	Mathematical Italic Small Q
(char-name '|itr| (integer->char #x1D45F))			; 𝑟	Mathematical Italic Small R
(char-name '|its| (integer->char #x1D460))			; 𝑠	Mathematical Italic Small S
(char-name '|itt| (integer->char #x1D461))			; 𝑡	Mathematical Italic Small T
(char-name '|itu| (integer->char #x1D462))			; 𝑢	Mathematical Italic Small U
(char-name '|itv| (integer->char #x1D463))			; 𝑣	Mathematical Italic Small V
(char-name '|itw| (integer->char #x1D464))			; 𝑤	Mathematical Italic Small W
(char-name '|itx| (integer->char #x1D465))			; 𝑥	Mathematical Italic Small X
(char-name '|ity| (integer->char #x1D466))			; 𝑦	Mathematical Italic Small Y
(char-name '|itz| (integer->char #x1D467))			; 𝑧	Mathematical Italic Small Z
(char-name '|biA| (integer->char #x1D468))			; 𝑨	Mathematical Bold Italic Capital A
(char-name '|biB| (integer->char #x1D469))			; 𝑩	Mathematical Bold Italic Capital B
(char-name '|biC| (integer->char #x1D46A))			; 𝑪	Mathematical Bold Italic Capital C
(char-name '|biD| (integer->char #x1D46B))			; 𝑫	Mathematical Bold Italic Capital D
(char-name '|biE| (integer->char #x1D46C))			; 𝑬	Mathematical Bold Italic Capital E
(char-name '|biF| (integer->char #x1D46D))			; 𝑭	Mathematical Bold Italic Capital F
(char-name '|biG| (integer->char #x1D46E))			; 𝑮	Mathematical Bold Italic Capital G
(char-name '|biH| (integer->char #x1D46F))			; 𝑯	Mathematical Bold Italic Capital H
(char-name '|biI| (integer->char #x1D470))			; 𝑰	Mathematical Bold Italic Capital I
(char-name '|biJ| (integer->char #x1D471))			; 𝑱	Mathematical Bold Italic Capital J
(char-name '|biK| (integer->char #x1D472))			; 𝑲	Mathematical Bold Italic Capital K
(char-name '|biL| (integer->char #x1D473))			; 𝑳	Mathematical Bold Italic Capital L
(char-name '|biM| (integer->char #x1D474))			; 𝑴	Mathematical Bold Italic Capital M
(char-name '|biN| (integer->char #x1D475))			; 𝑵	Mathematical Bold Italic Capital N
(char-name '|biO| (integer->char #x1D476))			; 𝑶	Mathematical Bold Italic Capital O
(char-name '|biP| (integer->char #x1D477))			; 𝑷	Mathematical Bold Italic Capital P
(char-name '|biQ| (integer->char #x1D478))			; 𝑸	Mathematical Bold Italic Capital Q
(char-name '|biR| (integer->char #x1D479))			; 𝑹	Mathematical Bold Italic Capital R
(char-name '|biS| (integer->char #x1D47A))			; 𝑺	Mathematical Bold Italic Capital S
(char-name '|biT| (integer->char #x1D47B))			; 𝑻	Mathematical Bold Italic Capital T
(char-name '|biU| (integer->char #x1D47C))			; 𝑼	Mathematical Bold Italic Capital U
(char-name '|biV| (integer->char #x1D47D))			; 𝑽	Mathematical Bold Italic Capital V
(char-name '|biW| (integer->char #x1D47E))			; 𝑾	Mathematical Bold Italic Capital W
(char-name '|biX| (integer->char #x1D47F))			; 𝑿	Mathematical Bold Italic Capital X
(char-name '|biY| (integer->char #x1D480))			; 𝒀	Mathematical Bold Italic Capital Y
(char-name '|biZ| (integer->char #x1D481))			; 𝒁	Mathematical Bold Italic Capital Z
(char-name '|bia| (integer->char #x1D482))			; 𝒂	Mathematical Bold Italic Small A
(char-name '|bib| (integer->char #x1D483))			; 𝒃	Mathematical Bold Italic Small B
(char-name '|bic| (integer->char #x1D484))			; 𝒄	Mathematical Bold Italic Small C
(char-name '|bid| (integer->char #x1D485))			; 𝒅	Mathematical Bold Italic Small D
(char-name '|bie| (integer->char #x1D486))			; 𝒆	Mathematical Bold Italic Small E
(char-name '|bif| (integer->char #x1D487))			; 𝒇	Mathematical Bold Italic Small F
(char-name '|big| (integer->char #x1D488))			; 𝒈	Mathematical Bold Italic Small G
(char-name '|bih| (integer->char #x1D489))			; 𝒉	Mathematical Bold Italic Small H
(char-name '|bii| (integer->char #x1D48A))			; 𝒊	Mathematical Bold Italic Small I
(char-name '|bij| (integer->char #x1D48B))			; 𝒋	Mathematical Bold Italic Small J
(char-name '|bik| (integer->char #x1D48C))			; 𝒌	Mathematical Bold Italic Small K
(char-name '|bil| (integer->char #x1D48D))			; 𝒍	Mathematical Bold Italic Small L
(char-name '|bim| (integer->char #x1D48E))			; 𝒎	Mathematical Bold Italic Small M
(char-name '|bin| (integer->char #x1D48F))			; 𝒏	Mathematical Bold Italic Small N
(char-name '|bio| (integer->char #x1D490))			; 𝒐	Mathematical Bold Italic Small O
(char-name '|bip| (integer->char #x1D491))			; 𝒑	Mathematical Bold Italic Small P
(char-name '|biq| (integer->char #x1D492))			; 𝒒	Mathematical Bold Italic Small Q
(char-name '|bir| (integer->char #x1D493))			; 𝒓	Mathematical Bold Italic Small R
(char-name '|bis| (integer->char #x1D494))			; 𝒔	Mathematical Bold Italic Small S
(char-name '|bit| (integer->char #x1D495))			; 𝒕	Mathematical Bold Italic Small T
(char-name '|biu| (integer->char #x1D496))			; 𝒖	Mathematical Bold Italic Small U
(char-name '|biv| (integer->char #x1D497))			; 𝒗	Mathematical Bold Italic Small V
(char-name '|biw| (integer->char #x1D498))			; 𝒘	Mathematical Bold Italic Small W
(char-name '|bix| (integer->char #x1D499))			; 𝒙	Mathematical Bold Italic Small X
(char-name '|biy| (integer->char #x1D49A))			; 𝒚	Mathematical Bold Italic Small Y
(char-name '|biz| (integer->char #x1D49B))			; 𝒛	Mathematical Bold Italic Small Z
(char-name '|scrA| (integer->char #x1D49C))			; 𝒜	Mathematical Script Capital A
(char-name '|scrC| (integer->char #x1D49E))			; 𝒞	Mathematical Script Capital C
(char-name '|scrD| (integer->char #x1D49F))			; 𝒟	Mathematical Script Capital D
(char-name '|scrG| (integer->char #x1D4A2))			; 𝒢	Mathematical Script Capital G
(char-name '|scrJ| (integer->char #x1D4A5))			; 𝒥	Mathematical Script Capital J
(char-name '|scrK| (integer->char #x1D4A6))			; 𝒦	Mathematical Script Capital K
(char-name '|scrN| (integer->char #x1D4A9))			; 𝒩	Mathematical Script Capital N
(char-name '|scrO| (integer->char #x1D4AA))			; 𝒪	Mathematical Script Capital O
(char-name '|scrP| (integer->char #x1D4AB))			; 𝒫	Mathematical Script Capital P
(char-name '|scrQ| (integer->char #x1D4AC))			; 𝒬	Mathematical Script Capital Q
(char-name '|scrS| (integer->char #x1D4AE))			; 𝒮	Mathematical Script Capital S
(char-name '|scrT| (integer->char #x1D4AF))			; 𝒯	Mathematical Script Capital T
(char-name '|scrU| (integer->char #x1D4B0))			; 𝒰	Mathematical Script Capital U
(char-name '|scrV| (integer->char #x1D4B1))			; 𝒱	Mathematical Script Capital V
(char-name '|scrW| (integer->char #x1D4B2))			; 𝒲	Mathematical Script Capital W
(char-name '|scrX| (integer->char #x1D4B3))			; 𝒳	Mathematical Script Capital X
(char-name '|scrY| (integer->char #x1D4B4))			; 𝒴	Mathematical Script Capital Y
(char-name '|scrZ| (integer->char #x1D4B5))			; 𝒵	Mathematical Script Capital Z
(char-name '|scra| (integer->char #x1D4B6))			; 𝒶	Mathematical Script Small A
(char-name '|scrb| (integer->char #x1D4B7))			; 𝒷	Mathematical Script Small B
(char-name '|scrc| (integer->char #x1D4B8))			; 𝒸	Mathematical Script Small C
(char-name '|scrd| (integer->char #x1D4B9))			; 𝒹	Mathematical Script Small D
(char-name '|scrf| (integer->char #x1D4BB))			; 𝒻	Mathematical Script Small F
(char-name '|scrh| (integer->char #x1D4BD))			; 𝒽	Mathematical Script Small H
(char-name '|scri| (integer->char #x1D4BE))			; 𝒾	Mathematical Script Small I
(char-name '|scrj| (integer->char #x1D4BF))			; 𝒿	Mathematical Script Small J
(char-name '|scrk| (integer->char #x1D4C0))			; 𝓀	Mathematical Script Small K
(char-name '|scrl| (integer->char #x1D4C1))			; 𝓁	Mathematical Script Small L
(char-name '|scrm| (integer->char #x1D4C2))			; 𝓂	Mathematical Script Small M
(char-name '|scrn| (integer->char #x1D4C3))			; 𝓃	Mathematical Script Small N
(char-name '|scrp| (integer->char #x1D4C5))			; 𝓅	Mathematical Script Small P
(char-name '|scrq| (integer->char #x1D4C6))			; 𝓆	Mathematical Script Small Q
(char-name '|scrr| (integer->char #x1D4C7))			; 𝓇	Mathematical Script Small R
(char-name '|scrs| (integer->char #x1D4C8))			; 𝓈	Mathematical Script Small S
(char-name '|scrt| (integer->char #x1D4C9))			; 𝓉	Mathematical Script Small T
(char-name '|scru| (integer->char #x1D4CA))			; 𝓊	Mathematical Script Small U
(char-name '|scrv| (integer->char #x1D4CB))			; 𝓋	Mathematical Script Small V
(char-name '|scrw| (integer->char #x1D4CC))			; 𝓌	Mathematical Script Small W
(char-name '|scrx| (integer->char #x1D4CD))			; 𝓍	Mathematical Script Small X
(char-name '|scry| (integer->char #x1D4CE))			; 𝓎	Mathematical Script Small Y
(char-name '|scrz| (integer->char #x1D4CF))			; 𝓏	Mathematical Script Small Z
(char-name '|bscrA| (integer->char #x1D4D0))			; 𝓐	Mathematical Bold Script Capital A
(char-name '|bscrB| (integer->char #x1D4D1))			; 𝓑	Mathematical Bold Script Capital B
(char-name '|bscrC| (integer->char #x1D4D2))			; 𝓒	Mathematical Bold Script Capital C
(char-name '|bscrD| (integer->char #x1D4D3))			; 𝓓	Mathematical Bold Script Capital D
(char-name '|bscrE| (integer->char #x1D4D4))			; 𝓔	Mathematical Bold Script Capital E
(char-name '|bscrF| (integer->char #x1D4D5))			; 𝓕	Mathematical Bold Script Capital F
(char-name '|bscrG| (integer->char #x1D4D6))			; 𝓖	Mathematical Bold Script Capital G
(char-name '|bscrH| (integer->char #x1D4D7))			; 𝓗	Mathematical Bold Script Capital H
(char-name '|bscrI| (integer->char #x1D4D8))			; 𝓘	Mathematical Bold Script Capital I
(char-name '|bscrJ| (integer->char #x1D4D9))			; 𝓙	Mathematical Bold Script Capital J
(char-name '|bscrK| (integer->char #x1D4DA))			; 𝓚	Mathematical Bold Script Capital K
(char-name '|bscrL| (integer->char #x1D4DB))			; 𝓛	Mathematical Bold Script Capital L
(char-name '|bscrM| (integer->char #x1D4DC))			; 𝓜	Mathematical Bold Script Capital M
(char-name '|bscrN| (integer->char #x1D4DD))			; 𝓝	Mathematical Bold Script Capital N
(char-name '|bscrO| (integer->char #x1D4DE))			; 𝓞	Mathematical Bold Script Capital O
(char-name '|bscrP| (integer->char #x1D4DF))			; 𝓟	Mathematical Bold Script Capital P
(char-name '|bscrQ| (integer->char #x1D4E0))			; 𝓠	Mathematical Bold Script Capital Q
(char-name '|bscrR| (integer->char #x1D4E1))			; 𝓡	Mathematical Bold Script Capital R
(char-name '|bscrS| (integer->char #x1D4E2))			; 𝓢	Mathematical Bold Script Capital S
(char-name '|bscrT| (integer->char #x1D4E3))			; 𝓣	Mathematical Bold Script Capital T
(char-name '|bscrU| (integer->char #x1D4E4))			; 𝓤	Mathematical Bold Script Capital U
(char-name '|bscrV| (integer->char #x1D4E5))			; 𝓥	Mathematical Bold Script Capital V
(char-name '|bscrW| (integer->char #x1D4E6))			; 𝓦	Mathematical Bold Script Capital W
(char-name '|bscrX| (integer->char #x1D4E7))			; 𝓧	Mathematical Bold Script Capital X
(char-name '|bscrY| (integer->char #x1D4E8))			; 𝓨	Mathematical Bold Script Capital Y
(char-name '|bscrZ| (integer->char #x1D4E9))			; 𝓩	Mathematical Bold Script Capital Z
(char-name '|bscra| (integer->char #x1D4EA))			; 𝓪	Mathematical Bold Script Small A
(char-name '|bscrb| (integer->char #x1D4EB))			; 𝓫	Mathematical Bold Script Small B
(char-name '|bscrc| (integer->char #x1D4EC))			; 𝓬	Mathematical Bold Script Small C
(char-name '|bscrd| (integer->char #x1D4ED))			; 𝓭	Mathematical Bold Script Small D
(char-name '|bscre| (integer->char #x1D4EE))			; 𝓮	Mathematical Bold Script Small E
(char-name '|bscrf| (integer->char #x1D4EF))			; 𝓯	Mathematical Bold Script Small F
(char-name '|bscrg| (integer->char #x1D4F0))			; 𝓰	Mathematical Bold Script Small G
(char-name '|bscrh| (integer->char #x1D4F1))			; 𝓱	Mathematical Bold Script Small H
(char-name '|bscri| (integer->char #x1D4F2))			; 𝓲	Mathematical Bold Script Small I
(char-name '|bscrj| (integer->char #x1D4F3))			; 𝓳	Mathematical Bold Script Small J
(char-name '|bscrk| (integer->char #x1D4F4))			; 𝓴	Mathematical Bold Script Small K
(char-name '|bscrl| (integer->char #x1D4F5))			; 𝓵	Mathematical Bold Script Small L
(char-name '|bscrm| (integer->char #x1D4F6))			; 𝓶	Mathematical Bold Script Small M
(char-name '|bscrn| (integer->char #x1D4F7))			; 𝓷	Mathematical Bold Script Small N
(char-name '|bscro| (integer->char #x1D4F8))			; 𝓸	Mathematical Bold Script Small O
(char-name '|bscrp| (integer->char #x1D4F9))			; 𝓹	Mathematical Bold Script Small P
(char-name '|bscrq| (integer->char #x1D4FA))			; 𝓺	Mathematical Bold Script Small Q
(char-name '|bscrr| (integer->char #x1D4FB))			; 𝓻	Mathematical Bold Script Small R
(char-name '|bscrs| (integer->char #x1D4FC))			; 𝓼	Mathematical Bold Script Small S
(char-name '|bscrt| (integer->char #x1D4FD))			; 𝓽	Mathematical Bold Script Small T
(char-name '|bscru| (integer->char #x1D4FE))			; 𝓾	Mathematical Bold Script Small U
(char-name '|bscrv| (integer->char #x1D4FF))			; 𝓿	Mathematical Bold Script Small V
(char-name '|bscrw| (integer->char #x1D500))			; 𝔀	Mathematical Bold Script Small W
(char-name '|bscrx| (integer->char #x1D501))			; 𝔁	Mathematical Bold Script Small X
(char-name '|bscry| (integer->char #x1D502))			; 𝔂	Mathematical Bold Script Small Y
(char-name '|bscrz| (integer->char #x1D503))			; 𝔃	Mathematical Bold Script Small Z
(char-name '|frakA| (integer->char #x1D504))			; 𝔄	Mathematical Fraktur Capital A
(char-name '|frakB| (integer->char #x1D505))			; 𝔅	Mathematical Fraktur Capital B
(char-name '|frakD| (integer->char #x1D507))			; 𝔇	Mathematical Fraktur Capital D
(char-name '|frakE| (integer->char #x1D508))			; 𝔈	Mathematical Fraktur Capital E
(char-name '|frakF| (integer->char #x1D509))			; 𝔉	Mathematical Fraktur Capital F
(char-name '|frakG| (integer->char #x1D50A))			; 𝔊	Mathematical Fraktur Capital G
(char-name '|frakJ| (integer->char #x1D50D))			; 𝔍	Mathematical Fraktur Capital J
(char-name '|frakK| (integer->char #x1D50E))			; 𝔎	Mathematical Fraktur Capital K
(char-name '|frakL| (integer->char #x1D50F))			; 𝔏	Mathematical Fraktur Capital L
(char-name '|frakM| (integer->char #x1D510))			; 𝔐	Mathematical Fraktur Capital M
(char-name '|frakN| (integer->char #x1D511))			; 𝔑	Mathematical Fraktur Capital N
(char-name '|frakO| (integer->char #x1D512))			; 𝔒	Mathematical Fraktur Capital O
(char-name '|frakP| (integer->char #x1D513))			; 𝔓	Mathematical Fraktur Capital P
(char-name '|frakQ| (integer->char #x1D514))			; 𝔔	Mathematical Fraktur Capital Q
(char-name '|frakS| (integer->char #x1D516))			; 𝔖	Mathematical Fraktur Capital S
(char-name '|frakT| (integer->char #x1D517))			; 𝔗	Mathematical Fraktur Capital T
(char-name '|frakU| (integer->char #x1D518))			; 𝔘	Mathematical Fraktur Capital U
(char-name '|frakV| (integer->char #x1D519))			; 𝔙	Mathematical Fraktur Capital V
(char-name '|frakW| (integer->char #x1D51A))			; 𝔚	Mathematical Fraktur Capital W
(char-name '|frakX| (integer->char #x1D51B))			; 𝔛	Mathematical Fraktur Capital X
(char-name '|frakY| (integer->char #x1D51C))			; 𝔜	Mathematical Fraktur Capital Y
(char-name '|fraka| (integer->char #x1D51E))			; 𝔞	Mathematical Fraktur Small A
(char-name '|frakb| (integer->char #x1D51F))			; 𝔟	Mathematical Fraktur Small B
(char-name '|frakc| (integer->char #x1D520))			; 𝔠	Mathematical Fraktur Small C
(char-name '|frakd| (integer->char #x1D521))			; 𝔡	Mathematical Fraktur Small D
(char-name '|frake| (integer->char #x1D522))			; 𝔢	Mathematical Fraktur Small E
(char-name '|frakf| (integer->char #x1D523))			; 𝔣	Mathematical Fraktur Small F
(char-name '|frakg| (integer->char #x1D524))			; 𝔤	Mathematical Fraktur Small G
(char-name '|frakh| (integer->char #x1D525))			; 𝔥	Mathematical Fraktur Small H
(char-name '|fraki| (integer->char #x1D526))			; 𝔦	Mathematical Fraktur Small I
(char-name '|frakj| (integer->char #x1D527))			; 𝔧	Mathematical Fraktur Small J
(char-name '|frakk| (integer->char #x1D528))			; 𝔨	Mathematical Fraktur Small K
(char-name '|frakl| (integer->char #x1D529))			; 𝔩	Mathematical Fraktur Small L
(char-name '|frakm| (integer->char #x1D52A))			; 𝔪	Mathematical Fraktur Small M
(char-name '|frakn| (integer->char #x1D52B))			; 𝔫	Mathematical Fraktur Small N
(char-name '|frako| (integer->char #x1D52C))			; 𝔬	Mathematical Fraktur Small O
(char-name '|frakp| (integer->char #x1D52D))			; 𝔭	Mathematical Fraktur Small P
(char-name '|frakq| (integer->char #x1D52E))			; 𝔮	Mathematical Fraktur Small Q
(char-name '|frakr| (integer->char #x1D52F))			; 𝔯	Mathematical Fraktur Small R
(char-name '|fraks| (integer->char #x1D530))			; 𝔰	Mathematical Fraktur Small S
(char-name '|frakt| (integer->char #x1D531))			; 𝔱	Mathematical Fraktur Small T
(char-name '|fraku| (integer->char #x1D532))			; 𝔲	Mathematical Fraktur Small U
(char-name '|frakv| (integer->char #x1D533))			; 𝔳	Mathematical Fraktur Small V
(char-name '|frakw| (integer->char #x1D534))			; 𝔴	Mathematical Fraktur Small W
(char-name '|frakx| (integer->char #x1D535))			; 𝔵	Mathematical Fraktur Small X
(char-name '|fraky| (integer->char #x1D536))			; 𝔶	Mathematical Fraktur Small Y
(char-name '|frakz| (integer->char #x1D537))			; 𝔷	Mathematical Fraktur Small Z
(char-name '|bbA| (integer->char #x1D538))			; 𝔸	Mathematical Double-Struck Capital A
(char-name '|bbB| (integer->char #x1D539))			; 𝔹	Mathematical Double-Struck Capital B
(char-name '|bbD| (integer->char #x1D53B))			; 𝔻	Mathematical Double-Struck Capital D
(char-name '|bbE| (integer->char #x1D53C))			; 𝔼	Mathematical Double-Struck Capital E
(char-name '|bbF| (integer->char #x1D53D))			; 𝔽	Mathematical Double-Struck Capital F
(char-name '|bbG| (integer->char #x1D53E))			; 𝔾	Mathematical Double-Struck Capital G
(char-name '|bbI| (integer->char #x1D540))			; 𝕀	Mathematical Double-Struck Capital I
(char-name '|bbJ| (integer->char #x1D541))			; 𝕁	Mathematical Double-Struck Capital J
(char-name '|bbK| (integer->char #x1D542))			; 𝕂	Mathematical Double-Struck Capital K
(char-name '|bbL| (integer->char #x1D543))			; 𝕃	Mathematical Double-Struck Capital L
(char-name '|bbM| (integer->char #x1D544))			; 𝕄	Mathematical Double-Struck Capital M
(char-name '|bbO| (integer->char #x1D546))			; 𝕆	Mathematical Double-Struck Capital O
(char-name '|bbS| (integer->char #x1D54A))			; 𝕊	Mathematical Double-Struck Capital S
(char-name '|bbT| (integer->char #x1D54B))			; 𝕋	Mathematical Double-Struck Capital T
(char-name '|bbU| (integer->char #x1D54C))			; 𝕌	Mathematical Double-Struck Capital U
(char-name '|bbV| (integer->char #x1D54D))			; 𝕍	Mathematical Double-Struck Capital V
(char-name '|bbW| (integer->char #x1D54E))			; 𝕎	Mathematical Double-Struck Capital W
(char-name '|bbX| (integer->char #x1D54F))			; 𝕏	Mathematical Double-Struck Capital X
(char-name '|bbY| (integer->char #x1D550))			; 𝕐	Mathematical Double-Struck Capital Y
(char-name '|bba| (integer->char #x1D552))			; 𝕒	Mathematical Double-Struck Small A
(char-name '|bbb| (integer->char #x1D553))			; 𝕓	Mathematical Double-Struck Small B
(char-name '|bbc| (integer->char #x1D554))			; 𝕔	Mathematical Double-Struck Small C
(char-name '|bbd| (integer->char #x1D555))			; 𝕕	Mathematical Double-Struck Small D
(char-name '|bbe| (integer->char #x1D556))			; 𝕖	Mathematical Double-Struck Small E
(char-name '|bbf| (integer->char #x1D557))			; 𝕗	Mathematical Double-Struck Small F
(char-name '|bbg| (integer->char #x1D558))			; 𝕘	Mathematical Double-Struck Small G
(char-name '|bbh| (integer->char #x1D559))			; 𝕙	Mathematical Double-Struck Small H
(char-name '|bbi| (integer->char #x1D55A))			; 𝕚	Mathematical Double-Struck Small I
(char-name '|bbj| (integer->char #x1D55B))			; 𝕛	Mathematical Double-Struck Small J
(char-name '|bbk| (integer->char #x1D55C))			; 𝕜	Mathematical Double-Struck Small K
(char-name '|bbl| (integer->char #x1D55D))			; 𝕝	Mathematical Double-Struck Small L
(char-name '|bbm| (integer->char #x1D55E))			; 𝕞	Mathematical Double-Struck Small M
(char-name '|bbn| (integer->char #x1D55F))			; 𝕟	Mathematical Double-Struck Small N
(char-name '|bbo| (integer->char #x1D560))			; 𝕠	Mathematical Double-Struck Small O
(char-name '|bbp| (integer->char #x1D561))			; 𝕡	Mathematical Double-Struck Small P
(char-name '|bbq| (integer->char #x1D562))			; 𝕢	Mathematical Double-Struck Small Q
(char-name '|bbr| (integer->char #x1D563))			; 𝕣	Mathematical Double-Struck Small R
(char-name '|bbs| (integer->char #x1D564))			; 𝕤	Mathematical Double-Struck Small S
(char-name '|bbt| (integer->char #x1D565))			; 𝕥	Mathematical Double-Struck Small T
(char-name '|bbu| (integer->char #x1D566))			; 𝕦	Mathematical Double-Struck Small U
(char-name '|bbv| (integer->char #x1D567))			; 𝕧	Mathematical Double-Struck Small V
(char-name '|bbw| (integer->char #x1D568))			; 𝕨	Mathematical Double-Struck Small W
(char-name '|bbx| (integer->char #x1D569))			; 𝕩	Mathematical Double-Struck Small X
(char-name '|bby| (integer->char #x1D56A))			; 𝕪	Mathematical Double-Struck Small Y
(char-name '|bbz| (integer->char #x1D56B))			; 𝕫	Mathematical Double-Struck Small Z
(char-name '|bfrakA| (integer->char #x1D56C))			; 𝕬	Mathematical Bold Fraktur Capital A
(char-name '|bfrakB| (integer->char #x1D56D))			; 𝕭	Mathematical Bold Fraktur Capital B
(char-name '|bfrakC| (integer->char #x1D56E))			; 𝕮	Mathematical Bold Fraktur Capital C
(char-name '|bfrakD| (integer->char #x1D56F))			; 𝕯	Mathematical Bold Fraktur Capital D
(char-name '|bfrakE| (integer->char #x1D570))			; 𝕰	Mathematical Bold Fraktur Capital E
(char-name '|bfrakF| (integer->char #x1D571))			; 𝕱	Mathematical Bold Fraktur Capital F
(char-name '|bfrakG| (integer->char #x1D572))			; 𝕲	Mathematical Bold Fraktur Capital G
(char-name '|bfrakH| (integer->char #x1D573))			; 𝕳	Mathematical Bold Fraktur Capital H
(char-name '|bfrakI| (integer->char #x1D574))			; 𝕴	Mathematical Bold Fraktur Capital I
(char-name '|bfrakJ| (integer->char #x1D575))			; 𝕵	Mathematical Bold Fraktur Capital J
(char-name '|bfrakK| (integer->char #x1D576))			; 𝕶	Mathematical Bold Fraktur Capital K
(char-name '|bfrakL| (integer->char #x1D577))			; 𝕷	Mathematical Bold Fraktur Capital L
(char-name '|bfrakM| (integer->char #x1D578))			; 𝕸	Mathematical Bold Fraktur Capital M
(char-name '|bfrakN| (integer->char #x1D579))			; 𝕹	Mathematical Bold Fraktur Capital N
(char-name '|bfrakO| (integer->char #x1D57A))			; 𝕺	Mathematical Bold Fraktur Capital O
(char-name '|bfrakP| (integer->char #x1D57B))			; 𝕻	Mathematical Bold Fraktur Capital P
(char-name '|bfrakQ| (integer->char #x1D57C))			; 𝕼	Mathematical Bold Fraktur Capital Q
(char-name '|bfrakR| (integer->char #x1D57D))			; 𝕽	Mathematical Bold Fraktur Capital R
(char-name '|bfrakS| (integer->char #x1D57E))			; 𝕾	Mathematical Bold Fraktur Capital S
(char-name '|bfrakT| (integer->char #x1D57F))			; 𝕿	Mathematical Bold Fraktur Capital T
(char-name '|bfrakU| (integer->char #x1D580))			; 𝖀	Mathematical Bold Fraktur Capital U
(char-name '|bfrakV| (integer->char #x1D581))			; 𝖁	Mathematical Bold Fraktur Capital V
(char-name '|bfrakW| (integer->char #x1D582))			; 𝖂	Mathematical Bold Fraktur Capital W
(char-name '|bfrakX| (integer->char #x1D583))			; 𝖃	Mathematical Bold Fraktur Capital X
(char-name '|bfrakY| (integer->char #x1D584))			; 𝖄	Mathematical Bold Fraktur Capital Y
(char-name '|bfrakZ| (integer->char #x1D585))			; 𝖅	Mathematical Bold Fraktur Capital Z
(char-name '|bfraka| (integer->char #x1D586))			; 𝖆	Mathematical Bold Fraktur Small A
(char-name '|bfrakb| (integer->char #x1D587))			; 𝖇	Mathematical Bold Fraktur Small B
(char-name '|bfrakc| (integer->char #x1D588))			; 𝖈	Mathematical Bold Fraktur Small C
(char-name '|bfrakd| (integer->char #x1D589))			; 𝖉	Mathematical Bold Fraktur Small D
(char-name '|bfrake| (integer->char #x1D58A))			; 𝖊	Mathematical Bold Fraktur Small E
(char-name '|bfrakf| (integer->char #x1D58B))			; 𝖋	Mathematical Bold Fraktur Small F
(char-name '|bfrakg| (integer->char #x1D58C))			; 𝖌	Mathematical Bold Fraktur Small G
(char-name '|bfrakh| (integer->char #x1D58D))			; 𝖍	Mathematical Bold Fraktur Small H
(char-name '|bfraki| (integer->char #x1D58E))			; 𝖎	Mathematical Bold Fraktur Small I
(char-name '|bfrakj| (integer->char #x1D58F))			; 𝖏	Mathematical Bold Fraktur Small J
(char-name '|bfrakk| (integer->char #x1D590))			; 𝖐	Mathematical Bold Fraktur Small K
(char-name '|bfrakl| (integer->char #x1D591))			; 𝖑	Mathematical Bold Fraktur Small L
(char-name '|bfrakm| (integer->char #x1D592))			; 𝖒	Mathematical Bold Fraktur Small M
(char-name '|bfrakn| (integer->char #x1D593))			; 𝖓	Mathematical Bold Fraktur Small N
(char-name '|bfrako| (integer->char #x1D594))			; 𝖔	Mathematical Bold Fraktur Small O
(char-name '|bfrakp| (integer->char #x1D595))			; 𝖕	Mathematical Bold Fraktur Small P
(char-name '|bfrakq| (integer->char #x1D596))			; 𝖖	Mathematical Bold Fraktur Small Q
(char-name '|bfrakr| (integer->char #x1D597))			; 𝖗	Mathematical Bold Fraktur Small R
(char-name '|bfraks| (integer->char #x1D598))			; 𝖘	Mathematical Bold Fraktur Small S
(char-name '|bfrakt| (integer->char #x1D599))			; 𝖙	Mathematical Bold Fraktur Small T
(char-name '|bfraku| (integer->char #x1D59A))			; 𝖚	Mathematical Bold Fraktur Small U
(char-name '|bfrakv| (integer->char #x1D59B))			; 𝖛	Mathematical Bold Fraktur Small V
(char-name '|bfrakw| (integer->char #x1D59C))			; 𝖜	Mathematical Bold Fraktur Small W
(char-name '|bfrakx| (integer->char #x1D59D))			; 𝖝	Mathematical Bold Fraktur Small X
(char-name '|bfraky| (integer->char #x1D59E))			; 𝖞	Mathematical Bold Fraktur Small Y
(char-name '|bfrakz| (integer->char #x1D59F))			; 𝖟	Mathematical Bold Fraktur Small Z
(char-name '|sansA| (integer->char #x1D5A0))			; 𝖠	Mathematical Sans-Serif Capital A
(char-name '|sansB| (integer->char #x1D5A1))			; 𝖡	Mathematical Sans-Serif Capital B
(char-name '|sansC| (integer->char #x1D5A2))			; 𝖢	Mathematical Sans-Serif Capital C
(char-name '|sansD| (integer->char #x1D5A3))			; 𝖣	Mathematical Sans-Serif Capital D
(char-name '|sansE| (integer->char #x1D5A4))			; 𝖤	Mathematical Sans-Serif Capital E
(char-name '|sansF| (integer->char #x1D5A5))			; 𝖥	Mathematical Sans-Serif Capital F
(char-name '|sansG| (integer->char #x1D5A6))			; 𝖦	Mathematical Sans-Serif Capital G
(char-name '|sansH| (integer->char #x1D5A7))			; 𝖧	Mathematical Sans-Serif Capital H
(char-name '|sansI| (integer->char #x1D5A8))			; 𝖨	Mathematical Sans-Serif Capital I
(char-name '|sansJ| (integer->char #x1D5A9))			; 𝖩	Mathematical Sans-Serif Capital J
(char-name '|sansK| (integer->char #x1D5AA))			; 𝖪	Mathematical Sans-Serif Capital K
(char-name '|sansL| (integer->char #x1D5AB))			; 𝖫	Mathematical Sans-Serif Capital L
(char-name '|sansM| (integer->char #x1D5AC))			; 𝖬	Mathematical Sans-Serif Capital M
(char-name '|sansN| (integer->char #x1D5AD))			; 𝖭	Mathematical Sans-Serif Capital N
(char-name '|sansO| (integer->char #x1D5AE))			; 𝖮	Mathematical Sans-Serif Capital O
(char-name '|sansP| (integer->char #x1D5AF))			; 𝖯	Mathematical Sans-Serif Capital P
(char-name '|sansQ| (integer->char #x1D5B0))			; 𝖰	Mathematical Sans-Serif Capital Q
(char-name '|sansR| (integer->char #x1D5B1))			; 𝖱	Mathematical Sans-Serif Capital R
(char-name '|sansS| (integer->char #x1D5B2))			; 𝖲	Mathematical Sans-Serif Capital S
(char-name '|sansT| (integer->char #x1D5B3))			; 𝖳	Mathematical Sans-Serif Capital T
(char-name '|sansU| (integer->char #x1D5B4))			; 𝖴	Mathematical Sans-Serif Capital U
(char-name '|sansV| (integer->char #x1D5B5))			; 𝖵	Mathematical Sans-Serif Capital V
(char-name '|sansW| (integer->char #x1D5B6))			; 𝖶	Mathematical Sans-Serif Capital W
(char-name '|sansX| (integer->char #x1D5B7))			; 𝖷	Mathematical Sans-Serif Capital X
(char-name '|sansY| (integer->char #x1D5B8))			; 𝖸	Mathematical Sans-Serif Capital Y
(char-name '|sansZ| (integer->char #x1D5B9))			; 𝖹	Mathematical Sans-Serif Capital Z
(char-name '|sansa| (integer->char #x1D5BA))			; 𝖺	Mathematical Sans-Serif Small A
(char-name '|sansb| (integer->char #x1D5BB))			; 𝖻	Mathematical Sans-Serif Small B
(char-name '|sansc| (integer->char #x1D5BC))			; 𝖼	Mathematical Sans-Serif Small C
(char-name '|sansd| (integer->char #x1D5BD))			; 𝖽	Mathematical Sans-Serif Small D
(char-name '|sanse| (integer->char #x1D5BE))			; 𝖾	Mathematical Sans-Serif Small E
(char-name '|sansf| (integer->char #x1D5BF))			; 𝖿	Mathematical Sans-Serif Small F
(char-name '|sansg| (integer->char #x1D5C0))			; 𝗀	Mathematical Sans-Serif Small G
(char-name '|sansh| (integer->char #x1D5C1))			; 𝗁	Mathematical Sans-Serif Small H
(char-name '|sansi| (integer->char #x1D5C2))			; 𝗂	Mathematical Sans-Serif Small I
(char-name '|sansj| (integer->char #x1D5C3))			; 𝗃	Mathematical Sans-Serif Small J
(char-name '|sansk| (integer->char #x1D5C4))			; 𝗄	Mathematical Sans-Serif Small K
(char-name '|sansl| (integer->char #x1D5C5))			; 𝗅	Mathematical Sans-Serif Small L
(char-name '|sansm| (integer->char #x1D5C6))			; 𝗆	Mathematical Sans-Serif Small M
(char-name '|sansn| (integer->char #x1D5C7))			; 𝗇	Mathematical Sans-Serif Small N
(char-name '|sanso| (integer->char #x1D5C8))			; 𝗈	Mathematical Sans-Serif Small O
(char-name '|sansp| (integer->char #x1D5C9))			; 𝗉	Mathematical Sans-Serif Small P
(char-name '|sansq| (integer->char #x1D5CA))			; 𝗊	Mathematical Sans-Serif Small Q
(char-name '|sansr| (integer->char #x1D5CB))			; 𝗋	Mathematical Sans-Serif Small R
(char-name '|sanss| (integer->char #x1D5CC))			; 𝗌	Mathematical Sans-Serif Small S
(char-name '|sanst| (integer->char #x1D5CD))			; 𝗍	Mathematical Sans-Serif Small T
(char-name '|sansu| (integer->char #x1D5CE))			; 𝗎	Mathematical Sans-Serif Small U
(char-name '|sansv| (integer->char #x1D5CF))			; 𝗏	Mathematical Sans-Serif Small V
(char-name '|sansw| (integer->char #x1D5D0))			; 𝗐	Mathematical Sans-Serif Small W
(char-name '|sansx| (integer->char #x1D5D1))			; 𝗑	Mathematical Sans-Serif Small X
(char-name '|sansy| (integer->char #x1D5D2))			; 𝗒	Mathematical Sans-Serif Small Y
(char-name '|sansz| (integer->char #x1D5D3))			; 𝗓	Mathematical Sans-Serif Small Z
(char-name '|bsansA| (integer->char #x1D5D4))			; 𝗔	Mathematical Sans-Serif Bold Capital A
(char-name '|bsansB| (integer->char #x1D5D5))			; 𝗕	Mathematical Sans-Serif Bold Capital B
(char-name '|bsansC| (integer->char #x1D5D6))			; 𝗖	Mathematical Sans-Serif Bold Capital C
(char-name '|bsansD| (integer->char #x1D5D7))			; 𝗗	Mathematical Sans-Serif Bold Capital D
(char-name '|bsansE| (integer->char #x1D5D8))			; 𝗘	Mathematical Sans-Serif Bold Capital E
(char-name '|bsansF| (integer->char #x1D5D9))			; 𝗙	Mathematical Sans-Serif Bold Capital F
(char-name '|bsansG| (integer->char #x1D5DA))			; 𝗚	Mathematical Sans-Serif Bold Capital G
(char-name '|bsansH| (integer->char #x1D5DB))			; 𝗛	Mathematical Sans-Serif Bold Capital H
(char-name '|bsansI| (integer->char #x1D5DC))			; 𝗜	Mathematical Sans-Serif Bold Capital I
(char-name '|bsansJ| (integer->char #x1D5DD))			; 𝗝	Mathematical Sans-Serif Bold Capital J
(char-name '|bsansK| (integer->char #x1D5DE))			; 𝗞	Mathematical Sans-Serif Bold Capital K
(char-name '|bsansL| (integer->char #x1D5DF))			; 𝗟	Mathematical Sans-Serif Bold Capital L
(char-name '|bsansM| (integer->char #x1D5E0))			; 𝗠	Mathematical Sans-Serif Bold Capital M
(char-name '|bsansN| (integer->char #x1D5E1))			; 𝗡	Mathematical Sans-Serif Bold Capital N
(char-name '|bsansO| (integer->char #x1D5E2))			; 𝗢	Mathematical Sans-Serif Bold Capital O
(char-name '|bsansP| (integer->char #x1D5E3))			; 𝗣	Mathematical Sans-Serif Bold Capital P
(char-name '|bsansQ| (integer->char #x1D5E4))			; 𝗤	Mathematical Sans-Serif Bold Capital Q
(char-name '|bsansR| (integer->char #x1D5E5))			; 𝗥	Mathematical Sans-Serif Bold Capital R
(char-name '|bsansS| (integer->char #x1D5E6))			; 𝗦	Mathematical Sans-Serif Bold Capital S
(char-name '|bsansT| (integer->char #x1D5E7))			; 𝗧	Mathematical Sans-Serif Bold Capital T
(char-name '|bsansU| (integer->char #x1D5E8))			; 𝗨	Mathematical Sans-Serif Bold Capital U
(char-name '|bsansV| (integer->char #x1D5E9))			; 𝗩	Mathematical Sans-Serif Bold Capital V
(char-name '|bsansW| (integer->char #x1D5EA))			; 𝗪	Mathematical Sans-Serif Bold Capital W
(char-name '|bsansX| (integer->char #x1D5EB))			; 𝗫	Mathematical Sans-Serif Bold Capital X
(char-name '|bsansY| (integer->char #x1D5EC))			; 𝗬	Mathematical Sans-Serif Bold Capital Y
(char-name '|bsansZ| (integer->char #x1D5ED))			; 𝗭	Mathematical Sans-Serif Bold Capital Z
(char-name '|bsansa| (integer->char #x1D5EE))			; 𝗮	Mathematical Sans-Serif Bold Small A
(char-name '|bsansb| (integer->char #x1D5EF))			; 𝗯	Mathematical Sans-Serif Bold Small B
(char-name '|bsansc| (integer->char #x1D5F0))			; 𝗰	Mathematical Sans-Serif Bold Small C
(char-name '|bsansd| (integer->char #x1D5F1))			; 𝗱	Mathematical Sans-Serif Bold Small D
(char-name '|bsanse| (integer->char #x1D5F2))			; 𝗲	Mathematical Sans-Serif Bold Small E
(char-name '|bsansf| (integer->char #x1D5F3))			; 𝗳	Mathematical Sans-Serif Bold Small F
(char-name '|bsansg| (integer->char #x1D5F4))			; 𝗴	Mathematical Sans-Serif Bold Small G
(char-name '|bsansh| (integer->char #x1D5F5))			; 𝗵	Mathematical Sans-Serif Bold Small H
(char-name '|bsansi| (integer->char #x1D5F6))			; 𝗶	Mathematical Sans-Serif Bold Small I
(char-name '|bsansj| (integer->char #x1D5F7))			; 𝗷	Mathematical Sans-Serif Bold Small J
(char-name '|bsansk| (integer->char #x1D5F8))			; 𝗸	Mathematical Sans-Serif Bold Small K
(char-name '|bsansl| (integer->char #x1D5F9))			; 𝗹	Mathematical Sans-Serif Bold Small L
(char-name '|bsansm| (integer->char #x1D5FA))			; 𝗺	Mathematical Sans-Serif Bold Small M
(char-name '|bsansn| (integer->char #x1D5FB))			; 𝗻	Mathematical Sans-Serif Bold Small N
(char-name '|bsanso| (integer->char #x1D5FC))			; 𝗼	Mathematical Sans-Serif Bold Small O
(char-name '|bsansp| (integer->char #x1D5FD))			; 𝗽	Mathematical Sans-Serif Bold Small P
(char-name '|bsansq| (integer->char #x1D5FE))			; 𝗾	Mathematical Sans-Serif Bold Small Q
(char-name '|bsansr| (integer->char #x1D5FF))			; 𝗿	Mathematical Sans-Serif Bold Small R
(char-name '|bsanss| (integer->char #x1D600))			; 𝘀	Mathematical Sans-Serif Bold Small S
(char-name '|bsanst| (integer->char #x1D601))			; 𝘁	Mathematical Sans-Serif Bold Small T
(char-name '|bsansu| (integer->char #x1D602))			; 𝘂	Mathematical Sans-Serif Bold Small U
(char-name '|bsansv| (integer->char #x1D603))			; 𝘃	Mathematical Sans-Serif Bold Small V
(char-name '|bsansw| (integer->char #x1D604))			; 𝘄	Mathematical Sans-Serif Bold Small W
(char-name '|bsansx| (integer->char #x1D605))			; 𝘅	Mathematical Sans-Serif Bold Small X
(char-name '|bsansy| (integer->char #x1D606))			; 𝘆	Mathematical Sans-Serif Bold Small Y
(char-name '|bsansz| (integer->char #x1D607))			; 𝘇	Mathematical Sans-Serif Bold Small Z
(char-name '|isansA| (integer->char #x1D608))			; 𝘈	Mathematical Sans-Serif Italic Capital A
(char-name '|isansB| (integer->char #x1D609))			; 𝘉	Mathematical Sans-Serif Italic Capital B
(char-name '|isansC| (integer->char #x1D60A))			; 𝘊	Mathematical Sans-Serif Italic Capital C
(char-name '|isansD| (integer->char #x1D60B))			; 𝘋	Mathematical Sans-Serif Italic Capital D
(char-name '|isansE| (integer->char #x1D60C))			; 𝘌	Mathematical Sans-Serif Italic Capital E
(char-name '|isansF| (integer->char #x1D60D))			; 𝘍	Mathematical Sans-Serif Italic Capital F
(char-name '|isansG| (integer->char #x1D60E))			; 𝘎	Mathematical Sans-Serif Italic Capital G
(char-name '|isansH| (integer->char #x1D60F))			; 𝘏	Mathematical Sans-Serif Italic Capital H
(char-name '|isansI| (integer->char #x1D610))			; 𝘐	Mathematical Sans-Serif Italic Capital I
(char-name '|isansJ| (integer->char #x1D611))			; 𝘑	Mathematical Sans-Serif Italic Capital J
(char-name '|isansK| (integer->char #x1D612))			; 𝘒	Mathematical Sans-Serif Italic Capital K
(char-name '|isansL| (integer->char #x1D613))			; 𝘓	Mathematical Sans-Serif Italic Capital L
(char-name '|isansM| (integer->char #x1D614))			; 𝘔	Mathematical Sans-Serif Italic Capital M
(char-name '|isansN| (integer->char #x1D615))			; 𝘕	Mathematical Sans-Serif Italic Capital N
(char-name '|isansO| (integer->char #x1D616))			; 𝘖	Mathematical Sans-Serif Italic Capital O
(char-name '|isansP| (integer->char #x1D617))			; 𝘗	Mathematical Sans-Serif Italic Capital P
(char-name '|isansQ| (integer->char #x1D618))			; 𝘘	Mathematical Sans-Serif Italic Capital Q
(char-name '|isansR| (integer->char #x1D619))			; 𝘙	Mathematical Sans-Serif Italic Capital R
(char-name '|isansS| (integer->char #x1D61A))			; 𝘚	Mathematical Sans-Serif Italic Capital S
(char-name '|isansT| (integer->char #x1D61B))			; 𝘛	Mathematical Sans-Serif Italic Capital T
(char-name '|isansU| (integer->char #x1D61C))			; 𝘜	Mathematical Sans-Serif Italic Capital U
(char-name '|isansV| (integer->char #x1D61D))			; 𝘝	Mathematical Sans-Serif Italic Capital V
(char-name '|isansW| (integer->char #x1D61E))			; 𝘞	Mathematical Sans-Serif Italic Capital W
(char-name '|isansX| (integer->char #x1D61F))			; 𝘟	Mathematical Sans-Serif Italic Capital X
(char-name '|isansY| (integer->char #x1D620))			; 𝘠	Mathematical Sans-Serif Italic Capital Y
(char-name '|isansZ| (integer->char #x1D621))			; 𝘡	Mathematical Sans-Serif Italic Capital Z
(char-name '|isansa| (integer->char #x1D622))			; 𝘢	Mathematical Sans-Serif Italic Small A
(char-name '|isansb| (integer->char #x1D623))			; 𝘣	Mathematical Sans-Serif Italic Small B
(char-name '|isansc| (integer->char #x1D624))			; 𝘤	Mathematical Sans-Serif Italic Small C
(char-name '|isansd| (integer->char #x1D625))			; 𝘥	Mathematical Sans-Serif Italic Small D
(char-name '|isanse| (integer->char #x1D626))			; 𝘦	Mathematical Sans-Serif Italic Small E
(char-name '|isansf| (integer->char #x1D627))			; 𝘧	Mathematical Sans-Serif Italic Small F
(char-name '|isansg| (integer->char #x1D628))			; 𝘨	Mathematical Sans-Serif Italic Small G
(char-name '|isansh| (integer->char #x1D629))			; 𝘩	Mathematical Sans-Serif Italic Small H
(char-name '|isansi| (integer->char #x1D62A))			; 𝘪	Mathematical Sans-Serif Italic Small I
(char-name '|isansj| (integer->char #x1D62B))			; 𝘫	Mathematical Sans-Serif Italic Small J
(char-name '|isansk| (integer->char #x1D62C))			; 𝘬	Mathematical Sans-Serif Italic Small K
(char-name '|isansl| (integer->char #x1D62D))			; 𝘭	Mathematical Sans-Serif Italic Small L
(char-name '|isansm| (integer->char #x1D62E))			; 𝘮	Mathematical Sans-Serif Italic Small M
(char-name '|isansn| (integer->char #x1D62F))			; 𝘯	Mathematical Sans-Serif Italic Small N
(char-name '|isanso| (integer->char #x1D630))			; 𝘰	Mathematical Sans-Serif Italic Small O
(char-name '|isansp| (integer->char #x1D631))			; 𝘱	Mathematical Sans-Serif Italic Small P
(char-name '|isansq| (integer->char #x1D632))			; 𝘲	Mathematical Sans-Serif Italic Small Q
(char-name '|isansr| (integer->char #x1D633))			; 𝘳	Mathematical Sans-Serif Italic Small R
(char-name '|isanss| (integer->char #x1D634))			; 𝘴	Mathematical Sans-Serif Italic Small S
(char-name '|isanst| (integer->char #x1D635))			; 𝘵	Mathematical Sans-Serif Italic Small T
(char-name '|isansu| (integer->char #x1D636))			; 𝘶	Mathematical Sans-Serif Italic Small U
(char-name '|isansv| (integer->char #x1D637))			; 𝘷	Mathematical Sans-Serif Italic Small V
(char-name '|isansw| (integer->char #x1D638))			; 𝘸	Mathematical Sans-Serif Italic Small W
(char-name '|isansx| (integer->char #x1D639))			; 𝘹	Mathematical Sans-Serif Italic Small X
(char-name '|isansy| (integer->char #x1D63A))			; 𝘺	Mathematical Sans-Serif Italic Small Y
(char-name '|isansz| (integer->char #x1D63B))			; 𝘻	Mathematical Sans-Serif Italic Small Z
(char-name '|bisansA| (integer->char #x1D63C))			; 𝘼	Mathematical Sans-Serif Bold Italic Capital A
(char-name '|bisansB| (integer->char #x1D63D))			; 𝘽	Mathematical Sans-Serif Bold Italic Capital B
(char-name '|bisansC| (integer->char #x1D63E))			; 𝘾	Mathematical Sans-Serif Bold Italic Capital C
(char-name '|bisansD| (integer->char #x1D63F))			; 𝘿	Mathematical Sans-Serif Bold Italic Capital D
(char-name '|bisansE| (integer->char #x1D640))			; 𝙀	Mathematical Sans-Serif Bold Italic Capital E
(char-name '|bisansF| (integer->char #x1D641))			; 𝙁	Mathematical Sans-Serif Bold Italic Capital F
(char-name '|bisansG| (integer->char #x1D642))			; 𝙂	Mathematical Sans-Serif Bold Italic Capital G
(char-name '|bisansH| (integer->char #x1D643))			; 𝙃	Mathematical Sans-Serif Bold Italic Capital H
(char-name '|bisansI| (integer->char #x1D644))			; 𝙄	Mathematical Sans-Serif Bold Italic Capital I
(char-name '|bisansJ| (integer->char #x1D645))			; 𝙅	Mathematical Sans-Serif Bold Italic Capital J
(char-name '|bisansK| (integer->char #x1D646))			; 𝙆	Mathematical Sans-Serif Bold Italic Capital K
(char-name '|bisansL| (integer->char #x1D647))			; 𝙇	Mathematical Sans-Serif Bold Italic Capital L
(char-name '|bisansM| (integer->char #x1D648))			; 𝙈	Mathematical Sans-Serif Bold Italic Capital M
(char-name '|bisansN| (integer->char #x1D649))			; 𝙉	Mathematical Sans-Serif Bold Italic Capital N
(char-name '|bisansO| (integer->char #x1D64A))			; 𝙊	Mathematical Sans-Serif Bold Italic Capital O
(char-name '|bisansP| (integer->char #x1D64B))			; 𝙋	Mathematical Sans-Serif Bold Italic Capital P
(char-name '|bisansQ| (integer->char #x1D64C))			; 𝙌	Mathematical Sans-Serif Bold Italic Capital Q
(char-name '|bisansR| (integer->char #x1D64D))			; 𝙍	Mathematical Sans-Serif Bold Italic Capital R
(char-name '|bisansS| (integer->char #x1D64E))			; 𝙎	Mathematical Sans-Serif Bold Italic Capital S
(char-name '|bisansT| (integer->char #x1D64F))			; 𝙏	Mathematical Sans-Serif Bold Italic Capital T
(char-name '|bisansU| (integer->char #x1D650))			; 𝙐	Mathematical Sans-Serif Bold Italic Capital U
(char-name '|bisansV| (integer->char #x1D651))			; 𝙑	Mathematical Sans-Serif Bold Italic Capital V
(char-name '|bisansW| (integer->char #x1D652))			; 𝙒	Mathematical Sans-Serif Bold Italic Capital W
(char-name '|bisansX| (integer->char #x1D653))			; 𝙓	Mathematical Sans-Serif Bold Italic Capital X
(char-name '|bisansY| (integer->char #x1D654))			; 𝙔	Mathematical Sans-Serif Bold Italic Capital Y
(char-name '|bisansZ| (integer->char #x1D655))			; 𝙕	Mathematical Sans-Serif Bold Italic Capital Z
(char-name '|bisansa| (integer->char #x1D656))			; 𝙖	Mathematical Sans-Serif Bold Italic Small A
(char-name '|bisansb| (integer->char #x1D657))			; 𝙗	Mathematical Sans-Serif Bold Italic Small B
(char-name '|bisansc| (integer->char #x1D658))			; 𝙘	Mathematical Sans-Serif Bold Italic Small C
(char-name '|bisansd| (integer->char #x1D659))			; 𝙙	Mathematical Sans-Serif Bold Italic Small D
(char-name '|bisanse| (integer->char #x1D65A))			; 𝙚	Mathematical Sans-Serif Bold Italic Small E
(char-name '|bisansf| (integer->char #x1D65B))			; 𝙛	Mathematical Sans-Serif Bold Italic Small F
(char-name '|bisansg| (integer->char #x1D65C))			; 𝙜	Mathematical Sans-Serif Bold Italic Small G
(char-name '|bisansh| (integer->char #x1D65D))			; 𝙝	Mathematical Sans-Serif Bold Italic Small H
(char-name '|bisansi| (integer->char #x1D65E))			; 𝙞	Mathematical Sans-Serif Bold Italic Small I
(char-name '|bisansj| (integer->char #x1D65F))			; 𝙟	Mathematical Sans-Serif Bold Italic Small J
(char-name '|bisansk| (integer->char #x1D660))			; 𝙠	Mathematical Sans-Serif Bold Italic Small K
(char-name '|bisansl| (integer->char #x1D661))			; 𝙡	Mathematical Sans-Serif Bold Italic Small L
(char-name '|bisansm| (integer->char #x1D662))			; 𝙢	Mathematical Sans-Serif Bold Italic Small M
(char-name '|bisansn| (integer->char #x1D663))			; 𝙣	Mathematical Sans-Serif Bold Italic Small N
(char-name '|bisanso| (integer->char #x1D664))			; 𝙤	Mathematical Sans-Serif Bold Italic Small O
(char-name '|bisansp| (integer->char #x1D665))			; 𝙥	Mathematical Sans-Serif Bold Italic Small P
(char-name '|bisansq| (integer->char #x1D666))			; 𝙦	Mathematical Sans-Serif Bold Italic Small Q
(char-name '|bisansr| (integer->char #x1D667))			; 𝙧	Mathematical Sans-Serif Bold Italic Small R
(char-name '|bisanss| (integer->char #x1D668))			; 𝙨	Mathematical Sans-Serif Bold Italic Small S
(char-name '|bisanst| (integer->char #x1D669))			; 𝙩	Mathematical Sans-Serif Bold Italic Small T
(char-name '|bisansu| (integer->char #x1D66A))			; 𝙪	Mathematical Sans-Serif Bold Italic Small U
(char-name '|bisansv| (integer->char #x1D66B))			; 𝙫	Mathematical Sans-Serif Bold Italic Small V
(char-name '|bisansw| (integer->char #x1D66C))			; 𝙬	Mathematical Sans-Serif Bold Italic Small W
(char-name '|bisansx| (integer->char #x1D66D))			; 𝙭	Mathematical Sans-Serif Bold Italic Small X
(char-name '|bisansy| (integer->char #x1D66E))			; 𝙮	Mathematical Sans-Serif Bold Italic Small Y
(char-name '|bisansz| (integer->char #x1D66F))			; 𝙯	Mathematical Sans-Serif Bold Italic Small Z
(char-name '|ttA| (integer->char #x1D670))			; 𝙰	Mathematical Monospace Capital A
(char-name '|ttB| (integer->char #x1D671))			; 𝙱	Mathematical Monospace Capital B
(char-name '|ttC| (integer->char #x1D672))			; 𝙲	Mathematical Monospace Capital C
(char-name '|ttD| (integer->char #x1D673))			; 𝙳	Mathematical Monospace Capital D
(char-name '|ttE| (integer->char #x1D674))			; 𝙴	Mathematical Monospace Capital E
(char-name '|ttF| (integer->char #x1D675))			; 𝙵	Mathematical Monospace Capital F
(char-name '|ttG| (integer->char #x1D676))			; 𝙶	Mathematical Monospace Capital G
(char-name '|ttH| (integer->char #x1D677))			; 𝙷	Mathematical Monospace Capital H
(char-name '|ttI| (integer->char #x1D678))			; 𝙸	Mathematical Monospace Capital I
(char-name '|ttJ| (integer->char #x1D679))			; 𝙹	Mathematical Monospace Capital J
(char-name '|ttK| (integer->char #x1D67A))			; 𝙺	Mathematical Monospace Capital K
(char-name '|ttL| (integer->char #x1D67B))			; 𝙻	Mathematical Monospace Capital L
(char-name '|ttM| (integer->char #x1D67C))			; 𝙼	Mathematical Monospace Capital M
(char-name '|ttN| (integer->char #x1D67D))			; 𝙽	Mathematical Monospace Capital N
(char-name '|ttO| (integer->char #x1D67E))			; 𝙾	Mathematical Monospace Capital O
(char-name '|ttP| (integer->char #x1D67F))			; 𝙿	Mathematical Monospace Capital P
(char-name '|ttQ| (integer->char #x1D680))			; 𝚀	Mathematical Monospace Capital Q
(char-name '|ttR| (integer->char #x1D681))			; 𝚁	Mathematical Monospace Capital R
(char-name '|ttS| (integer->char #x1D682))			; 𝚂	Mathematical Monospace Capital S
(char-name '|ttT| (integer->char #x1D683))			; 𝚃	Mathematical Monospace Capital T
(char-name '|ttU| (integer->char #x1D684))			; 𝚄	Mathematical Monospace Capital U
(char-name '|ttV| (integer->char #x1D685))			; 𝚅	Mathematical Monospace Capital V
(char-name '|ttW| (integer->char #x1D686))			; 𝚆	Mathematical Monospace Capital W
(char-name '|ttX| (integer->char #x1D687))			; 𝚇	Mathematical Monospace Capital X
(char-name '|ttY| (integer->char #x1D688))			; 𝚈	Mathematical Monospace Capital Y
(char-name '|ttZ| (integer->char #x1D689))			; 𝚉	Mathematical Monospace Capital Z
(char-name '|tta| (integer->char #x1D68A))			; 𝚊	Mathematical Monospace Small A
(char-name '|ttb| (integer->char #x1D68B))			; 𝚋	Mathematical Monospace Small B
(char-name '|ttc| (integer->char #x1D68C))			; 𝚌	Mathematical Monospace Small C
(char-name '|ttd| (integer->char #x1D68D))			; 𝚍	Mathematical Monospace Small D
(char-name '|tte| (integer->char #x1D68E))			; 𝚎	Mathematical Monospace Small E
(char-name '|ttf| (integer->char #x1D68F))			; 𝚏	Mathematical Monospace Small F
(char-name '|ttg| (integer->char #x1D690))			; 𝚐	Mathematical Monospace Small G
(char-name '|tth| (integer->char #x1D691))			; 𝚑	Mathematical Monospace Small H
(char-name '|tti| (integer->char #x1D692))			; 𝚒	Mathematical Monospace Small I
(char-name '|ttj| (integer->char #x1D693))			; 𝚓	Mathematical Monospace Small J
(char-name '|ttk| (integer->char #x1D694))			; 𝚔	Mathematical Monospace Small K
(char-name '|ttl| (integer->char #x1D695))			; 𝚕	Mathematical Monospace Small L
(char-name '|ttm| (integer->char #x1D696))			; 𝚖	Mathematical Monospace Small M
(char-name '|ttn| (integer->char #x1D697))			; 𝚗	Mathematical Monospace Small N
(char-name '|tto| (integer->char #x1D698))			; 𝚘	Mathematical Monospace Small O
(char-name '|ttp| (integer->char #x1D699))			; 𝚙	Mathematical Monospace Small P
(char-name '|ttq| (integer->char #x1D69A))			; 𝚚	Mathematical Monospace Small Q
(char-name '|ttr| (integer->char #x1D69B))			; 𝚛	Mathematical Monospace Small R
(char-name '|tts| (integer->char #x1D69C))			; 𝚜	Mathematical Monospace Small S
(char-name '|ttt| (integer->char #x1D69D))			; 𝚝	Mathematical Monospace Small T
(char-name '|ttu| (integer->char #x1D69E))			; 𝚞	Mathematical Monospace Small U
(char-name '|ttv| (integer->char #x1D69F))			; 𝚟	Mathematical Monospace Small V
(char-name '|ttw| (integer->char #x1D6A0))			; 𝚠	Mathematical Monospace Small W
(char-name '|ttx| (integer->char #x1D6A1))			; 𝚡	Mathematical Monospace Small X
(char-name '|tty| (integer->char #x1D6A2))			; 𝚢	Mathematical Monospace Small Y
(char-name '|ttz| (integer->char #x1D6A3))			; 𝚣	Mathematical Monospace Small Z
(char-name '|itimath| (integer->char #x1D6A4))			; 𝚤	Mathematical Italic Small Dotless I
(char-name '|itjmath| (integer->char #x1D6A5))			; 𝚥	Mathematical Italic Small Dotless J
(char-name '|bfAlpha| (integer->char #x1D6A8))			; 𝚨	Mathematical Bold Capital Alpha
(char-name '|bfBeta| (integer->char #x1D6A9))			; 𝚩	Mathematical Bold Capital Beta
(char-name '|bfGamma| (integer->char #x1D6AA))			; 𝚪	Mathematical Bold Capital Gamma
(char-name '|bfDelta| (integer->char #x1D6AB))			; 𝚫	Mathematical Bold Capital Delta
(char-name '|bfEpsilon| (integer->char #x1D6AC))			; 𝚬	Mathematical Bold Capital Epsilon
(char-name '|bfZeta| (integer->char #x1D6AD))			; 𝚭	Mathematical Bold Capital Zeta
(char-name '|bfEta| (integer->char #x1D6AE))			; 𝚮	Mathematical Bold Capital Eta
(char-name '|bfTheta| (integer->char #x1D6AF))			; 𝚯	Mathematical Bold Capital Theta
(char-name '|bfIota| (integer->char #x1D6B0))			; 𝚰	Mathematical Bold Capital Iota
(char-name '|bfKappa| (integer->char #x1D6B1))			; 𝚱	Mathematical Bold Capital Kappa
(char-name '|bfLambda| (integer->char #x1D6B2))			; 𝚲	Mathematical Bold Capital Lamda
(char-name '|bfMu| (integer->char #x1D6B3))			; 𝚳	Mathematical Bold Capital Mu
(char-name '|bfNu| (integer->char #x1D6B4))			; 𝚴	Mathematical Bold Capital Nu
(char-name '|bfXi| (integer->char #x1D6B5))			; 𝚵	Mathematical Bold Capital Xi
(char-name '|bfOmicron| (integer->char #x1D6B6))			; 𝚶	Mathematical Bold Capital Omicron
(char-name '|bfPi| (integer->char #x1D6B7))			; 𝚷	Mathematical Bold Capital Pi
(char-name '|bfRho| (integer->char #x1D6B8))			; 𝚸	Mathematical Bold Capital Rho
(char-name '|bfvarTheta| (integer->char #x1D6B9))			; 𝚹	Mathematical Bold Capital Theta Symbol
(char-name '|bfSigma| (integer->char #x1D6BA))			; 𝚺	Mathematical Bold Capital Sigma
(char-name '|bfTau| (integer->char #x1D6BB))			; 𝚻	Mathematical Bold Capital Tau
(char-name '|bfUpsilon| (integer->char #x1D6BC))			; 𝚼	Mathematical Bold Capital Upsilon
(char-name '|bfPhi| (integer->char #x1D6BD))			; 𝚽	Mathematical Bold Capital Phi
(char-name '|bfChi| (integer->char #x1D6BE))			; 𝚾	Mathematical Bold Capital Chi
(char-name '|bfPsi| (integer->char #x1D6BF))			; 𝚿	Mathematical Bold Capital Psi
(char-name '|bfOmega| (integer->char #x1D6C0))			; 𝛀	Mathematical Bold Capital Omega
(char-name '|bfnabla| (integer->char #x1D6C1))			; 𝛁	Mathematical Bold Nabla
(char-name '|bfalpha| (integer->char #x1D6C2))			; 𝛂	Mathematical Bold Small Alpha
(char-name '|bfbeta| (integer->char #x1D6C3))			; 𝛃	Mathematical Bold Small Beta
(char-name '|bfgamma| (integer->char #x1D6C4))			; 𝛄	Mathematical Bold Small Gamma
(char-name '|bfdelta| (integer->char #x1D6C5))			; 𝛅	Mathematical Bold Small Delta
(char-name '|bfepsilon| (integer->char #x1D6C6))			; 𝛆	Mathematical Bold Small Epsilon
(char-name '|bfzeta| (integer->char #x1D6C7))			; 𝛇	Mathematical Bold Small Zeta
(char-name '|bfeta| (integer->char #x1D6C8))			; 𝛈	Mathematical Bold Small Eta
(char-name '|bftheta| (integer->char #x1D6C9))			; 𝛉	Mathematical Bold Small Theta
(char-name '|bfiota| (integer->char #x1D6CA))			; 𝛊	Mathematical Bold Small Iota
(char-name '|bfkappa| (integer->char #x1D6CB))			; 𝛋	Mathematical Bold Small Kappa
(char-name '|bflambda| (integer->char #x1D6CC))			; 𝛌	Mathematical Bold Small Lamda
(char-name '|bfmu| (integer->char #x1D6CD))			; 𝛍	Mathematical Bold Small Mu
(char-name '|bfnu| (integer->char #x1D6CE))			; 𝛎	Mathematical Bold Small Nu
(char-name '|bfxi| (integer->char #x1D6CF))			; 𝛏	Mathematical Bold Small Xi
(char-name '|bfomicron| (integer->char #x1D6D0))			; 𝛐	Mathematical Bold Small Omicron
(char-name '|bfpi| (integer->char #x1D6D1))			; 𝛑	Mathematical Bold Small Pi
(char-name '|bfrho| (integer->char #x1D6D2))			; 𝛒	Mathematical Bold Small Rho
(char-name '|bfvarsigma| (integer->char #x1D6D3))			; 𝛓	Mathematical Bold Small Final Sigma
(char-name '|bfsigma| (integer->char #x1D6D4))			; 𝛔	Mathematical Bold Small Sigma
(char-name '|bftau| (integer->char #x1D6D5))			; 𝛕	Mathematical Bold Small Tau
(char-name '|bfupsilon| (integer->char #x1D6D6))			; 𝛖	Mathematical Bold Small Upsilon
(char-name '|bfvarphi| (integer->char #x1D6D7))			; 𝛗	Mathematical Bold Small Phi
(char-name '|bfchi| (integer->char #x1D6D8))			; 𝛘	Mathematical Bold Small Chi
(char-name '|bfpsi| (integer->char #x1D6D9))			; 𝛙	Mathematical Bold Small Psi
(char-name '|bfomega| (integer->char #x1D6DA))			; 𝛚	Mathematical Bold Small Omega
(char-name '|bfpartial| (integer->char #x1D6DB))			; 𝛛	Mathematical Bold Partial Differential
(char-name '|bfvarepsilon| (integer->char #x1D6DC))			; 𝛜	Mathematical Bold Epsilon Symbol
(char-name '|bfvartheta| (integer->char #x1D6DD))			; 𝛝	Mathematical Bold Theta Symbol
(char-name '|bfvarkappa| (integer->char #x1D6DE))			; 𝛞	Mathematical Bold Kappa Symbol
(char-name '|bfphi| (integer->char #x1D6DF))			; 𝛟	Mathematical Bold Phi Symbol
(char-name '|bfvarrho| (integer->char #x1D6E0))			; 𝛠	Mathematical Bold Rho Symbol
(char-name '|bfvarpi| (integer->char #x1D6E1))			; 𝛡	Mathematical Bold Pi Symbol
(char-name '|itAlpha| (integer->char #x1D6E2))			; 𝛢	Mathematical Italic Capital Alpha
(char-name '|itBeta| (integer->char #x1D6E3))			; 𝛣	Mathematical Italic Capital Beta
(char-name '|itGamma| (integer->char #x1D6E4))			; 𝛤	Mathematical Italic Capital Gamma
(char-name '|itDelta| (integer->char #x1D6E5))			; 𝛥	Mathematical Italic Capital Delta
(char-name '|itEpsilon| (integer->char #x1D6E6))			; 𝛦	Mathematical Italic Capital Epsilon
(char-name '|itZeta| (integer->char #x1D6E7))			; 𝛧	Mathematical Italic Capital Zeta
(char-name '|itEta| (integer->char #x1D6E8))			; 𝛨	Mathematical Italic Capital Eta
(char-name '|itTheta| (integer->char #x1D6E9))			; 𝛩	Mathematical Italic Capital Theta
(char-name '|itIota| (integer->char #x1D6EA))			; 𝛪	Mathematical Italic Capital Iota
(char-name '|itKappa| (integer->char #x1D6EB))			; 𝛫	Mathematical Italic Capital Kappa
(char-name '|itLambda| (integer->char #x1D6EC))			; 𝛬	Mathematical Italic Capital Lamda
(char-name '|itMu| (integer->char #x1D6ED))			; 𝛭	Mathematical Italic Capital Mu
(char-name '|itNu| (integer->char #x1D6EE))			; 𝛮	Mathematical Italic Capital Nu
(char-name '|itXi| (integer->char #x1D6EF))			; 𝛯	Mathematical Italic Capital Xi
(char-name '|itOmicron| (integer->char #x1D6F0))			; 𝛰	Mathematical Italic Capital Omicron
(char-name '|itPi| (integer->char #x1D6F1))			; 𝛱	Mathematical Italic Capital Pi
(char-name '|itRho| (integer->char #x1D6F2))			; 𝛲	Mathematical Italic Capital Rho
(char-name '|itvarTheta| (integer->char #x1D6F3))			; 𝛳	Mathematical Italic Capital Theta Symbol
(char-name '|itSigma| (integer->char #x1D6F4))			; 𝛴	Mathematical Italic Capital Sigma
(char-name '|itTau| (integer->char #x1D6F5))			; 𝛵	Mathematical Italic Capital Tau
(char-name '|itUpsilon| (integer->char #x1D6F6))			; 𝛶	Mathematical Italic Capital Upsilon
(char-name '|itPhi| (integer->char #x1D6F7))			; 𝛷	Mathematical Italic Capital Phi
(char-name '|itChi| (integer->char #x1D6F8))			; 𝛸	Mathematical Italic Capital Chi
(char-name '|itPsi| (integer->char #x1D6F9))			; 𝛹	Mathematical Italic Capital Psi
(char-name '|itOmega| (integer->char #x1D6FA))			; 𝛺	Mathematical Italic Capital Omega
(char-name '|itnabla| (integer->char #x1D6FB))			; 𝛻	Mathematical Italic Nabla
(char-name '|italpha| (integer->char #x1D6FC))			; 𝛼	Mathematical Italic Small Alpha
(char-name '|itbeta| (integer->char #x1D6FD))			; 𝛽	Mathematical Italic Small Beta
(char-name '|itgamma| (integer->char #x1D6FE))			; 𝛾	Mathematical Italic Small Gamma
(char-name '|itdelta| (integer->char #x1D6FF))			; 𝛿	Mathematical Italic Small Delta
(char-name '|itepsilon| (integer->char #x1D700))			; 𝜀	Mathematical Italic Small Epsilon
(char-name '|itzeta| (integer->char #x1D701))			; 𝜁	Mathematical Italic Small Zeta
(char-name '|iteta| (integer->char #x1D702))			; 𝜂	Mathematical Italic Small Eta
(char-name '|ittheta| (integer->char #x1D703))			; 𝜃	Mathematical Italic Small Theta
(char-name '|itiota| (integer->char #x1D704))			; 𝜄	Mathematical Italic Small Iota
(char-name '|itkappa| (integer->char #x1D705))			; 𝜅	Mathematical Italic Small Kappa
(char-name '|itlambda| (integer->char #x1D706))			; 𝜆	Mathematical Italic Small Lamda
(char-name '|itmu| (integer->char #x1D707))			; 𝜇	Mathematical Italic Small Mu
(char-name '|itnu| (integer->char #x1D708))			; 𝜈	Mathematical Italic Small Nu
(char-name '|itxi| (integer->char #x1D709))			; 𝜉	Mathematical Italic Small Xi
(char-name '|itomicron| (integer->char #x1D70A))			; 𝜊	Mathematical Italic Small Omicron
(char-name '|itpi| (integer->char #x1D70B))			; 𝜋	Mathematical Italic Small Pi
(char-name '|itrho| (integer->char #x1D70C))			; 𝜌	Mathematical Italic Small Rho
(char-name '|itvarsigma| (integer->char #x1D70D))			; 𝜍	Mathematical Italic Small Final Sigma
(char-name '|itsigma| (integer->char #x1D70E))			; 𝜎	Mathematical Italic Small Sigma
(char-name '|ittau| (integer->char #x1D70F))			; 𝜏	Mathematical Italic Small Tau
(char-name '|itupsilon| (integer->char #x1D710))			; 𝜐	Mathematical Italic Small Upsilon
(char-name '|itphi| (integer->char #x1D711))			; 𝜑	Mathematical Italic Small Phi
(char-name '|itchi| (integer->char #x1D712))			; 𝜒	Mathematical Italic Small Chi
(char-name '|itpsi| (integer->char #x1D713))			; 𝜓	Mathematical Italic Small Psi
(char-name '|itomega| (integer->char #x1D714))			; 𝜔	Mathematical Italic Small Omega
(char-name '|itpartial| (integer->char #x1D715))			; 𝜕	Mathematical Italic Partial Differential
(char-name '|itvarepsilon| (integer->char #x1D716))			; 𝜖	Mathematical Italic Epsilon Symbol
(char-name '|itvartheta| (integer->char #x1D717))			; 𝜗	Mathematical Italic Theta Symbol
(char-name '|itvarkappa| (integer->char #x1D718))			; 𝜘	Mathematical Italic Kappa Symbol
(char-name '|itvarphi| (integer->char #x1D719))			; 𝜙	Mathematical Italic Phi Symbol
(char-name '|itvarrho| (integer->char #x1D71A))			; 𝜚	Mathematical Italic Rho Symbol
(char-name '|itvarpi| (integer->char #x1D71B))			; 𝜛	Mathematical Italic Pi Symbol
(char-name '|biAlpha| (integer->char #x1D71C))			; 𝜜	Mathematical Bold Italic Capital Alpha
(char-name '|biBeta| (integer->char #x1D71D))			; 𝜝	Mathematical Bold Italic Capital Beta
(char-name '|biGamma| (integer->char #x1D71E))			; 𝜞	Mathematical Bold Italic Capital Gamma
(char-name '|biDelta| (integer->char #x1D71F))			; 𝜟	Mathematical Bold Italic Capital Delta
(char-name '|biEpsilon| (integer->char #x1D720))			; 𝜠	Mathematical Bold Italic Capital Epsilon
(char-name '|biZeta| (integer->char #x1D721))			; 𝜡	Mathematical Bold Italic Capital Zeta
(char-name '|biEta| (integer->char #x1D722))			; 𝜢	Mathematical Bold Italic Capital Eta
(char-name '|biTheta| (integer->char #x1D723))			; 𝜣	Mathematical Bold Italic Capital Theta
(char-name '|biIota| (integer->char #x1D724))			; 𝜤	Mathematical Bold Italic Capital Iota
(char-name '|biKappa| (integer->char #x1D725))			; 𝜥	Mathematical Bold Italic Capital Kappa
(char-name '|biLambda| (integer->char #x1D726))			; 𝜦	Mathematical Bold Italic Capital Lamda
(char-name '|biMu| (integer->char #x1D727))			; 𝜧	Mathematical Bold Italic Capital Mu
(char-name '|biNu| (integer->char #x1D728))			; 𝜨	Mathematical Bold Italic Capital Nu
(char-name '|biXi| (integer->char #x1D729))			; 𝜩	Mathematical Bold Italic Capital Xi
(char-name '|biOmicron| (integer->char #x1D72A))			; 𝜪	Mathematical Bold Italic Capital Omicron
(char-name '|biPi| (integer->char #x1D72B))			; 𝜫	Mathematical Bold Italic Capital Pi
(char-name '|biRho| (integer->char #x1D72C))			; 𝜬	Mathematical Bold Italic Capital Rho
(char-name '|bivarTheta| (integer->char #x1D72D))			; 𝜭	Mathematical Bold Italic Capital Theta Symbol
(char-name '|biSigma| (integer->char #x1D72E))			; 𝜮	Mathematical Bold Italic Capital Sigma
(char-name '|biTau| (integer->char #x1D72F))			; 𝜯	Mathematical Bold Italic Capital Tau
(char-name '|biUpsilon| (integer->char #x1D730))			; 𝜰	Mathematical Bold Italic Capital Upsilon
(char-name '|biPhi| (integer->char #x1D731))			; 𝜱	Mathematical Bold Italic Capital Phi
(char-name '|biChi| (integer->char #x1D732))			; 𝜲	Mathematical Bold Italic Capital Chi
(char-name '|biPsi| (integer->char #x1D733))			; 𝜳	Mathematical Bold Italic Capital Psi
(char-name '|biOmega| (integer->char #x1D734))			; 𝜴	Mathematical Bold Italic Capital Omega
(char-name '|binabla| (integer->char #x1D735))			; 𝜵	Mathematical Bold Italic Nabla
(char-name '|bialpha| (integer->char #x1D736))			; 𝜶	Mathematical Bold Italic Small Alpha
(char-name '|bibeta| (integer->char #x1D737))			; 𝜷	Mathematical Bold Italic Small Beta
(char-name '|bigamma| (integer->char #x1D738))			; 𝜸	Mathematical Bold Italic Small Gamma
(char-name '|bidelta| (integer->char #x1D739))			; 𝜹	Mathematical Bold Italic Small Delta
(char-name '|biepsilon| (integer->char #x1D73A))			; 𝜺	Mathematical Bold Italic Small Epsilon
(char-name '|bizeta| (integer->char #x1D73B))			; 𝜻	Mathematical Bold Italic Small Zeta
(char-name '|bieta| (integer->char #x1D73C))			; 𝜼	Mathematical Bold Italic Small Eta
(char-name '|bitheta| (integer->char #x1D73D))			; 𝜽	Mathematical Bold Italic Small Theta
(char-name '|biiota| (integer->char #x1D73E))			; 𝜾	Mathematical Bold Italic Small Iota
(char-name '|bikappa| (integer->char #x1D73F))			; 𝜿	Mathematical Bold Italic Small Kappa
(char-name '|bilambda| (integer->char #x1D740))			; 𝝀	Mathematical Bold Italic Small Lamda
(char-name '|bimu| (integer->char #x1D741))			; 𝝁	Mathematical Bold Italic Small Mu
(char-name '|binu| (integer->char #x1D742))			; 𝝂	Mathematical Bold Italic Small Nu
(char-name '|bixi| (integer->char #x1D743))			; 𝝃	Mathematical Bold Italic Small Xi
(char-name '|biomicron| (integer->char #x1D744))			; 𝝄	Mathematical Bold Italic Small Omicron
(char-name '|bipi| (integer->char #x1D745))			; 𝝅	Mathematical Bold Italic Small Pi
(char-name '|birho| (integer->char #x1D746))			; 𝝆	Mathematical Bold Italic Small Rho
(char-name '|bivarsigma| (integer->char #x1D747))			; 𝝇	Mathematical Bold Italic Small Final Sigma
(char-name '|bisigma| (integer->char #x1D748))			; 𝝈	Mathematical Bold Italic Small Sigma
(char-name '|bitau| (integer->char #x1D749))			; 𝝉	Mathematical Bold Italic Small Tau
(char-name '|biupsilon| (integer->char #x1D74A))			; 𝝊	Mathematical Bold Italic Small Upsilon
(char-name '|biphi| (integer->char #x1D74B))			; 𝝋	Mathematical Bold Italic Small Phi
(char-name '|bichi| (integer->char #x1D74C))			; 𝝌	Mathematical Bold Italic Small Chi
(char-name '|bipsi| (integer->char #x1D74D))			; 𝝍	Mathematical Bold Italic Small Psi
(char-name '|biomega| (integer->char #x1D74E))			; 𝝎	Mathematical Bold Italic Small Omega
(char-name '|bipartial| (integer->char #x1D74F))			; 𝝏	Mathematical Bold Italic Partial Differential
(char-name '|bivarepsilon| (integer->char #x1D750))			; 𝝐	Mathematical Bold Italic Epsilon Symbol
(char-name '|bivartheta| (integer->char #x1D751))			; 𝝑	Mathematical Bold Italic Theta Symbol
(char-name '|bivarkappa| (integer->char #x1D752))			; 𝝒	Mathematical Bold Italic Kappa Symbol
(char-name '|bivarphi| (integer->char #x1D753))			; 𝝓	Mathematical Bold Italic Phi Symbol
(char-name '|bivarrho| (integer->char #x1D754))			; 𝝔	Mathematical Bold Italic Rho Symbol
(char-name '|bivarpi| (integer->char #x1D755))			; 𝝕	Mathematical Bold Italic Pi Symbol
(char-name '|bsansAlpha| (integer->char #x1D756))			; 𝝖	Mathematical Sans-Serif Bold Capital Alpha
(char-name '|bsansBeta| (integer->char #x1D757))			; 𝝗	Mathematical Sans-Serif Bold Capital Beta
(char-name '|bsansGamma| (integer->char #x1D758))			; 𝝘	Mathematical Sans-Serif Bold Capital Gamma
(char-name '|bsansDelta| (integer->char #x1D759))			; 𝝙	Mathematical Sans-Serif Bold Capital Delta
(char-name '|bsansEpsilon| (integer->char #x1D75A))			; 𝝚	Mathematical Sans-Serif Bold Capital Epsilon
(char-name '|bsansZeta| (integer->char #x1D75B))			; 𝝛	Mathematical Sans-Serif Bold Capital Zeta
(char-name '|bsansEta| (integer->char #x1D75C))			; 𝝜	Mathematical Sans-Serif Bold Capital Eta
(char-name '|bsansTheta| (integer->char #x1D75D))			; 𝝝	Mathematical Sans-Serif Bold Capital Theta
(char-name '|bsansIota| (integer->char #x1D75E))			; 𝝞	Mathematical Sans-Serif Bold Capital Iota
(char-name '|bsansKappa| (integer->char #x1D75F))			; 𝝟	Mathematical Sans-Serif Bold Capital Kappa
(char-name '|bsansLambda| (integer->char #x1D760))			; 𝝠	Mathematical Sans-Serif Bold Capital Lamda
(char-name '|bsansMu| (integer->char #x1D761))			; 𝝡	Mathematical Sans-Serif Bold Capital Mu
(char-name '|bsansNu| (integer->char #x1D762))			; 𝝢	Mathematical Sans-Serif Bold Capital Nu
(char-name '|bsansXi| (integer->char #x1D763))			; 𝝣	Mathematical Sans-Serif Bold Capital Xi
(char-name '|bsansOmicron| (integer->char #x1D764))			; 𝝤	Mathematical Sans-Serif Bold Capital Omicron
(char-name '|bsansPi| (integer->char #x1D765))			; 𝝥	Mathematical Sans-Serif Bold Capital Pi
(char-name '|bsansRho| (integer->char #x1D766))			; 𝝦	Mathematical Sans-Serif Bold Capital Rho
(char-name '|bsansvarTheta| (integer->char #x1D767))			; 𝝧	Mathematical Sans-Serif Bold Capital Theta Symbol
(char-name '|bsansSigma| (integer->char #x1D768))			; 𝝨	Mathematical Sans-Serif Bold Capital Sigma
(char-name '|bsansTau| (integer->char #x1D769))			; 𝝩	Mathematical Sans-Serif Bold Capital Tau
(char-name '|bsansUpsilon| (integer->char #x1D76A))			; 𝝪	Mathematical Sans-Serif Bold Capital Upsilon
(char-name '|bsansPhi| (integer->char #x1D76B))			; 𝝫	Mathematical Sans-Serif Bold Capital Phi
(char-name '|bsansChi| (integer->char #x1D76C))			; 𝝬	Mathematical Sans-Serif Bold Capital Chi
(char-name '|bsansPsi| (integer->char #x1D76D))			; 𝝭	Mathematical Sans-Serif Bold Capital Psi
(char-name '|bsansOmega| (integer->char #x1D76E))			; 𝝮	Mathematical Sans-Serif Bold Capital Omega
(char-name '|bsansnabla| (integer->char #x1D76F))			; 𝝯	Mathematical Sans-Serif Bold Nabla
(char-name '|bsansalpha| (integer->char #x1D770))			; 𝝰	Mathematical Sans-Serif Bold Small Alpha
(char-name '|bsansbeta| (integer->char #x1D771))			; 𝝱	Mathematical Sans-Serif Bold Small Beta
(char-name '|bsansgamma| (integer->char #x1D772))			; 𝝲	Mathematical Sans-Serif Bold Small Gamma
(char-name '|bsansdelta| (integer->char #x1D773))			; 𝝳	Mathematical Sans-Serif Bold Small Delta
(char-name '|bsansepsilon| (integer->char #x1D774))			; 𝝴	Mathematical Sans-Serif Bold Small Epsilon
(char-name '|bsanszeta| (integer->char #x1D775))			; 𝝵	Mathematical Sans-Serif Bold Small Zeta
(char-name '|bsanseta| (integer->char #x1D776))			; 𝝶	Mathematical Sans-Serif Bold Small Eta
(char-name '|bsanstheta| (integer->char #x1D777))			; 𝝷	Mathematical Sans-Serif Bold Small Theta
(char-name '|bsansiota| (integer->char #x1D778))			; 𝝸	Mathematical Sans-Serif Bold Small Iota
(char-name '|bsanskappa| (integer->char #x1D779))			; 𝝹	Mathematical Sans-Serif Bold Small Kappa
(char-name '|bsanslambda| (integer->char #x1D77A))			; 𝝺	Mathematical Sans-Serif Bold Small Lamda
(char-name '|bsansmu| (integer->char #x1D77B))			; 𝝻	Mathematical Sans-Serif Bold Small Mu
(char-name '|bsansnu| (integer->char #x1D77C))			; 𝝼	Mathematical Sans-Serif Bold Small Nu
(char-name '|bsansxi| (integer->char #x1D77D))			; 𝝽	Mathematical Sans-Serif Bold Small Xi
(char-name '|bsansomicron| (integer->char #x1D77E))			; 𝝾	Mathematical Sans-Serif Bold Small Omicron
(char-name '|bsanspi| (integer->char #x1D77F))			; 𝝿	Mathematical Sans-Serif Bold Small Pi
(char-name '|bsansrho| (integer->char #x1D780))			; 𝞀	Mathematical Sans-Serif Bold Small Rho
(char-name '|bsansvarsigma| (integer->char #x1D781))			; 𝞁	Mathematical Sans-Serif Bold Small Final Sigma
(char-name '|bsanssigma| (integer->char #x1D782))			; 𝞂	Mathematical Sans-Serif Bold Small Sigma
(char-name '|bsanstau| (integer->char #x1D783))			; 𝞃	Mathematical Sans-Serif Bold Small Tau
(char-name '|bsansupsilon| (integer->char #x1D784))			; 𝞄	Mathematical Sans-Serif Bold Small Upsilon
(char-name '|bsansphi| (integer->char #x1D785))			; 𝞅	Mathematical Sans-Serif Bold Small Phi
(char-name '|bsanschi| (integer->char #x1D786))			; 𝞆	Mathematical Sans-Serif Bold Small Chi
(char-name '|bsanspsi| (integer->char #x1D787))			; 𝞇	Mathematical Sans-Serif Bold Small Psi
(char-name '|bsansomega| (integer->char #x1D788))			; 𝞈	Mathematical Sans-Serif Bold Small Omega
(char-name '|bsanspartial| (integer->char #x1D789))			; 𝞉	Mathematical Sans-Serif Bold Partial Differential
(char-name '|bsansvarepsilon| (integer->char #x1D78A))			; 𝞊	Mathematical Sans-Serif Bold Epsilon Symbol
(char-name '|bsansvartheta| (integer->char #x1D78B))			; 𝞋	Mathematical Sans-Serif Bold Theta Symbol
(char-name '|bsansvarkappa| (integer->char #x1D78C))			; 𝞌	Mathematical Sans-Serif Bold Kappa Symbol
(char-name '|bsansvarphi| (integer->char #x1D78D))			; 𝞍	Mathematical Sans-Serif Bold Phi Symbol
(char-name '|bsansvarrho| (integer->char #x1D78E))			; 𝞎	Mathematical Sans-Serif Bold Rho Symbol
(char-name '|bsansvarpi| (integer->char #x1D78F))			; 𝞏	Mathematical Sans-Serif Bold Pi Symbol
(char-name '|bisansAlpha| (integer->char #x1D790))			; 𝞐	Mathematical Sans-Serif Bold Italic Capital Alpha
(char-name '|bisansBeta| (integer->char #x1D791))			; 𝞑	Mathematical Sans-Serif Bold Italic Capital Beta
(char-name '|bisansGamma| (integer->char #x1D792))			; 𝞒	Mathematical Sans-Serif Bold Italic Capital Gamma
(char-name '|bisansDelta| (integer->char #x1D793))			; 𝞓	Mathematical Sans-Serif Bold Italic Capital Delta
(char-name '|bisansEpsilon| (integer->char #x1D794))			; 𝞔	Mathematical Sans-Serif Bold Italic Capital Epsilon
(char-name '|bisansZeta| (integer->char #x1D795))			; 𝞕	Mathematical Sans-Serif Bold Italic Capital Zeta
(char-name '|bisansEta| (integer->char #x1D796))			; 𝞖	Mathematical Sans-Serif Bold Italic Capital Eta
(char-name '|bisansTheta| (integer->char #x1D797))			; 𝞗	Mathematical Sans-Serif Bold Italic Capital Theta
(char-name '|bisansIota| (integer->char #x1D798))			; 𝞘	Mathematical Sans-Serif Bold Italic Capital Iota
(char-name '|bisansKappa| (integer->char #x1D799))			; 𝞙	Mathematical Sans-Serif Bold Italic Capital Kappa
(char-name '|bisansLambda| (integer->char #x1D79A))			; 𝞚	Mathematical Sans-Serif Bold Italic Capital Lamda
(char-name '|bisansMu| (integer->char #x1D79B))			; 𝞛	Mathematical Sans-Serif Bold Italic Capital Mu
(char-name '|bisansNu| (integer->char #x1D79C))			; 𝞜	Mathematical Sans-Serif Bold Italic Capital Nu
(char-name '|bisansXi| (integer->char #x1D79D))			; 𝞝	Mathematical Sans-Serif Bold Italic Capital Xi
(char-name '|bisansOmicron| (integer->char #x1D79E))			; 𝞞	Mathematical Sans-Serif Bold Italic Capital Omicron
(char-name '|bisansPi| (integer->char #x1D79F))			; 𝞟	Mathematical Sans-Serif Bold Italic Capital Pi
(char-name '|bisansRho| (integer->char #x1D7A0))			; 𝞠	Mathematical Sans-Serif Bold Italic Capital Rho
(char-name '|bisansvarTheta| (integer->char #x1D7A1))			; 𝞡	Mathematical Sans-Serif Bold Italic Capital Theta Symbol
(char-name '|bisansSigma| (integer->char #x1D7A2))			; 𝞢	Mathematical Sans-Serif Bold Italic Capital Sigma
(char-name '|bisansTau| (integer->char #x1D7A3))			; 𝞣	Mathematical Sans-Serif Bold Italic Capital Tau
(char-name '|bisansUpsilon| (integer->char #x1D7A4))			; 𝞤	Mathematical Sans-Serif Bold Italic Capital Upsilon
(char-name '|bisansPhi| (integer->char #x1D7A5))			; 𝞥	Mathematical Sans-Serif Bold Italic Capital Phi
(char-name '|bisansChi| (integer->char #x1D7A6))			; 𝞦	Mathematical Sans-Serif Bold Italic Capital Chi
(char-name '|bisansPsi| (integer->char #x1D7A7))			; 𝞧	Mathematical Sans-Serif Bold Italic Capital Psi
(char-name '|bisansOmega| (integer->char #x1D7A8))			; 𝞨	Mathematical Sans-Serif Bold Italic Capital Omega
(char-name '|bisansnabla| (integer->char #x1D7A9))			; 𝞩	Mathematical Sans-Serif Bold Italic Nabla
(char-name '|bisansalpha| (integer->char #x1D7AA))			; 𝞪	Mathematical Sans-Serif Bold Italic Small Alpha
(char-name '|bisansbeta| (integer->char #x1D7AB))			; 𝞫	Mathematical Sans-Serif Bold Italic Small Beta
(char-name '|bisansgamma| (integer->char #x1D7AC))			; 𝞬	Mathematical Sans-Serif Bold Italic Small Gamma
(char-name '|bisansdelta| (integer->char #x1D7AD))			; 𝞭	Mathematical Sans-Serif Bold Italic Small Delta
(char-name '|bisansepsilon| (integer->char #x1D7AE))			; 𝞮	Mathematical Sans-Serif Bold Italic Small Epsilon
(char-name '|bisanszeta| (integer->char #x1D7AF))			; 𝞯	Mathematical Sans-Serif Bold Italic Small Zeta
(char-name '|bisanseta| (integer->char #x1D7B0))			; 𝞰	Mathematical Sans-Serif Bold Italic Small Eta
(char-name '|bisanstheta| (integer->char #x1D7B1))			; 𝞱	Mathematical Sans-Serif Bold Italic Small Theta
(char-name '|bisansiota| (integer->char #x1D7B2))			; 𝞲	Mathematical Sans-Serif Bold Italic Small Iota
(char-name '|bisanskappa| (integer->char #x1D7B3))			; 𝞳	Mathematical Sans-Serif Bold Italic Small Kappa
(char-name '|bisanslambda| (integer->char #x1D7B4))			; 𝞴	Mathematical Sans-Serif Bold Italic Small Lamda
(char-name '|bisansmu| (integer->char #x1D7B5))			; 𝞵	Mathematical Sans-Serif Bold Italic Small Mu
(char-name '|bisansnu| (integer->char #x1D7B6))			; 𝞶	Mathematical Sans-Serif Bold Italic Small Nu
(char-name '|bisansxi| (integer->char #x1D7B7))			; 𝞷	Mathematical Sans-Serif Bold Italic Small Xi
(char-name '|bisansomicron| (integer->char #x1D7B8))			; 𝞸	Mathematical Sans-Serif Bold Italic Small Omicron
(char-name '|bisanspi| (integer->char #x1D7B9))			; 𝞹	Mathematical Sans-Serif Bold Italic Small Pi
(char-name '|bisansrho| (integer->char #x1D7BA))			; 𝞺	Mathematical Sans-Serif Bold Italic Small Rho
(char-name '|bisansvarsigma| (integer->char #x1D7BB))			; 𝞻	Mathematical Sans-Serif Bold Italic Small Final Sigma
(char-name '|bisanssigma| (integer->char #x1D7BC))			; 𝞼	Mathematical Sans-Serif Bold Italic Small Sigma
(char-name '|bisanstau| (integer->char #x1D7BD))			; 𝞽	Mathematical Sans-Serif Bold Italic Small Tau
(char-name '|bisansupsilon| (integer->char #x1D7BE))			; 𝞾	Mathematical Sans-Serif Bold Italic Small Upsilon
(char-name '|bisansphi| (integer->char #x1D7BF))			; 𝞿	Mathematical Sans-Serif Bold Italic Small Phi
(char-name '|bisanschi| (integer->char #x1D7C0))			; 𝟀	Mathematical Sans-Serif Bold Italic Small Chi
(char-name '|bisanspsi| (integer->char #x1D7C1))			; 𝟁	Mathematical Sans-Serif Bold Italic Small Psi
(char-name '|bisansomega| (integer->char #x1D7C2))			; 𝟂	Mathematical Sans-Serif Bold Italic Small Omega
(char-name '|bisanspartial| (integer->char #x1D7C3))			; 𝟃	Mathematical Sans-Serif Bold Italic Partial Differential
(char-name '|bisansvarepsilon| (integer->char #x1D7C4))			; 𝟄	Mathematical Sans-Serif Bold Italic Epsilon Symbol
(char-name '|bisansvartheta| (integer->char #x1D7C5))			; 𝟅	Mathematical Sans-Serif Bold Italic Theta Symbol
(char-name '|bisansvarkappa| (integer->char #x1D7C6))			; 𝟆	Mathematical Sans-Serif Bold Italic Kappa Symbol
(char-name '|bisansvarphi| (integer->char #x1D7C7))			; 𝟇	Mathematical Sans-Serif Bold Italic Phi Symbol
(char-name '|bisansvarrho| (integer->char #x1D7C8))			; 𝟈	Mathematical Sans-Serif Bold Italic Rho Symbol
(char-name '|bisansvarpi| (integer->char #x1D7C9))			; 𝟉	Mathematical Sans-Serif Bold Italic Pi Symbol
(char-name '|bfDigamma| (integer->char #x1D7CA))			; 𝟊	Mathematical Bold Capital Digamma
(char-name '|bfdigamma| (integer->char #x1D7CB))			; 𝟋	Mathematical Bold Small Digamma
(char-name '|bfzero| (integer->char #x1D7CE))			; 𝟎	Mathematical Bold Digit Zero
(char-name '|bfone| (integer->char #x1D7CF))			; 𝟏	Mathematical Bold Digit One
(char-name '|bftwo| (integer->char #x1D7D0))			; 𝟐	Mathematical Bold Digit Two
(char-name '|bfthree| (integer->char #x1D7D1))			; 𝟑	Mathematical Bold Digit Three
(char-name '|bffour| (integer->char #x1D7D2))			; 𝟒	Mathematical Bold Digit Four
(char-name '|bffive| (integer->char #x1D7D3))			; 𝟓	Mathematical Bold Digit Five
(char-name '|bfsix| (integer->char #x1D7D4))			; 𝟔	Mathematical Bold Digit Six
(char-name '|bfseven| (integer->char #x1D7D5))			; 𝟕	Mathematical Bold Digit Seven
(char-name '|bfeight| (integer->char #x1D7D6))			; 𝟖	Mathematical Bold Digit Eight
(char-name '|bfnine| (integer->char #x1D7D7))			; 𝟗	Mathematical Bold Digit Nine
(char-name '|bbzero| (integer->char #x1D7D8))			; 𝟘	Mathematical Double-Struck Digit Zero
(char-name '|bbone| (integer->char #x1D7D9))			; 𝟙	Mathematical Double-Struck Digit One
(char-name '|bbtwo| (integer->char #x1D7DA))			; 𝟚	Mathematical Double-Struck Digit Two
(char-name '|bbthree| (integer->char #x1D7DB))			; 𝟛	Mathematical Double-Struck Digit Three
(char-name '|bbfour| (integer->char #x1D7DC))			; 𝟜	Mathematical Double-Struck Digit Four
(char-name '|bbfive| (integer->char #x1D7DD))			; 𝟝	Mathematical Double-Struck Digit Five
(char-name '|bbsix| (integer->char #x1D7DE))			; 𝟞	Mathematical Double-Struck Digit Six
(char-name '|bbseven| (integer->char #x1D7DF))			; 𝟟	Mathematical Double-Struck Digit Seven
(char-name '|bbeight| (integer->char #x1D7E0))			; 𝟠	Mathematical Double-Struck Digit Eight
(char-name '|bbnine| (integer->char #x1D7E1))			; 𝟡	Mathematical Double-Struck Digit Nine
(char-name '|sanszero| (integer->char #x1D7E2))			; 𝟢	Mathematical Sans-Serif Digit Zero
(char-name '|sansone| (integer->char #x1D7E3))			; 𝟣	Mathematical Sans-Serif Digit One
(char-name '|sanstwo| (integer->char #x1D7E4))			; 𝟤	Mathematical Sans-Serif Digit Two
(char-name '|sansthree| (integer->char #x1D7E5))			; 𝟥	Mathematical Sans-Serif Digit Three
(char-name '|sansfour| (integer->char #x1D7E6))			; 𝟦	Mathematical Sans-Serif Digit Four
(char-name '|sansfive| (integer->char #x1D7E7))			; 𝟧	Mathematical Sans-Serif Digit Five
(char-name '|sanssix| (integer->char #x1D7E8))			; 𝟨	Mathematical Sans-Serif Digit Six
(char-name '|sansseven| (integer->char #x1D7E9))			; 𝟩	Mathematical Sans-Serif Digit Seven
(char-name '|sanseight| (integer->char #x1D7EA))			; 𝟪	Mathematical Sans-Serif Digit Eight
(char-name '|sansnine| (integer->char #x1D7EB))			; 𝟫	Mathematical Sans-Serif Digit Nine
(char-name '|bsanszero| (integer->char #x1D7EC))			; 𝟬	Mathematical Sans-Serif Bold Digit Zero
(char-name '|bsansone| (integer->char #x1D7ED))			; 𝟭	Mathematical Sans-Serif Bold Digit One
(char-name '|bsanstwo| (integer->char #x1D7EE))			; 𝟮	Mathematical Sans-Serif Bold Digit Two
(char-name '|bsansthree| (integer->char #x1D7EF))			; 𝟯	Mathematical Sans-Serif Bold Digit Three
(char-name '|bsansfour| (integer->char #x1D7F0))			; 𝟰	Mathematical Sans-Serif Bold Digit Four
(char-name '|bsansfive| (integer->char #x1D7F1))			; 𝟱	Mathematical Sans-Serif Bold Digit Five
(char-name '|bsanssix| (integer->char #x1D7F2))			; 𝟲	Mathematical Sans-Serif Bold Digit Six
(char-name '|bsansseven| (integer->char #x1D7F3))			; 𝟳	Mathematical Sans-Serif Bold Digit Seven
(char-name '|bsanseight| (integer->char #x1D7F4))			; 𝟴	Mathematical Sans-Serif Bold Digit Eight
(char-name '|bsansnine| (integer->char #x1D7F5))			; 𝟵	Mathematical Sans-Serif Bold Digit Nine
(char-name '|ttzero| (integer->char #x1D7F6))			; 𝟶	Mathematical Monospace Digit Zero
(char-name '|ttone| (integer->char #x1D7F7))			; 𝟷	Mathematical Monospace Digit One
(char-name '|tttwo| (integer->char #x1D7F8))			; 𝟸	Mathematical Monospace Digit Two
(char-name '|ttthree| (integer->char #x1D7F9))			; 𝟹	Mathematical Monospace Digit Three
(char-name '|ttfour| (integer->char #x1D7FA))			; 𝟺	Mathematical Monospace Digit Four
(char-name '|ttfive| (integer->char #x1D7FB))			; 𝟻	Mathematical Monospace Digit Five
(char-name '|ttsix| (integer->char #x1D7FC))			; 𝟼	Mathematical Monospace Digit Six
(char-name '|ttseven| (integer->char #x1D7FD))			; 𝟽	Mathematical Monospace Digit Seven
(char-name '|tteight| (integer->char #x1D7FE))			; 𝟾	Mathematical Monospace Digit Eight
(char-name '|ttnine| (integer->char #x1D7FF))			; 𝟿	Mathematical Monospace Digit Nine
(char-name '|:mahjong:| (integer->char #x1F004))			; 🀄	Mahjong Tile Red Dragon
(char-name '|:black_joker:| (integer->char #x1F0CF))			; 🃏	Playing Card Black Joker
(char-name '|:a:| (integer->char #x1F170))			; 🅰	Negative Squared Latin Capital Letter A
(char-name '|:b:| (integer->char #x1F171))			; 🅱	Negative Squared Latin Capital Letter B
(char-name '|:o2:| (integer->char #x1F17E))			; 🅾	Negative Squared Latin Capital Letter O
(char-name '|:parking:| (integer->char #x1F17F))			; 🅿	Negative Squared Latin Capital Letter P
(char-name '|:ab:| (integer->char #x1F18E))			; 🆎	Negative Squared Ab
(char-name '|:cl:| (integer->char #x1F191))			; 🆑	Squared Cl
(char-name '|:cool:| (integer->char #x1F192))			; 🆒	Squared Cool
(char-name '|:free:| (integer->char #x1F193))			; 🆓	Squared Free
(char-name '|:id:| (integer->char #x1F194))			; 🆔	Squared Id
(char-name '|:new:| (integer->char #x1F195))			; 🆕	Squared New
(char-name '|:ng:| (integer->char #x1F196))			; 🆖	Squared Ng
(char-name '|:ok:| (integer->char #x1F197))			; 🆗	Squared Ok
(char-name '|:sos:| (integer->char #x1F198))			; 🆘	Squared Sos
(char-name '|:up:| (integer->char #x1F199))			; 🆙	Squared Up With Exclamation Mark
(char-name '|:vs:| (integer->char #x1F19A))			; 🆚	Squared Vs
(char-name '|:koko:| (integer->char #x1F201))			; 🈁	Squared Katakana Koko
(char-name '|:sa:| (integer->char #x1F202))			; 🈂	Squared Katakana Sa
(char-name '|:u7121:| (integer->char #x1F21A))			; 🈚	Squared Cjk Unified Ideograph-7121
(char-name '|:u6307:| (integer->char #x1F22F))			; 🈯	Squared Cjk Unified Ideograph-6307
(char-name '|:u7981:| (integer->char #x1F232))			; 🈲	Squared Cjk Unified Ideograph-7981
(char-name '|:u7a7a:| (integer->char #x1F233))			; 🈳	Squared Cjk Unified Ideograph-7A7A
(char-name '|:u5408:| (integer->char #x1F234))			; 🈴	Squared Cjk Unified Ideograph-5408
(char-name '|:u6e80:| (integer->char #x1F235))			; 🈵	Squared Cjk Unified Ideograph-6E80
(char-name '|:u6709:| (integer->char #x1F236))			; 🈶	Squared Cjk Unified Ideograph-6709
(char-name '|:u6708:| (integer->char #x1F237))			; 🈷	Squared Cjk Unified Ideograph-6708
(char-name '|:u7533:| (integer->char #x1F238))			; 🈸	Squared Cjk Unified Ideograph-7533
(char-name '|:u5272:| (integer->char #x1F239))			; 🈹	Squared Cjk Unified Ideograph-5272
(char-name '|:u55b6:| (integer->char #x1F23A))			; 🈺	Squared Cjk Unified Ideograph-55B6
(char-name '|:ideograph_advantage:| (integer->char #x1F250))			; 🉐	Circled Ideograph Advantage
(char-name '|:accept:| (integer->char #x1F251))			; 🉑	Circled Ideograph Accept
(char-name '|:cyclone:| (integer->char #x1F300))			; 🌀	Cyclone
(char-name '|:foggy:| (integer->char #x1F301))			; 🌁	Foggy
(char-name '|:closed_umbrella:| (integer->char #x1F302))			; 🌂	Closed Umbrella
(char-name '|:night_with_stars:| (integer->char #x1F303))			; 🌃	Night With Stars
(char-name '|:sunrise_over_mountains:| (integer->char #x1F304))			; 🌄	Sunrise Over Mountains
(char-name '|:sunrise:| (integer->char #x1F305))			; 🌅	Sunrise
(char-name '|:city_sunset:| (integer->char #x1F306))			; 🌆	Cityscape At Dusk
(char-name '|:city_sunrise:| (integer->char #x1F307))			; 🌇	Sunset Over Buildings
(char-name '|:rainbow:| (integer->char #x1F308))			; 🌈	Rainbow
(char-name '|:bridge_at_night:| (integer->char #x1F309))			; 🌉	Bridge At Night
(char-name '|:ocean:| (integer->char #x1F30A))			; 🌊	Water Wave
(char-name '|:volcano:| (integer->char #x1F30B))			; 🌋	Volcano
(char-name '|:milky_way:| (integer->char #x1F30C))			; 🌌	Milky Way
(char-name '|:earth_africa:| (integer->char #x1F30D))			; 🌍	Earth Globe Europe-Africa
(char-name '|:earth_americas:| (integer->char #x1F30E))			; 🌎	Earth Globe Americas
(char-name '|:earth_asia:| (integer->char #x1F30F))			; 🌏	Earth Globe Asia-Australia
(char-name '|:globe_with_meridians:| (integer->char #x1F310))			; 🌐	Globe With Meridians
(char-name '|:new_moon:| (integer->char #x1F311))			; 🌑	New Moon Symbol
(char-name '|:waxing_crescent_moon:| (integer->char #x1F312))			; 🌒	Waxing Crescent Moon Symbol
(char-name '|:first_quarter_moon:| (integer->char #x1F313))			; 🌓	First Quarter Moon Symbol
(char-name '|:moon:| (integer->char #x1F314))			; 🌔	Waxing Gibbous Moon Symbol
(char-name '|:full_moon:| (integer->char #x1F315))			; 🌕	Full Moon Symbol
(char-name '|:waning_gibbous_moon:| (integer->char #x1F316))			; 🌖	Waning Gibbous Moon Symbol
(char-name '|:last_quarter_moon:| (integer->char #x1F317))			; 🌗	Last Quarter Moon Symbol
(char-name '|:waning_crescent_moon:| (integer->char #x1F318))			; 🌘	Waning Crescent Moon Symbol
(char-name '|:crescent_moon:| (integer->char #x1F319))			; 🌙	Crescent Moon
(char-name '|:new_moon_with_face:| (integer->char #x1F31A))			; 🌚	New Moon With Face
(char-name '|:first_quarter_moon_with_face:| (integer->char #x1F31B))			; 🌛	First Quarter Moon With Face
(char-name '|:last_quarter_moon_with_face:| (integer->char #x1F31C))			; 🌜	Last Quarter Moon With Face
(char-name '|:full_moon_with_face:| (integer->char #x1F31D))			; 🌝	Full Moon With Face
(char-name '|:sun_with_face:| (integer->char #x1F31E))			; 🌞	Sun With Face
(char-name '|:star2:| (integer->char #x1F31F))			; 🌟	Glowing Star
(char-name '|:stars:| (integer->char #x1F320))			; 🌠	Shooting Star
(char-name '|:chestnut:| (integer->char #x1F330))			; 🌰	Chestnut
(char-name '|:seedling:| (integer->char #x1F331))			; 🌱	Seedling
(char-name '|:evergreen_tree:| (integer->char #x1F332))			; 🌲	Evergreen Tree
(char-name '|:deciduous_tree:| (integer->char #x1F333))			; 🌳	Deciduous Tree
(char-name '|:palm_tree:| (integer->char #x1F334))			; 🌴	Palm Tree
(char-name '|:cactus:| (integer->char #x1F335))			; 🌵	Cactus
(char-name '|:tulip:| (integer->char #x1F337))			; 🌷	Tulip
(char-name '|:cherry_blossom:| (integer->char #x1F338))			; 🌸	Cherry Blossom
(char-name '|:rose:| (integer->char #x1F339))			; 🌹	Rose
(char-name '|:hibiscus:| (integer->char #x1F33A))			; 🌺	Hibiscus
(char-name '|:sunflower:| (integer->char #x1F33B))			; 🌻	Sunflower
(char-name '|:blossom:| (integer->char #x1F33C))			; 🌼	Blossom
(char-name '|:corn:| (integer->char #x1F33D))			; 🌽	Ear Of Maize
(char-name '|:ear_of_rice:| (integer->char #x1F33E))			; 🌾	Ear Of Rice
(char-name '|:herb:| (integer->char #x1F33F))			; 🌿	Herb
(char-name '|:four_leaf_clover:| (integer->char #x1F340))			; 🍀	Four Leaf Clover
(char-name '|:maple_leaf:| (integer->char #x1F341))			; 🍁	Maple Leaf
(char-name '|:fallen_leaf:| (integer->char #x1F342))			; 🍂	Fallen Leaf
(char-name '|:leaves:| (integer->char #x1F343))			; 🍃	Leaf Fluttering In Wind
(char-name '|:mushroom:| (integer->char #x1F344))			; 🍄	Mushroom
(char-name '|:tomato:| (integer->char #x1F345))			; 🍅	Tomato
(char-name '|:eggplant:| (integer->char #x1F346))			; 🍆	Aubergine
(char-name '|:grapes:| (integer->char #x1F347))			; 🍇	Grapes
(char-name '|:melon:| (integer->char #x1F348))			; 🍈	Melon
(char-name '|:watermelon:| (integer->char #x1F349))			; 🍉	Watermelon
(char-name '|:tangerine:| (integer->char #x1F34A))			; 🍊	Tangerine
(char-name '|:lemon:| (integer->char #x1F34B))			; 🍋	Lemon
(char-name '|:banana:| (integer->char #x1F34C))			; 🍌	Banana
(char-name '|:pineapple:| (integer->char #x1F34D))			; 🍍	Pineapple
(char-name '|:apple:| (integer->char #x1F34E))			; 🍎	Red Apple
(char-name '|:green_apple:| (integer->char #x1F34F))			; 🍏	Green Apple
(char-name '|:pear:| (integer->char #x1F350))			; 🍐	Pear
(char-name '|:peach:| (integer->char #x1F351))			; 🍑	Peach
(char-name '|:cherries:| (integer->char #x1F352))			; 🍒	Cherries
(char-name '|:strawberry:| (integer->char #x1F353))			; 🍓	Strawberry
(char-name '|:hamburger:| (integer->char #x1F354))			; 🍔	Hamburger
(char-name '|:pizza:| (integer->char #x1F355))			; 🍕	Slice Of Pizza
(char-name '|:meat_on_bone:| (integer->char #x1F356))			; 🍖	Meat On Bone
(char-name '|:poultry_leg:| (integer->char #x1F357))			; 🍗	Poultry Leg
(char-name '|:rice_cracker:| (integer->char #x1F358))			; 🍘	Rice Cracker
(char-name '|:rice_ball:| (integer->char #x1F359))			; 🍙	Rice Ball
(char-name '|:rice:| (integer->char #x1F35A))			; 🍚	Cooked Rice
(char-name '|:curry:| (integer->char #x1F35B))			; 🍛	Curry And Rice
(char-name '|:ramen:| (integer->char #x1F35C))			; 🍜	Steaming Bowl
(char-name '|:spaghetti:| (integer->char #x1F35D))			; 🍝	Spaghetti
(char-name '|:bread:| (integer->char #x1F35E))			; 🍞	Bread
(char-name '|:fries:| (integer->char #x1F35F))			; 🍟	French Fries
(char-name '|:sweet_potato:| (integer->char #x1F360))			; 🍠	Roasted Sweet Potato
(char-name '|:dango:| (integer->char #x1F361))			; 🍡	Dango
(char-name '|:oden:| (integer->char #x1F362))			; 🍢	Oden
(char-name '|:sushi:| (integer->char #x1F363))			; 🍣	Sushi
(char-name '|:fried_shrimp:| (integer->char #x1F364))			; 🍤	Fried Shrimp
(char-name '|:fish_cake:| (integer->char #x1F365))			; 🍥	Fish Cake With Swirl Design
(char-name '|:icecream:| (integer->char #x1F366))			; 🍦	Soft Ice Cream
(char-name '|:shaved_ice:| (integer->char #x1F367))			; 🍧	Shaved Ice
(char-name '|:ice_cream:| (integer->char #x1F368))			; 🍨	Ice Cream
(char-name '|:doughnut:| (integer->char #x1F369))			; 🍩	Doughnut
(char-name '|:cookie:| (integer->char #x1F36A))			; 🍪	Cookie
(char-name '|:chocolate_bar:| (integer->char #x1F36B))			; 🍫	Chocolate Bar
(char-name '|:candy:| (integer->char #x1F36C))			; 🍬	Candy
(char-name '|:lollipop:| (integer->char #x1F36D))			; 🍭	Lollipop
(char-name '|:custard:| (integer->char #x1F36E))			; 🍮	Custard
(char-name '|:honey_pot:| (integer->char #x1F36F))			; 🍯	Honey Pot
(char-name '|:cake:| (integer->char #x1F370))			; 🍰	Shortcake
(char-name '|:bento:| (integer->char #x1F371))			; 🍱	Bento Box
(char-name '|:stew:| (integer->char #x1F372))			; 🍲	Pot Of Food
(char-name '|:egg:| (integer->char #x1F373))			; 🍳	Cooking
(char-name '|:fork_and_knife:| (integer->char #x1F374))			; 🍴	Fork And Knife
(char-name '|:tea:| (integer->char #x1F375))			; 🍵	Teacup Without Handle
(char-name '|:sake:| (integer->char #x1F376))			; 🍶	Sake Bottle And Cup
(char-name '|:wine_glass:| (integer->char #x1F377))			; 🍷	Wine Glass
(char-name '|:cocktail:| (integer->char #x1F378))			; 🍸	Cocktail Glass
(char-name '|:tropical_drink:| (integer->char #x1F379))			; 🍹	Tropical Drink
(char-name '|:beer:| (integer->char #x1F37A))			; 🍺	Beer Mug
(char-name '|:beers:| (integer->char #x1F37B))			; 🍻	Clinking Beer Mugs
(char-name '|:baby_bottle:| (integer->char #x1F37C))			; 🍼	Baby Bottle
(char-name '|:ribbon:| (integer->char #x1F380))			; 🎀	Ribbon
(char-name '|:gift:| (integer->char #x1F381))			; 🎁	Wrapped Present
(char-name '|:birthday:| (integer->char #x1F382))			; 🎂	Birthday Cake
(char-name '|:jack_o_lantern:| (integer->char #x1F383))			; 🎃	Jack-O-Lantern
(char-name '|:christmas_tree:| (integer->char #x1F384))			; 🎄	Christmas Tree
(char-name '|:santa:| (integer->char #x1F385))			; 🎅	Father Christmas
(char-name '|:fireworks:| (integer->char #x1F386))			; 🎆	Fireworks
(char-name '|:sparkler:| (integer->char #x1F387))			; 🎇	Firework Sparkler
(char-name '|:balloon:| (integer->char #x1F388))			; 🎈	Balloon
(char-name '|:tada:| (integer->char #x1F389))			; 🎉	Party Popper
(char-name '|:confetti_ball:| (integer->char #x1F38A))			; 🎊	Confetti Ball
(char-name '|:tanabata_tree:| (integer->char #x1F38B))			; 🎋	Tanabata Tree
(char-name '|:crossed_flags:| (integer->char #x1F38C))			; 🎌	Crossed Flags
(char-name '|:bamboo:| (integer->char #x1F38D))			; 🎍	Pine Decoration
(char-name '|:dolls:| (integer->char #x1F38E))			; 🎎	Japanese Dolls
(char-name '|:flags:| (integer->char #x1F38F))			; 🎏	Carp Streamer
(char-name '|:wind_chime:| (integer->char #x1F390))			; 🎐	Wind Chime
(char-name '|:rice_scene:| (integer->char #x1F391))			; 🎑	Moon Viewing Ceremony
(char-name '|:school_satchel:| (integer->char #x1F392))			; 🎒	School Satchel
(char-name '|:mortar_board:| (integer->char #x1F393))			; 🎓	Graduation Cap
(char-name '|:carousel_horse:| (integer->char #x1F3A0))			; 🎠	Carousel Horse
(char-name '|:ferris_wheel:| (integer->char #x1F3A1))			; 🎡	Ferris Wheel
(char-name '|:roller_coaster:| (integer->char #x1F3A2))			; 🎢	Roller Coaster
(char-name '|:fishing_pole_and_fish:| (integer->char #x1F3A3))			; 🎣	Fishing Pole And Fish
(char-name '|:microphone:| (integer->char #x1F3A4))			; 🎤	Microphone
(char-name '|:movie_camera:| (integer->char #x1F3A5))			; 🎥	Movie Camera
(char-name '|:cinema:| (integer->char #x1F3A6))			; 🎦	Cinema
(char-name '|:headphones:| (integer->char #x1F3A7))			; 🎧	Headphone
(char-name '|:art:| (integer->char #x1F3A8))			; 🎨	Artist Palette
(char-name '|:tophat:| (integer->char #x1F3A9))			; 🎩	Top Hat
(char-name '|:circus_tent:| (integer->char #x1F3AA))			; 🎪	Circus Tent
(char-name '|:ticket:| (integer->char #x1F3AB))			; 🎫	Ticket
(char-name '|:clapper:| (integer->char #x1F3AC))			; 🎬	Clapper Board
(char-name '|:performing_arts:| (integer->char #x1F3AD))			; 🎭	Performing Arts
(char-name '|:video_game:| (integer->char #x1F3AE))			; 🎮	Video Game
(char-name '|:dart:| (integer->char #x1F3AF))			; 🎯	Direct Hit
(char-name '|:slot_machine:| (integer->char #x1F3B0))			; 🎰	Slot Machine
(char-name '|:8ball:| (integer->char #x1F3B1))			; 🎱	Billiards
(char-name '|:game_die:| (integer->char #x1F3B2))			; 🎲	Game Die
(char-name '|:bowling:| (integer->char #x1F3B3))			; 🎳	Bowling
(char-name '|:flower_playing_cards:| (integer->char #x1F3B4))			; 🎴	Flower Playing Cards
(char-name '|:musical_note:| (integer->char #x1F3B5))			; 🎵	Musical Note
(char-name '|:notes:| (integer->char #x1F3B6))			; 🎶	Multiple Musical Notes
(char-name '|:saxophone:| (integer->char #x1F3B7))			; 🎷	Saxophone
(char-name '|:guitar:| (integer->char #x1F3B8))			; 🎸	Guitar
(char-name '|:musical_keyboard:| (integer->char #x1F3B9))			; 🎹	Musical Keyboard
(char-name '|:trumpet:| (integer->char #x1F3BA))			; 🎺	Trumpet
(char-name '|:violin:| (integer->char #x1F3BB))			; 🎻	Violin
(char-name '|:musical_score:| (integer->char #x1F3BC))			; 🎼	Musical Score
(char-name '|:running_shirt_with_sash:| (integer->char #x1F3BD))			; 🎽	Running Shirt With Sash
(char-name '|:tennis:| (integer->char #x1F3BE))			; 🎾	Tennis Racquet And Ball
(char-name '|:ski:| (integer->char #x1F3BF))			; 🎿	Ski And Ski Boot
(char-name '|:basketball:| (integer->char #x1F3C0))			; 🏀	Basketball And Hoop
(char-name '|:checkered_flag:| (integer->char #x1F3C1))			; 🏁	Chequered Flag
(char-name '|:snowboarder:| (integer->char #x1F3C2))			; 🏂	Snowboarder
(char-name '|:runner:| (integer->char #x1F3C3))			; 🏃	Runner
(char-name '|:surfer:| (integer->char #x1F3C4))			; 🏄	Surfer
(char-name '|:trophy:| (integer->char #x1F3C6))			; 🏆	Trophy
(char-name '|:horse_racing:| (integer->char #x1F3C7))			; 🏇	Horse Racing
(char-name '|:football:| (integer->char #x1F3C8))			; 🏈	American Football
(char-name '|:rugby_football:| (integer->char #x1F3C9))			; 🏉	Rugby Football
(char-name '|:swimmer:| (integer->char #x1F3CA))			; 🏊	Swimmer
(char-name '|:house:| (integer->char #x1F3E0))			; 🏠	House Building
(char-name '|:house_with_garden:| (integer->char #x1F3E1))			; 🏡	House With Garden
(char-name '|:office:| (integer->char #x1F3E2))			; 🏢	Office Building
(char-name '|:post_office:| (integer->char #x1F3E3))			; 🏣	Japanese Post Office
(char-name '|:european_post_office:| (integer->char #x1F3E4))			; 🏤	European Post Office
(char-name '|:hospital:| (integer->char #x1F3E5))			; 🏥	Hospital
(char-name '|:bank:| (integer->char #x1F3E6))			; 🏦	Bank
(char-name '|:atm:| (integer->char #x1F3E7))			; 🏧	Automated Teller Machine
(char-name '|:hotel:| (integer->char #x1F3E8))			; 🏨	Hotel
(char-name '|:love_hotel:| (integer->char #x1F3E9))			; 🏩	Love Hotel
(char-name '|:convenience_store:| (integer->char #x1F3EA))			; 🏪	Convenience Store
(char-name '|:school:| (integer->char #x1F3EB))			; 🏫	School
(char-name '|:department_store:| (integer->char #x1F3EC))			; 🏬	Department Store
(char-name '|:factory:| (integer->char #x1F3ED))			; 🏭	Factory
(char-name '|:izakaya_lantern:| (integer->char #x1F3EE))			; 🏮	Izakaya Lantern
(char-name '|:japanese_castle:| (integer->char #x1F3EF))			; 🏯	Japanese Castle
(char-name '|:european_castle:| (integer->char #x1F3F0))			; 🏰	European Castle
(char-name '|:skin-tone-2:| (integer->char #x1F3FB))			; 🏻	Emoji Modifier Fitzpatrick Type-1-2
(char-name '|:skin-tone-3:| (integer->char #x1F3FC))			; 🏼	Emoji Modifier Fitzpatrick Type-3
(char-name '|:skin-tone-4:| (integer->char #x1F3FD))			; 🏽	Emoji Modifier Fitzpatrick Type-4
(char-name '|:skin-tone-5:| (integer->char #x1F3FE))			; 🏾	Emoji Modifier Fitzpatrick Type-5
(char-name '|:skin-tone-6:| (integer->char #x1F3FF))			; 🏿	Emoji Modifier Fitzpatrick Type-6
(char-name '|:rat:| (integer->char #x1F400))			; 🐀	Rat
(char-name '|:mouse2:| (integer->char #x1F401))			; 🐁	Mouse
(char-name '|:ox:| (integer->char #x1F402))			; 🐂	Ox
(char-name '|:water_buffalo:| (integer->char #x1F403))			; 🐃	Water Buffalo
(char-name '|:cow2:| (integer->char #x1F404))			; 🐄	Cow
(char-name '|:tiger2:| (integer->char #x1F405))			; 🐅	Tiger
(char-name '|:leopard:| (integer->char #x1F406))			; 🐆	Leopard
(char-name '|:rabbit2:| (integer->char #x1F407))			; 🐇	Rabbit
(char-name '|:cat2:| (integer->char #x1F408))			; 🐈	Cat
(char-name '|:dragon:| (integer->char #x1F409))			; 🐉	Dragon
(char-name '|:crocodile:| (integer->char #x1F40A))			; 🐊	Crocodile
(char-name '|:whale2:| (integer->char #x1F40B))			; 🐋	Whale
(char-name '|:snail:| (integer->char #x1F40C))			; 🐌	Snail
(char-name '|:snake:| (integer->char #x1F40D))			; 🐍	Snake
(char-name '|:racehorse:| (integer->char #x1F40E))			; 🐎	Horse
(char-name '|:ram:| (integer->char #x1F40F))			; 🐏	Ram
(char-name '|:goat:| (integer->char #x1F410))			; 🐐	Goat
(char-name '|:sheep:| (integer->char #x1F411))			; 🐑	Sheep
(char-name '|:monkey:| (integer->char #x1F412))			; 🐒	Monkey
(char-name '|:rooster:| (integer->char #x1F413))			; 🐓	Rooster
(char-name '|:chicken:| (integer->char #x1F414))			; 🐔	Chicken
(char-name '|:dog2:| (integer->char #x1F415))			; 🐕	Dog
(char-name '|:pig2:| (integer->char #x1F416))			; 🐖	Pig
(char-name '|:boar:| (integer->char #x1F417))			; 🐗	Boar
(char-name '|:elephant:| (integer->char #x1F418))			; 🐘	Elephant
(char-name '|:octopus:| (integer->char #x1F419))			; 🐙	Octopus
(char-name '|:shell:| (integer->char #x1F41A))			; 🐚	Spiral Shell
(char-name '|:bug:| (integer->char #x1F41B))			; 🐛	Bug
(char-name '|:ant:| (integer->char #x1F41C))			; 🐜	Ant
(char-name '|:bee:| (integer->char #x1F41D))			; 🐝	Honeybee
(char-name '|:beetle:| (integer->char #x1F41E))			; 🐞	Lady Beetle
(char-name '|:fish:| (integer->char #x1F41F))			; 🐟	Fish
(char-name '|:tropical_fish:| (integer->char #x1F420))			; 🐠	Tropical Fish
(char-name '|:blowfish:| (integer->char #x1F421))			; 🐡	Blowfish
(char-name '|:turtle:| (integer->char #x1F422))			; 🐢	Turtle
(char-name '|:hatching_chick:| (integer->char #x1F423))			; 🐣	Hatching Chick
(char-name '|:baby_chick:| (integer->char #x1F424))			; 🐤	Baby Chick
(char-name '|:hatched_chick:| (integer->char #x1F425))			; 🐥	Front-Facing Baby Chick
(char-name '|:bird:| (integer->char #x1F426))			; 🐦	Bird
(char-name '|:penguin:| (integer->char #x1F427))			; 🐧	Penguin
(char-name '|:koala:| (integer->char #x1F428))			; 🐨	Koala
(char-name '|:poodle:| (integer->char #x1F429))			; 🐩	Poodle
(char-name '|:dromedary_camel:| (integer->char #x1F42A))			; 🐪	Dromedary Camel
(char-name '|:camel:| (integer->char #x1F42B))			; 🐫	Bactrian Camel
(char-name '|:dolphin:| (integer->char #x1F42C))			; 🐬	Dolphin
(char-name '|:mouse:| (integer->char #x1F42D))			; 🐭	Mouse Face
(char-name '|:cow:| (integer->char #x1F42E))			; 🐮	Cow Face
(char-name '|:tiger:| (integer->char #x1F42F))			; 🐯	Tiger Face
(char-name '|:rabbit:| (integer->char #x1F430))			; 🐰	Rabbit Face
(char-name '|:cat:| (integer->char #x1F431))			; 🐱	Cat Face
(char-name '|:dragon_face:| (integer->char #x1F432))			; 🐲	Dragon Face
(char-name '|:whale:| (integer->char #x1F433))			; 🐳	Spouting Whale
(char-name '|:horse:| (integer->char #x1F434))			; 🐴	Horse Face
(char-name '|:monkey_face:| (integer->char #x1F435))			; 🐵	Monkey Face
(char-name '|:dog:| (integer->char #x1F436))			; 🐶	Dog Face
(char-name '|:pig:| (integer->char #x1F437))			; 🐷	Pig Face
(char-name '|:frog:| (integer->char #x1F438))			; 🐸	Frog Face
(char-name '|:hamster:| (integer->char #x1F439))			; 🐹	Hamster Face
(char-name '|:wolf:| (integer->char #x1F43A))			; 🐺	Wolf Face
(char-name '|:bear:| (integer->char #x1F43B))			; 🐻	Bear Face
(char-name '|:panda_face:| (integer->char #x1F43C))			; 🐼	Panda Face
(char-name '|:pig_nose:| (integer->char #x1F43D))			; 🐽	Pig Nose
(char-name '|:feet:| (integer->char #x1F43E))			; 🐾	Paw Prints
(char-name '|:eyes:| (integer->char #x1F440))			; 👀	Eyes
(char-name '|:ear:| (integer->char #x1F442))			; 👂	Ear
(char-name '|:nose:| (integer->char #x1F443))			; 👃	Nose
(char-name '|:lips:| (integer->char #x1F444))			; 👄	Mouth
(char-name '|:tongue:| (integer->char #x1F445))			; 👅	Tongue
(char-name '|:point_up_2:| (integer->char #x1F446))			; 👆	White Up Pointing Backhand Index
(char-name '|:point_down:| (integer->char #x1F447))			; 👇	White Down Pointing Backhand Index
(char-name '|:point_left:| (integer->char #x1F448))			; 👈	White Left Pointing Backhand Index
(char-name '|:point_right:| (integer->char #x1F449))			; 👉	White Right Pointing Backhand Index
(char-name '|:facepunch:| (integer->char #x1F44A))			; 👊	Fisted Hand Sign
(char-name '|:wave:| (integer->char #x1F44B))			; 👋	Waving Hand Sign
(char-name '|:ok_hand:| (integer->char #x1F44C))			; 👌	Ok Hand Sign
(char-name '|:+1:| (integer->char #x1F44D))			; 👍	Thumbs Up Sign
(char-name '|:-1:| (integer->char #x1F44E))			; 👎	Thumbs Down Sign
(char-name '|:clap:| (integer->char #x1F44F))			; 👏	Clapping Hands Sign
(char-name '|:open_hands:| (integer->char #x1F450))			; 👐	Open Hands Sign
(char-name '|:crown:| (integer->char #x1F451))			; 👑	Crown
(char-name '|:womans_hat:| (integer->char #x1F452))			; 👒	Womans Hat
(char-name '|:eyeglasses:| (integer->char #x1F453))			; 👓	Eyeglasses
(char-name '|:necktie:| (integer->char #x1F454))			; 👔	Necktie
(char-name '|:shirt:| (integer->char #x1F455))			; 👕	T-Shirt
(char-name '|:jeans:| (integer->char #x1F456))			; 👖	Jeans
(char-name '|:dress:| (integer->char #x1F457))			; 👗	Dress
(char-name '|:kimono:| (integer->char #x1F458))			; 👘	Kimono
(char-name '|:bikini:| (integer->char #x1F459))			; 👙	Bikini
(char-name '|:womans_clothes:| (integer->char #x1F45A))			; 👚	Womans Clothes
(char-name '|:purse:| (integer->char #x1F45B))			; 👛	Purse
(char-name '|:handbag:| (integer->char #x1F45C))			; 👜	Handbag
(char-name '|:pouch:| (integer->char #x1F45D))			; 👝	Pouch
(char-name '|:mans_shoe:| (integer->char #x1F45E))			; 👞	Mans Shoe
(char-name '|:athletic_shoe:| (integer->char #x1F45F))			; 👟	Athletic Shoe
(char-name '|:high_heel:| (integer->char #x1F460))			; 👠	High-Heeled Shoe
(char-name '|:sandal:| (integer->char #x1F461))			; 👡	Womans Sandal
(char-name '|:boot:| (integer->char #x1F462))			; 👢	Womans Boots
(char-name '|:footprints:| (integer->char #x1F463))			; 👣	Footprints
(char-name '|:bust_in_silhouette:| (integer->char #x1F464))			; 👤	Bust In Silhouette
(char-name '|:busts_in_silhouette:| (integer->char #x1F465))			; 👥	Busts In Silhouette
(char-name '|:boy:| (integer->char #x1F466))			; 👦	Boy
(char-name '|:girl:| (integer->char #x1F467))			; 👧	Girl
(char-name '|:man:| (integer->char #x1F468))			; 👨	Man
(char-name '|:woman:| (integer->char #x1F469))			; 👩	Woman
(char-name '|:family:| (integer->char #x1F46A))			; 👪	Family
(char-name '|:couple:| (integer->char #x1F46B))			; 👫	Man And Woman Holding Hands
(char-name '|:two_men_holding_hands:| (integer->char #x1F46C))			; 👬	Two Men Holding Hands
(char-name '|:two_women_holding_hands:| (integer->char #x1F46D))			; 👭	Two Women Holding Hands
(char-name '|:cop:| (integer->char #x1F46E))			; 👮	Police Officer
(char-name '|:dancers:| (integer->char #x1F46F))			; 👯	Woman With Bunny Ears
(char-name '|:bride_with_veil:| (integer->char #x1F470))			; 👰	Bride With Veil
(char-name '|:person_with_blond_hair:| (integer->char #x1F471))			; 👱	Person With Blond Hair
(char-name '|:man_with_gua_pi_mao:| (integer->char #x1F472))			; 👲	Man With Gua Pi Mao
(char-name '|:man_with_turban:| (integer->char #x1F473))			; 👳	Man With Turban
(char-name '|:older_man:| (integer->char #x1F474))			; 👴	Older Man
(char-name '|:older_woman:| (integer->char #x1F475))			; 👵	Older Woman
(char-name '|:baby:| (integer->char #x1F476))			; 👶	Baby
(char-name '|:construction_worker:| (integer->char #x1F477))			; 👷	Construction Worker
(char-name '|:princess:| (integer->char #x1F478))			; 👸	Princess
(char-name '|:japanese_ogre:| (integer->char #x1F479))			; 👹	Japanese Ogre
(char-name '|:japanese_goblin:| (integer->char #x1F47A))			; 👺	Japanese Goblin
(char-name '|:ghost:| (integer->char #x1F47B))			; 👻	Ghost
(char-name '|:angel:| (integer->char #x1F47C))			; 👼	Baby Angel
(char-name '|:alien:| (integer->char #x1F47D))			; 👽	Extraterrestrial Alien
(char-name '|:space_invader:| (integer->char #x1F47E))			; 👾	Alien Monster
(char-name '|:imp:| (integer->char #x1F47F))			; 👿	Imp
(char-name '|:skull:| (integer->char #x1F480))			; 💀	Skull
(char-name '|:information_desk_person:| (integer->char #x1F481))			; 💁	Information Desk Person
(char-name '|:guardsman:| (integer->char #x1F482))			; 💂	Guardsman
(char-name '|:dancer:| (integer->char #x1F483))			; 💃	Dancer
(char-name '|:lipstick:| (integer->char #x1F484))			; 💄	Lipstick
(char-name '|:nail_care:| (integer->char #x1F485))			; 💅	Nail Polish
(char-name '|:massage:| (integer->char #x1F486))			; 💆	Face Massage
(char-name '|:haircut:| (integer->char #x1F487))			; 💇	Haircut
(char-name '|:barber:| (integer->char #x1F488))			; 💈	Barber Pole
(char-name '|:syringe:| (integer->char #x1F489))			; 💉	Syringe
(char-name '|:pill:| (integer->char #x1F48A))			; 💊	Pill
(char-name '|:kiss:| (integer->char #x1F48B))			; 💋	Kiss Mark
(char-name '|:love_letter:| (integer->char #x1F48C))			; 💌	Love Letter
(char-name '|:ring:| (integer->char #x1F48D))			; 💍	Ring
(char-name '|:gem:| (integer->char #x1F48E))			; 💎	Gem Stone
(char-name '|:couplekiss:| (integer->char #x1F48F))			; 💏	Kiss
(char-name '|:bouquet:| (integer->char #x1F490))			; 💐	Bouquet
(char-name '|:couple_with_heart:| (integer->char #x1F491))			; 💑	Couple With Heart
(char-name '|:wedding:| (integer->char #x1F492))			; 💒	Wedding
(char-name '|:heartbeat:| (integer->char #x1F493))			; 💓	Beating Heart
(char-name '|:broken_heart:| (integer->char #x1F494))			; 💔	Broken Heart
(char-name '|:two_hearts:| (integer->char #x1F495))			; 💕	Two Hearts
(char-name '|:sparkling_heart:| (integer->char #x1F496))			; 💖	Sparkling Heart
(char-name '|:heartpulse:| (integer->char #x1F497))			; 💗	Growing Heart
(char-name '|:cupid:| (integer->char #x1F498))			; 💘	Heart With Arrow
(char-name '|:blue_heart:| (integer->char #x1F499))			; 💙	Blue Heart
(char-name '|:green_heart:| (integer->char #x1F49A))			; 💚	Green Heart
(char-name '|:yellow_heart:| (integer->char #x1F49B))			; 💛	Yellow Heart
(char-name '|:purple_heart:| (integer->char #x1F49C))			; 💜	Purple Heart
(char-name '|:gift_heart:| (integer->char #x1F49D))			; 💝	Heart With Ribbon
(char-name '|:revolving_hearts:| (integer->char #x1F49E))			; 💞	Revolving Hearts
(char-name '|:heart_decoration:| (integer->char #x1F49F))			; 💟	Heart Decoration
(char-name '|:diamond_shape_with_a_dot_inside:| (integer->char #x1F4A0))			; 💠	Diamond Shape With A Dot Inside
(char-name '|:bulb:| (integer->char #x1F4A1))			; 💡	Electric Light Bulb
(char-name '|:anger:| (integer->char #x1F4A2))			; 💢	Anger Symbol
(char-name '|:bomb:| (integer->char #x1F4A3))			; 💣	Bomb
(char-name '|:zzz:| (integer->char #x1F4A4))			; 💤	Sleeping Symbol
(char-name '|:boom:| (integer->char #x1F4A5))			; 💥	Collision Symbol
(char-name '|:sweat_drops:| (integer->char #x1F4A6))			; 💦	Splashing Sweat Symbol
(char-name '|:droplet:| (integer->char #x1F4A7))			; 💧	Droplet
(char-name '|:dash:| (integer->char #x1F4A8))			; 💨	Dash Symbol
(char-name '|:hankey:| (integer->char #x1F4A9))			; 💩	Pile Of Poo
(char-name '|:muscle:| (integer->char #x1F4AA))			; 💪	Flexed Biceps
(char-name '|:dizzy:| (integer->char #x1F4AB))			; 💫	Dizzy Symbol
(char-name '|:speech_balloon:| (integer->char #x1F4AC))			; 💬	Speech Balloon
(char-name '|:thought_balloon:| (integer->char #x1F4AD))			; 💭	Thought Balloon
(char-name '|:white_flower:| (integer->char #x1F4AE))			; 💮	White Flower
(char-name '|:100:| (integer->char #x1F4AF))			; 💯	Hundred Points Symbol
(char-name '|:moneybag:| (integer->char #x1F4B0))			; 💰	Money Bag
(char-name '|:currency_exchange:| (integer->char #x1F4B1))			; 💱	Currency Exchange
(char-name '|:heavy_dollar_sign:| (integer->char #x1F4B2))			; 💲	Heavy Dollar Sign
(char-name '|:credit_card:| (integer->char #x1F4B3))			; 💳	Credit Card
(char-name '|:yen:| (integer->char #x1F4B4))			; 💴	Banknote With Yen Sign
(char-name '|:dollar:| (integer->char #x1F4B5))			; 💵	Banknote With Dollar Sign
(char-name '|:euro:| (integer->char #x1F4B6))			; 💶	Banknote With Euro Sign
(char-name '|:pound:| (integer->char #x1F4B7))			; 💷	Banknote With Pound Sign
(char-name '|:money_with_wings:| (integer->char #x1F4B8))			; 💸	Money With Wings
(char-name '|:chart:| (integer->char #x1F4B9))			; 💹	Chart With Upwards Trend And Yen Sign
(char-name '|:seat:| (integer->char #x1F4BA))			; 💺	Seat
(char-name '|:computer:| (integer->char #x1F4BB))			; 💻	Personal Computer
(char-name '|:briefcase:| (integer->char #x1F4BC))			; 💼	Briefcase
(char-name '|:minidisc:| (integer->char #x1F4BD))			; 💽	Minidisc
(char-name '|:floppy_disk:| (integer->char #x1F4BE))			; 💾	Floppy Disk
(char-name '|:cd:| (integer->char #x1F4BF))			; 💿	Optical Disc
(char-name '|:dvd:| (integer->char #x1F4C0))			; 📀	Dvd
(char-name '|:file_folder:| (integer->char #x1F4C1))			; 📁	File Folder
(char-name '|:open_file_folder:| (integer->char #x1F4C2))			; 📂	Open File Folder
(char-name '|:page_with_curl:| (integer->char #x1F4C3))			; 📃	Page With Curl
(char-name '|:page_facing_up:| (integer->char #x1F4C4))			; 📄	Page Facing Up
(char-name '|:date:| (integer->char #x1F4C5))			; 📅	Calendar
(char-name '|:calendar:| (integer->char #x1F4C6))			; 📆	Tear-Off Calendar
(char-name '|:card_index:| (integer->char #x1F4C7))			; 📇	Card Index
(char-name '|:chart_with_upwards_trend:| (integer->char #x1F4C8))			; 📈	Chart With Upwards Trend
(char-name '|:chart_with_downwards_trend:| (integer->char #x1F4C9))			; 📉	Chart With Downwards Trend
(char-name '|:bar_chart:| (integer->char #x1F4CA))			; 📊	Bar Chart
(char-name '|:clipboard:| (integer->char #x1F4CB))			; 📋	Clipboard
(char-name '|:pushpin:| (integer->char #x1F4CC))			; 📌	Pushpin
(char-name '|:round_pushpin:| (integer->char #x1F4CD))			; 📍	Round Pushpin
(char-name '|:paperclip:| (integer->char #x1F4CE))			; 📎	Paperclip
(char-name '|:straight_ruler:| (integer->char #x1F4CF))			; 📏	Straight Ruler
(char-name '|:triangular_ruler:| (integer->char #x1F4D0))			; 📐	Triangular Ruler
(char-name '|:bookmark_tabs:| (integer->char #x1F4D1))			; 📑	Bookmark Tabs
(char-name '|:ledger:| (integer->char #x1F4D2))			; 📒	Ledger
(char-name '|:notebook:| (integer->char #x1F4D3))			; 📓	Notebook
(char-name '|:notebook_with_decorative_cover:| (integer->char #x1F4D4))			; 📔	Notebook With Decorative Cover
(char-name '|:closed_book:| (integer->char #x1F4D5))			; 📕	Closed Book
(char-name '|:book:| (integer->char #x1F4D6))			; 📖	Open Book
(char-name '|:green_book:| (integer->char #x1F4D7))			; 📗	Green Book
(char-name '|:blue_book:| (integer->char #x1F4D8))			; 📘	Blue Book
(char-name '|:orange_book:| (integer->char #x1F4D9))			; 📙	Orange Book
(char-name '|:books:| (integer->char #x1F4DA))			; 📚	Books
(char-name '|:name_badge:| (integer->char #x1F4DB))			; 📛	Name Badge
(char-name '|:scroll:| (integer->char #x1F4DC))			; 📜	Scroll
(char-name '|:memo:| (integer->char #x1F4DD))			; 📝	Memo
(char-name '|:telephone_receiver:| (integer->char #x1F4DE))			; 📞	Telephone Receiver
(char-name '|:pager:| (integer->char #x1F4DF))			; 📟	Pager
(char-name '|:fax:| (integer->char #x1F4E0))			; 📠	Fax Machine
(char-name '|:satellite:| (integer->char #x1F4E1))			; 📡	Satellite Antenna
(char-name '|:loudspeaker:| (integer->char #x1F4E2))			; 📢	Public Address Loudspeaker
(char-name '|:mega:| (integer->char #x1F4E3))			; 📣	Cheering Megaphone
(char-name '|:outbox_tray:| (integer->char #x1F4E4))			; 📤	Outbox Tray
(char-name '|:inbox_tray:| (integer->char #x1F4E5))			; 📥	Inbox Tray
(char-name '|:package:| (integer->char #x1F4E6))			; 📦	Package
(char-name '|:e-mail:| (integer->char #x1F4E7))			; 📧	E-Mail Symbol
(char-name '|:incoming_envelope:| (integer->char #x1F4E8))			; 📨	Incoming Envelope
(char-name '|:envelope_with_arrow:| (integer->char #x1F4E9))			; 📩	Envelope With Downwards Arrow Above
(char-name '|:mailbox_closed:| (integer->char #x1F4EA))			; 📪	Closed Mailbox With Lowered Flag
(char-name '|:mailbox:| (integer->char #x1F4EB))			; 📫	Closed Mailbox With Raised Flag
(char-name '|:mailbox_with_mail:| (integer->char #x1F4EC))			; 📬	Open Mailbox With Raised Flag
(char-name '|:mailbox_with_no_mail:| (integer->char #x1F4ED))			; 📭	Open Mailbox With Lowered Flag
(char-name '|:postbox:| (integer->char #x1F4EE))			; 📮	Postbox
(char-name '|:postal_horn:| (integer->char #x1F4EF))			; 📯	Postal Horn
(char-name '|:newspaper:| (integer->char #x1F4F0))			; 📰	Newspaper
(char-name '|:iphone:| (integer->char #x1F4F1))			; 📱	Mobile Phone
(char-name '|:calling:| (integer->char #x1F4F2))			; 📲	Mobile Phone With Rightwards Arrow At Left
(char-name '|:vibration_mode:| (integer->char #x1F4F3))			; 📳	Vibration Mode
(char-name '|:mobile_phone_off:| (integer->char #x1F4F4))			; 📴	Mobile Phone Off
(char-name '|:no_mobile_phones:| (integer->char #x1F4F5))			; 📵	No Mobile Phones
(char-name '|:signal_strength:| (integer->char #x1F4F6))			; 📶	Antenna With Bars
(char-name '|:camera:| (integer->char #x1F4F7))			; 📷	Camera
(char-name '|:video_camera:| (integer->char #x1F4F9))			; 📹	Video Camera
(char-name '|:tv:| (integer->char #x1F4FA))			; 📺	Television
(char-name '|:radio:| (integer->char #x1F4FB))			; 📻	Radio
(char-name '|:vhs:| (integer->char #x1F4FC))			; 📼	Videocassette
(char-name '|:twisted_rightwards_arrows:| (integer->char #x1F500))			; 🔀	Twisted Rightwards Arrows
(char-name '|:repeat:| (integer->char #x1F501))			; 🔁	Clockwise Rightwards And Leftwards Open Circle Arrows
(char-name '|:repeat_one:| (integer->char #x1F502))			; 🔂	Clockwise Rightwards And Leftwards Open Circle Arrows With Circled One Overlay
(char-name '|:arrows_clockwise:| (integer->char #x1F503))			; 🔃	Clockwise Downwards And Upwards Open Circle Arrows
(char-name '|:arrows_counterclockwise:| (integer->char #x1F504))			; 🔄	Anticlockwise Downwards And Upwards Open Circle Arrows
(char-name '|:low_brightness:| (integer->char #x1F505))			; 🔅	Low Brightness Symbol
(char-name '|:high_brightness:| (integer->char #x1F506))			; 🔆	High Brightness Symbol
(char-name '|:mute:| (integer->char #x1F507))			; 🔇	Speaker With Cancellation Stroke
(char-name '|:speaker:| (integer->char #x1F508))			; 🔈	Speaker
(char-name '|:sound:| (integer->char #x1F509))			; 🔉	Speaker With One Sound Wave
(char-name '|:loud_sound:| (integer->char #x1F50A))			; 🔊	Speaker With Three Sound Waves
(char-name '|:battery:| (integer->char #x1F50B))			; 🔋	Battery
(char-name '|:electric_plug:| (integer->char #x1F50C))			; 🔌	Electric Plug
(char-name '|:mag:| (integer->char #x1F50D))			; 🔍	Left-Pointing Magnifying Glass
(char-name '|:mag_right:| (integer->char #x1F50E))			; 🔎	Right-Pointing Magnifying Glass
(char-name '|:lock_with_ink_pen:| (integer->char #x1F50F))			; 🔏	Lock With Ink Pen
(char-name '|:closed_lock_with_key:| (integer->char #x1F510))			; 🔐	Closed Lock With Key
(char-name '|:key:| (integer->char #x1F511))			; 🔑	Key
(char-name '|:lock:| (integer->char #x1F512))			; 🔒	Lock
(char-name '|:unlock:| (integer->char #x1F513))			; 🔓	Open Lock
(char-name '|:bell:| (integer->char #x1F514))			; 🔔	Bell
(char-name '|:no_bell:| (integer->char #x1F515))			; 🔕	Bell With Cancellation Stroke
(char-name '|:bookmark:| (integer->char #x1F516))			; 🔖	Bookmark
(char-name '|:link:| (integer->char #x1F517))			; 🔗	Link Symbol
(char-name '|:radio_button:| (integer->char #x1F518))			; 🔘	Radio Button
(char-name '|:back:| (integer->char #x1F519))			; 🔙	Back With Leftwards Arrow Above
(char-name '|:end:| (integer->char #x1F51A))			; 🔚	End With Leftwards Arrow Above
(char-name '|:on:| (integer->char #x1F51B))			; 🔛	On With Exclamation Mark With Left Right Arrow Above
(char-name '|:soon:| (integer->char #x1F51C))			; 🔜	Soon With Rightwards Arrow Above
(char-name '|:top:| (integer->char #x1F51D))			; 🔝	Top With Upwards Arrow Above
(char-name '|:underage:| (integer->char #x1F51E))			; 🔞	No One Under Eighteen Symbol
(char-name '|:keycap_ten:| (integer->char #x1F51F))			; 🔟	Keycap Ten
(char-name '|:capital_abcd:| (integer->char #x1F520))			; 🔠	Input Symbol For Latin Capital Letters
(char-name '|:abcd:| (integer->char #x1F521))			; 🔡	Input Symbol For Latin Small Letters
(char-name '|:1234:| (integer->char #x1F522))			; 🔢	Input Symbol For Numbers
(char-name '|:symbols:| (integer->char #x1F523))			; 🔣	Input Symbol For Symbols
(char-name '|:abc:| (integer->char #x1F524))			; 🔤	Input Symbol For Latin Letters
(char-name '|:fire:| (integer->char #x1F525))			; 🔥	Fire
(char-name '|:flashlight:| (integer->char #x1F526))			; 🔦	Electric Torch
(char-name '|:wrench:| (integer->char #x1F527))			; 🔧	Wrench
(char-name '|:hammer:| (integer->char #x1F528))			; 🔨	Hammer
(char-name '|:nut_and_bolt:| (integer->char #x1F529))			; 🔩	Nut And Bolt
(char-name '|:hocho:| (integer->char #x1F52A))			; 🔪	Hocho
(char-name '|:gun:| (integer->char #x1F52B))			; 🔫	Pistol
(char-name '|:microscope:| (integer->char #x1F52C))			; 🔬	Microscope
(char-name '|:telescope:| (integer->char #x1F52D))			; 🔭	Telescope
(char-name '|:crystal_ball:| (integer->char #x1F52E))			; 🔮	Crystal Ball
(char-name '|:six_pointed_star:| (integer->char #x1F52F))			; 🔯	Six Pointed Star With Middle Dot
(char-name '|:beginner:| (integer->char #x1F530))			; 🔰	Japanese Symbol For Beginner
(char-name '|:trident:| (integer->char #x1F531))			; 🔱	Trident Emblem
(char-name '|:black_square_button:| (integer->char #x1F532))			; 🔲	Black Square Button
(char-name '|:white_square_button:| (integer->char #x1F533))			; 🔳	White Square Button
(char-name '|:red_circle:| (integer->char #x1F534))			; 🔴	Large Red Circle
(char-name '|:large_blue_circle:| (integer->char #x1F535))			; 🔵	Large Blue Circle
(char-name '|:large_orange_diamond:| (integer->char #x1F536))			; 🔶	Large Orange Diamond
(char-name '|:large_blue_diamond:| (integer->char #x1F537))			; 🔷	Large Blue Diamond
(char-name '|:small_orange_diamond:| (integer->char #x1F538))			; 🔸	Small Orange Diamond
(char-name '|:small_blue_diamond:| (integer->char #x1F539))			; 🔹	Small Blue Diamond
(char-name '|:small_red_triangle:| (integer->char #x1F53A))			; 🔺	Up-Pointing Red Triangle
(char-name '|:small_red_triangle_down:| (integer->char #x1F53B))			; 🔻	Down-Pointing Red Triangle
(char-name '|:arrow_up_small:| (integer->char #x1F53C))			; 🔼	Up-Pointing Small Red Triangle
(char-name '|:arrow_down_small:| (integer->char #x1F53D))			; 🔽	Down-Pointing Small Red Triangle
(char-name '|:clock1:| (integer->char #x1F550))			; 🕐	Clock Face One Oclock
(char-name '|:clock2:| (integer->char #x1F551))			; 🕑	Clock Face Two Oclock
(char-name '|:clock3:| (integer->char #x1F552))			; 🕒	Clock Face Three Oclock
(char-name '|:clock4:| (integer->char #x1F553))			; 🕓	Clock Face Four Oclock
(char-name '|:clock5:| (integer->char #x1F554))			; 🕔	Clock Face Five Oclock
(char-name '|:clock6:| (integer->char #x1F555))			; 🕕	Clock Face Six Oclock
(char-name '|:clock7:| (integer->char #x1F556))			; 🕖	Clock Face Seven Oclock
(char-name '|:clock8:| (integer->char #x1F557))			; 🕗	Clock Face Eight Oclock
(char-name '|:clock9:| (integer->char #x1F558))			; 🕘	Clock Face Nine Oclock
(char-name '|:clock10:| (integer->char #x1F559))			; 🕙	Clock Face Ten Oclock
(char-name '|:clock11:| (integer->char #x1F55A))			; 🕚	Clock Face Eleven Oclock
(char-name '|:clock12:| (integer->char #x1F55B))			; 🕛	Clock Face Twelve Oclock
(char-name '|:clock130:| (integer->char #x1F55C))			; 🕜	Clock Face One-Thirty
(char-name '|:clock230:| (integer->char #x1F55D))			; 🕝	Clock Face Two-Thirty
(char-name '|:clock330:| (integer->char #x1F55E))			; 🕞	Clock Face Three-Thirty
(char-name '|:clock430:| (integer->char #x1F55F))			; 🕟	Clock Face Four-Thirty
(char-name '|:clock530:| (integer->char #x1F560))			; 🕠	Clock Face Five-Thirty
(char-name '|:clock630:| (integer->char #x1F561))			; 🕡	Clock Face Six-Thirty
(char-name '|:clock730:| (integer->char #x1F562))			; 🕢	Clock Face Seven-Thirty
(char-name '|:clock830:| (integer->char #x1F563))			; 🕣	Clock Face Eight-Thirty
(char-name '|:clock930:| (integer->char #x1F564))			; 🕤	Clock Face Nine-Thirty
(char-name '|:clock1030:| (integer->char #x1F565))			; 🕥	Clock Face Ten-Thirty
(char-name '|:clock1130:| (integer->char #x1F566))			; 🕦	Clock Face Eleven-Thirty
(char-name '|:clock1230:| (integer->char #x1F567))			; 🕧	Clock Face Twelve-Thirty
(char-name '|:mount_fuji:| (integer->char #x1F5FB))			; 🗻	Mount Fuji
(char-name '|:tokyo_tower:| (integer->char #x1F5FC))			; 🗼	Tokyo Tower
(char-name '|:statue_of_liberty:| (integer->char #x1F5FD))			; 🗽	Statue Of Liberty
(char-name '|:japan:| (integer->char #x1F5FE))			; 🗾	Silhouette Of Japan
(char-name '|:moyai:| (integer->char #x1F5FF))			; 🗿	Moyai
(char-name '|:grinning:| (integer->char #x1F600))			; 😀	Grinning Face
(char-name '|:grin:| (integer->char #x1F601))			; 😁	Grinning Face With Smiling Eyes
(char-name '|:joy:| (integer->char #x1F602))			; 😂	Face With Tears Of Joy
(char-name '|:smiley:| (integer->char #x1F603))			; 😃	Smiling Face With Open Mouth
(char-name '|:smile:| (integer->char #x1F604))			; 😄	Smiling Face With Open Mouth And Smiling Eyes
(char-name '|:sweat_smile:| (integer->char #x1F605))			; 😅	Smiling Face With Open Mouth And Cold Sweat
(char-name '|:laughing:| (integer->char #x1F606))			; 😆	Smiling Face With Open Mouth And Tightly-Closed Eyes
(char-name '|:innocent:| (integer->char #x1F607))			; 😇	Smiling Face With Halo
(char-name '|:smiling_imp:| (integer->char #x1F608))			; 😈	Smiling Face With Horns
(char-name '|:wink:| (integer->char #x1F609))			; 😉	Winking Face
(char-name '|:blush:| (integer->char #x1F60A))			; 😊	Smiling Face With Smiling Eyes
(char-name '|:yum:| (integer->char #x1F60B))			; 😋	Face Savouring Delicious Food
(char-name '|:relieved:| (integer->char #x1F60C))			; 😌	Relieved Face
(char-name '|:heart_eyes:| (integer->char #x1F60D))			; 😍	Smiling Face With Heart-Shaped Eyes
(char-name '|:sunglasses:| (integer->char #x1F60E))			; 😎	Smiling Face With Sunglasses
(char-name '|:smirk:| (integer->char #x1F60F))			; 😏	Smirking Face
(char-name '|:neutral_face:| (integer->char #x1F610))			; 😐	Neutral Face
(char-name '|:expressionless:| (integer->char #x1F611))			; 😑	Expressionless Face
(char-name '|:unamused:| (integer->char #x1F612))			; 😒	Unamused Face
(char-name '|:sweat:| (integer->char #x1F613))			; 😓	Face With Cold Sweat
(char-name '|:pensive:| (integer->char #x1F614))			; 😔	Pensive Face
(char-name '|:confused:| (integer->char #x1F615))			; 😕	Confused Face
(char-name '|:confounded:| (integer->char #x1F616))			; 😖	Confounded Face
(char-name '|:kissing:| (integer->char #x1F617))			; 😗	Kissing Face
(char-name '|:kissing_heart:| (integer->char #x1F618))			; 😘	Face Throwing A Kiss
(char-name '|:kissing_smiling_eyes:| (integer->char #x1F619))			; 😙	Kissing Face With Smiling Eyes
(char-name '|:kissing_closed_eyes:| (integer->char #x1F61A))			; 😚	Kissing Face With Closed Eyes
(char-name '|:stuck_out_tongue:| (integer->char #x1F61B))			; 😛	Face With Stuck-Out Tongue
(char-name '|:stuck_out_tongue_winking_eye:| (integer->char #x1F61C))			; 😜	Face With Stuck-Out Tongue And Winking Eye
(char-name '|:stuck_out_tongue_closed_eyes:| (integer->char #x1F61D))			; 😝	Face With Stuck-Out Tongue And Tightly-Closed Eyes
(char-name '|:disappointed:| (integer->char #x1F61E))			; 😞	Disappointed Face
(char-name '|:worried:| (integer->char #x1F61F))			; 😟	Worried Face
(char-name '|:angry:| (integer->char #x1F620))			; 😠	Angry Face
(char-name '|:rage:| (integer->char #x1F621))			; 😡	Pouting Face
(char-name '|:cry:| (integer->char #x1F622))			; 😢	Crying Face
(char-name '|:persevere:| (integer->char #x1F623))			; 😣	Persevering Face
(char-name '|:triumph:| (integer->char #x1F624))			; 😤	Face With Look Of Triumph
(char-name '|:disappointed_relieved:| (integer->char #x1F625))			; 😥	Disappointed But Relieved Face
(char-name '|:frowning:| (integer->char #x1F626))			; 😦	Frowning Face With Open Mouth
(char-name '|:anguished:| (integer->char #x1F627))			; 😧	Anguished Face
(char-name '|:fearful:| (integer->char #x1F628))			; 😨	Fearful Face
(char-name '|:weary:| (integer->char #x1F629))			; 😩	Weary Face
(char-name '|:sleepy:| (integer->char #x1F62A))			; 😪	Sleepy Face
(char-name '|:tired_face:| (integer->char #x1F62B))			; 😫	Tired Face
(char-name '|:grimacing:| (integer->char #x1F62C))			; 😬	Grimacing Face
(char-name '|:sob:| (integer->char #x1F62D))			; 😭	Loudly Crying Face
(char-name '|:open_mouth:| (integer->char #x1F62E))			; 😮	Face With Open Mouth
(char-name '|:hushed:| (integer->char #x1F62F))			; 😯	Hushed Face
(char-name '|:cold_sweat:| (integer->char #x1F630))			; 😰	Face With Open Mouth And Cold Sweat
(char-name '|:scream:| (integer->char #x1F631))			; 😱	Face Screaming In Fear
(char-name '|:astonished:| (integer->char #x1F632))			; 😲	Astonished Face
(char-name '|:flushed:| (integer->char #x1F633))			; 😳	Flushed Face
(char-name '|:sleeping:| (integer->char #x1F634))			; 😴	Sleeping Face
(char-name '|:dizzy_face:| (integer->char #x1F635))			; 😵	Dizzy Face
(char-name '|:no_mouth:| (integer->char #x1F636))			; 😶	Face Without Mouth
(char-name '|:mask:| (integer->char #x1F637))			; 😷	Face With Medical Mask
(char-name '|:smile_cat:| (integer->char #x1F638))			; 😸	Grinning Cat Face With Smiling Eyes
(char-name '|:joy_cat:| (integer->char #x1F639))			; 😹	Cat Face With Tears Of Joy
(char-name '|:smiley_cat:| (integer->char #x1F63A))			; 😺	Smiling Cat Face With Open Mouth
(char-name '|:heart_eyes_cat:| (integer->char #x1F63B))			; 😻	Smiling Cat Face With Heart-Shaped Eyes
(char-name '|:smirk_cat:| (integer->char #x1F63C))			; 😼	Cat Face With Wry Smile
(char-name '|:kissing_cat:| (integer->char #x1F63D))			; 😽	Kissing Cat Face With Closed Eyes
(char-name '|:pouting_cat:| (integer->char #x1F63E))			; 😾	Pouting Cat Face
(char-name '|:crying_cat_face:| (integer->char #x1F63F))			; 😿	Crying Cat Face
(char-name '|:scream_cat:| (integer->char #x1F640))			; 🙀	Weary Cat Face
(char-name '|:no_good:| (integer->char #x1F645))			; 🙅	Face With No Good Gesture
(char-name '|:ok_woman:| (integer->char #x1F646))			; 🙆	Face With Ok Gesture
(char-name '|:bow:| (integer->char #x1F647))			; 🙇	Person Bowing Deeply
(char-name '|:see_no_evil:| (integer->char #x1F648))			; 🙈	See-No-Evil Monkey
(char-name '|:hear_no_evil:| (integer->char #x1F649))			; 🙉	Hear-No-Evil Monkey
(char-name '|:speak_no_evil:| (integer->char #x1F64A))			; 🙊	Speak-No-Evil Monkey
(char-name '|:raising_hand:| (integer->char #x1F64B))			; 🙋	Happy Person Raising One Hand
(char-name '|:raised_hands:| (integer->char #x1F64C))			; 🙌	Person Raising Both Hands In Celebration
(char-name '|:person_frowning:| (integer->char #x1F64D))			; 🙍	Person Frowning
(char-name '|:person_with_pouting_face:| (integer->char #x1F64E))			; 🙎	Person With Pouting Face
(char-name '|:pray:| (integer->char #x1F64F))			; 🙏	Person With Folded Hands
(char-name '|:rocket:| (integer->char #x1F680))			; 🚀	Rocket
(char-name '|:helicopter:| (integer->char #x1F681))			; 🚁	Helicopter
(char-name '|:steam_locomotive:| (integer->char #x1F682))			; 🚂	Steam Locomotive
(char-name '|:railway_car:| (integer->char #x1F683))			; 🚃	Railway Car
(char-name '|:bullettrain_side:| (integer->char #x1F684))			; 🚄	High-Speed Train
(char-name '|:bullettrain_front:| (integer->char #x1F685))			; 🚅	High-Speed Train With Bullet Nose
(char-name '|:train2:| (integer->char #x1F686))			; 🚆	Train
(char-name '|:metro:| (integer->char #x1F687))			; 🚇	Metro
(char-name '|:light_rail:| (integer->char #x1F688))			; 🚈	Light Rail
(char-name '|:station:| (integer->char #x1F689))			; 🚉	Station
(char-name '|:tram:| (integer->char #x1F68A))			; 🚊	Tram
(char-name '|:train:| (integer->char #x1F68B))			; 🚋	Tram Car
(char-name '|:bus:| (integer->char #x1F68C))			; 🚌	Bus
(char-name '|:oncoming_bus:| (integer->char #x1F68D))			; 🚍	Oncoming Bus
(char-name '|:trolleybus:| (integer->char #x1F68E))			; 🚎	Trolleybus
(char-name '|:busstop:| (integer->char #x1F68F))			; 🚏	Bus Stop
(char-name '|:minibus:| (integer->char #x1F690))			; 🚐	Minibus
(char-name '|:ambulance:| (integer->char #x1F691))			; 🚑	Ambulance
(char-name '|:fire_engine:| (integer->char #x1F692))			; 🚒	Fire Engine
(char-name '|:police_car:| (integer->char #x1F693))			; 🚓	Police Car
(char-name '|:oncoming_police_car:| (integer->char #x1F694))			; 🚔	Oncoming Police Car
(char-name '|:taxi:| (integer->char #x1F695))			; 🚕	Taxi
(char-name '|:oncoming_taxi:| (integer->char #x1F696))			; 🚖	Oncoming Taxi
(char-name '|:car:| (integer->char #x1F697))			; 🚗	Automobile
(char-name '|:oncoming_automobile:| (integer->char #x1F698))			; 🚘	Oncoming Automobile
(char-name '|:blue_car:| (integer->char #x1F699))			; 🚙	Recreational Vehicle
(char-name '|:truck:| (integer->char #x1F69A))			; 🚚	Delivery Truck
(char-name '|:articulated_lorry:| (integer->char #x1F69B))			; 🚛	Articulated Lorry
(char-name '|:tractor:| (integer->char #x1F69C))			; 🚜	Tractor
(char-name '|:monorail:| (integer->char #x1F69D))			; 🚝	Monorail
(char-name '|:mountain_railway:| (integer->char #x1F69E))			; 🚞	Mountain Railway
(char-name '|:suspension_railway:| (integer->char #x1F69F))			; 🚟	Suspension Railway
(char-name '|:mountain_cableway:| (integer->char #x1F6A0))			; 🚠	Mountain Cableway
(char-name '|:aerial_tramway:| (integer->char #x1F6A1))			; 🚡	Aerial Tramway
(char-name '|:ship:| (integer->char #x1F6A2))			; 🚢	Ship
(char-name '|:rowboat:| (integer->char #x1F6A3))			; 🚣	Rowboat
(char-name '|:speedboat:| (integer->char #x1F6A4))			; 🚤	Speedboat
(char-name '|:traffic_light:| (integer->char #x1F6A5))			; 🚥	Horizontal Traffic Light
(char-name '|:vertical_traffic_light:| (integer->char #x1F6A6))			; 🚦	Vertical Traffic Light
(char-name '|:construction:| (integer->char #x1F6A7))			; 🚧	Construction Sign
(char-name '|:rotating_light:| (integer->char #x1F6A8))			; 🚨	Police Cars Revolving Light
(char-name '|:triangular_flag_on_post:| (integer->char #x1F6A9))			; 🚩	Triangular Flag On Post
(char-name '|:door:| (integer->char #x1F6AA))			; 🚪	Door
(char-name '|:no_entry_sign:| (integer->char #x1F6AB))			; 🚫	No Entry Sign
(char-name '|:smoking:| (integer->char #x1F6AC))			; 🚬	Smoking Symbol
(char-name '|:no_smoking:| (integer->char #x1F6AD))			; 🚭	No Smoking Symbol
(char-name '|:put_litter_in_its_place:| (integer->char #x1F6AE))			; 🚮	Put Litter In Its Place Symbol
(char-name '|:do_not_litter:| (integer->char #x1F6AF))			; 🚯	Do Not Litter Symbol
(char-name '|:potable_water:| (integer->char #x1F6B0))			; 🚰	Potable Water Symbol
(char-name '|:non-potable_water:| (integer->char #x1F6B1))			; 🚱	Non-Potable Water Symbol
(char-name '|:bike:| (integer->char #x1F6B2))			; 🚲	Bicycle
(char-name '|:no_bicycles:| (integer->char #x1F6B3))			; 🚳	No Bicycles
(char-name '|:bicyclist:| (integer->char #x1F6B4))			; 🚴	Bicyclist
(char-name '|:mountain_bicyclist:| (integer->char #x1F6B5))			; 🚵	Mountain Bicyclist
(char-name '|:walking:| (integer->char #x1F6B6))			; 🚶	Pedestrian
(char-name '|:no_pedestrians:| (integer->char #x1F6B7))			; 🚷	No Pedestrians
(char-name '|:children_crossing:| (integer->char #x1F6B8))			; 🚸	Children Crossing
(char-name '|:mens:| (integer->char #x1F6B9))			; 🚹	Mens Symbol
(char-name '|:womens:| (integer->char #x1F6BA))			; 🚺	Womens Symbol
(char-name '|:restroom:| (integer->char #x1F6BB))			; 🚻	Restroom
(char-name '|:baby_symbol:| (integer->char #x1F6BC))			; 🚼	Baby Symbol
(char-name '|:toilet:| (integer->char #x1F6BD))			; 🚽	Toilet
(char-name '|:wc:| (integer->char #x1F6BE))			; 🚾	Water Closet
(char-name '|:shower:| (integer->char #x1F6BF))			; 🚿	Shower
(char-name '|:bath:| (integer->char #x1F6C0))			; 🛀	Bath
(char-name '|:bathtub:| (integer->char #x1F6C1))			; 🛁	Bathtub
(char-name '|:passport_control:| (integer->char #x1F6C2))			; 🛂	Passport Control
(char-name '|:customs:| (integer->char #x1F6C3))			; 🛃	Customs
(char-name '|:baggage_claim:| (integer->char #x1F6C4))			; 🛄	Baggage Claim
(char-name '|:left_luggage:| (integer->char #x1F6C5))			; 🛅	Left Luggage

) ;unitex-named-chars
